# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220101
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Input JSON to get audio inference from TTS Service.
  class AiSpeech::Models::SynthesizeSpeechDetails
    # **[Required]** The text input to get the inference audio from TTS Service.
    # @return [String]
    attr_accessor :text

    # If set to true, response will be sent in the chunked transfer-encoding and audio chunks
    # are sent back as and when they are ready. If set to false, response will be sent only once
    # the entire audio is generated.
    #
    # @return [BOOLEAN]
    attr_accessor :is_stream_enabled

    # The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment where the user has access to call `SpeechSynthesize` api. But default user access will be checked at tenancy level.
    # @return [String]
    attr_accessor :compartment_id

    # @return [OCI::AiSpeech::Models::TtsConfiguration]
    attr_accessor :configuration

    # @return [OCI::AiSpeech::Models::TtsAudioConfig]
    attr_accessor :audio_config

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'text': :'text',
        'is_stream_enabled': :'isStreamEnabled',
        'compartment_id': :'compartmentId',
        'configuration': :'configuration',
        'audio_config': :'audioConfig'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'text': :'String',
        'is_stream_enabled': :'BOOLEAN',
        'compartment_id': :'String',
        'configuration': :'OCI::AiSpeech::Models::TtsConfiguration',
        'audio_config': :'OCI::AiSpeech::Models::TtsAudioConfig'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :text The value to assign to the {#text} property
    # @option attributes [BOOLEAN] :is_stream_enabled The value to assign to the {#is_stream_enabled} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [OCI::AiSpeech::Models::TtsConfiguration] :configuration The value to assign to the {#configuration} property
    # @option attributes [OCI::AiSpeech::Models::TtsAudioConfig] :audio_config The value to assign to the {#audio_config} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.text = attributes[:'text'] if attributes[:'text']

      self.is_stream_enabled = attributes[:'isStreamEnabled'] unless attributes[:'isStreamEnabled'].nil?
      self.is_stream_enabled = false if is_stream_enabled.nil? && !attributes.key?(:'isStreamEnabled') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :isStreamEnabled and :is_stream_enabled' if attributes.key?(:'isStreamEnabled') && attributes.key?(:'is_stream_enabled')

      self.is_stream_enabled = attributes[:'is_stream_enabled'] unless attributes[:'is_stream_enabled'].nil?
      self.is_stream_enabled = false if is_stream_enabled.nil? && !attributes.key?(:'isStreamEnabled') && !attributes.key?(:'is_stream_enabled') # rubocop:disable Style/StringLiterals

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.configuration = attributes[:'configuration'] if attributes[:'configuration']

      self.audio_config = attributes[:'audioConfig'] if attributes[:'audioConfig']

      raise 'You cannot provide both :audioConfig and :audio_config' if attributes.key?(:'audioConfig') && attributes.key?(:'audio_config')

      self.audio_config = attributes[:'audio_config'] if attributes[:'audio_config']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        text == other.text &&
        is_stream_enabled == other.is_stream_enabled &&
        compartment_id == other.compartment_id &&
        configuration == other.configuration &&
        audio_config == other.audio_config
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [text, is_stream_enabled, compartment_id, configuration, audio_config].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
