# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20190531
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # The information about the NodeBackupConfiguration.
  class Bds::Models::CreateNodeBackupConfigurationDetails
    # This attribute is required.
    # @return [OCI::Bds::Models::LevelTypeDetails]
    attr_accessor :level_type_details

    # A user-friendly name. Only ASCII alphanumeric characters with no spaces allowed. The name does not have to be unique, and it may be changed. Avoid entering confidential information.
    # @return [String]
    attr_accessor :display_name

    # The time zone of the execution schedule, in IANA time zone database name format
    # @return [String]
    attr_accessor :timezone

    # **[Required]** Day/time recurrence (specified following RFC 5545) at which to trigger the backup process. Currently only DAILY, WEEKLY and MONTHLY frequency is supported. Days of the week are specified using BYDAY field. Time of the day is specified using BYHOUR. Other fields are not supported.
    #
    # @return [String]
    attr_accessor :schedule

    # Number of backup copies to retain.
    # @return [Integer]
    attr_accessor :number_of_backups_to_retain

    # Incremental backup type includes only the changes since the last backup. Full backup type includes all changes since the volume was created.
    # @return [String]
    attr_accessor :backup_type

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'level_type_details': :'levelTypeDetails',
        'display_name': :'displayName',
        'timezone': :'timezone',
        'schedule': :'schedule',
        'number_of_backups_to_retain': :'numberOfBackupsToRetain',
        'backup_type': :'backupType'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'level_type_details': :'OCI::Bds::Models::LevelTypeDetails',
        'display_name': :'String',
        'timezone': :'String',
        'schedule': :'String',
        'number_of_backups_to_retain': :'Integer',
        'backup_type': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [OCI::Bds::Models::LevelTypeDetails] :level_type_details The value to assign to the {#level_type_details} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :timezone The value to assign to the {#timezone} property
    # @option attributes [String] :schedule The value to assign to the {#schedule} property
    # @option attributes [Integer] :number_of_backups_to_retain The value to assign to the {#number_of_backups_to_retain} property
    # @option attributes [String] :backup_type The value to assign to the {#backup_type} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.level_type_details = attributes[:'levelTypeDetails'] if attributes[:'levelTypeDetails']

      raise 'You cannot provide both :levelTypeDetails and :level_type_details' if attributes.key?(:'levelTypeDetails') && attributes.key?(:'level_type_details')

      self.level_type_details = attributes[:'level_type_details'] if attributes[:'level_type_details']

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.timezone = attributes[:'timezone'] if attributes[:'timezone']
      self.timezone = "Etc/UTC" if timezone.nil? && !attributes.key?(:'timezone') # rubocop:disable Style/StringLiterals

      self.schedule = attributes[:'schedule'] if attributes[:'schedule']

      self.number_of_backups_to_retain = attributes[:'numberOfBackupsToRetain'] if attributes[:'numberOfBackupsToRetain']

      raise 'You cannot provide both :numberOfBackupsToRetain and :number_of_backups_to_retain' if attributes.key?(:'numberOfBackupsToRetain') && attributes.key?(:'number_of_backups_to_retain')

      self.number_of_backups_to_retain = attributes[:'number_of_backups_to_retain'] if attributes[:'number_of_backups_to_retain']

      self.backup_type = attributes[:'backupType'] if attributes[:'backupType']
      self.backup_type = "FULL" if backup_type.nil? && !attributes.key?(:'backupType') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :backupType and :backup_type' if attributes.key?(:'backupType') && attributes.key?(:'backup_type')

      self.backup_type = attributes[:'backup_type'] if attributes[:'backup_type']
      self.backup_type = "FULL" if backup_type.nil? && !attributes.key?(:'backupType') && !attributes.key?(:'backup_type') # rubocop:disable Style/StringLiterals
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        level_type_details == other.level_type_details &&
        display_name == other.display_name &&
        timezone == other.timezone &&
        schedule == other.schedule &&
        number_of_backups_to_retain == other.number_of_backups_to_retain &&
        backup_type == other.backup_type
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [level_type_details, display_name, timezone, schedule, number_of_backups_to_retain, backup_type].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
