# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20231107
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # The details of the create capacity request. This model serves as a base for different namespaces.
  class CapacityManagement::Models::OccCapacityRequestBaseDetails
    # **[Required]** The type of the resource against which the user wants to place a capacity request.
    # @return [String]
    attr_accessor :resource_type

    # **[Required]** The type of the workload (Generic/ROW).
    # @return [String]
    attr_accessor :workload_type

    # The WorkloadType from where capacity request are to be transferred.
    # @return [String]
    attr_accessor :source_workload_type

    # The incremental quantity of resources supplied as the provisioning is underway.
    # @return [Integer]
    attr_accessor :expected_handover_quantity

    # The date on which the latest increment to supplied quantity of resources was delivered.
    # @return [DateTime]
    attr_accessor :date_expected_handover

    # The actual handed over quantity of resources at the time of request resolution.
    # @return [Integer]
    attr_accessor :actual_handover_quantity

    # The date on which the actual handover quantity of resources is delivered.
    # @return [DateTime]
    attr_accessor :date_actual_handover

    # The availability domain of the resource which is to be transferred. Note that this is only required for Capacity Request Transfer requests.
    # @return [String]
    attr_accessor :availability_domain

    # A list containing details about occHandoverResourceBlocks which were handed over for the corresponding resource name.
    #
    # @return [Array<OCI::CapacityManagement::Models::AssociatedOccHandoverResourceBlock>]
    attr_accessor :associated_occ_handover_resource_block_list

    # **[Required]** The name of the COMPUTE server shape for which the request is made. Do not use CAPACITY_CONSTRAINT as the resource name.
    # @return [String]
    attr_accessor :resource_name

    # **[Required]** The number of compute server's with name <resourceName> required by the user.
    # @return [Integer]
    attr_accessor :demand_quantity

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'resource_type': :'resourceType',
        'workload_type': :'workloadType',
        'source_workload_type': :'sourceWorkloadType',
        'expected_handover_quantity': :'expectedHandoverQuantity',
        'date_expected_handover': :'dateExpectedHandover',
        'actual_handover_quantity': :'actualHandoverQuantity',
        'date_actual_handover': :'dateActualHandover',
        'availability_domain': :'availabilityDomain',
        'associated_occ_handover_resource_block_list': :'associatedOccHandoverResourceBlockList',
        'resource_name': :'resourceName',
        'demand_quantity': :'demandQuantity'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'resource_type': :'String',
        'workload_type': :'String',
        'source_workload_type': :'String',
        'expected_handover_quantity': :'Integer',
        'date_expected_handover': :'DateTime',
        'actual_handover_quantity': :'Integer',
        'date_actual_handover': :'DateTime',
        'availability_domain': :'String',
        'associated_occ_handover_resource_block_list': :'Array<OCI::CapacityManagement::Models::AssociatedOccHandoverResourceBlock>',
        'resource_name': :'String',
        'demand_quantity': :'Integer'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :resource_type The value to assign to the {#resource_type} property
    # @option attributes [String] :workload_type The value to assign to the {#workload_type} property
    # @option attributes [String] :source_workload_type The value to assign to the {#source_workload_type} property
    # @option attributes [Integer] :expected_handover_quantity The value to assign to the {#expected_handover_quantity} property
    # @option attributes [DateTime] :date_expected_handover The value to assign to the {#date_expected_handover} property
    # @option attributes [Integer] :actual_handover_quantity The value to assign to the {#actual_handover_quantity} property
    # @option attributes [DateTime] :date_actual_handover The value to assign to the {#date_actual_handover} property
    # @option attributes [String] :availability_domain The value to assign to the {#availability_domain} property
    # @option attributes [Array<OCI::CapacityManagement::Models::AssociatedOccHandoverResourceBlock>] :associated_occ_handover_resource_block_list The value to assign to the {#associated_occ_handover_resource_block_list} property
    # @option attributes [String] :resource_name The value to assign to the {#resource_name} property
    # @option attributes [Integer] :demand_quantity The value to assign to the {#demand_quantity} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

      raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

      self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

      self.workload_type = attributes[:'workloadType'] if attributes[:'workloadType']

      raise 'You cannot provide both :workloadType and :workload_type' if attributes.key?(:'workloadType') && attributes.key?(:'workload_type')

      self.workload_type = attributes[:'workload_type'] if attributes[:'workload_type']

      self.source_workload_type = attributes[:'sourceWorkloadType'] if attributes[:'sourceWorkloadType']

      raise 'You cannot provide both :sourceWorkloadType and :source_workload_type' if attributes.key?(:'sourceWorkloadType') && attributes.key?(:'source_workload_type')

      self.source_workload_type = attributes[:'source_workload_type'] if attributes[:'source_workload_type']

      self.expected_handover_quantity = attributes[:'expectedHandoverQuantity'] if attributes[:'expectedHandoverQuantity']

      raise 'You cannot provide both :expectedHandoverQuantity and :expected_handover_quantity' if attributes.key?(:'expectedHandoverQuantity') && attributes.key?(:'expected_handover_quantity')

      self.expected_handover_quantity = attributes[:'expected_handover_quantity'] if attributes[:'expected_handover_quantity']

      self.date_expected_handover = attributes[:'dateExpectedHandover'] if attributes[:'dateExpectedHandover']

      raise 'You cannot provide both :dateExpectedHandover and :date_expected_handover' if attributes.key?(:'dateExpectedHandover') && attributes.key?(:'date_expected_handover')

      self.date_expected_handover = attributes[:'date_expected_handover'] if attributes[:'date_expected_handover']

      self.actual_handover_quantity = attributes[:'actualHandoverQuantity'] if attributes[:'actualHandoverQuantity']

      raise 'You cannot provide both :actualHandoverQuantity and :actual_handover_quantity' if attributes.key?(:'actualHandoverQuantity') && attributes.key?(:'actual_handover_quantity')

      self.actual_handover_quantity = attributes[:'actual_handover_quantity'] if attributes[:'actual_handover_quantity']

      self.date_actual_handover = attributes[:'dateActualHandover'] if attributes[:'dateActualHandover']

      raise 'You cannot provide both :dateActualHandover and :date_actual_handover' if attributes.key?(:'dateActualHandover') && attributes.key?(:'date_actual_handover')

      self.date_actual_handover = attributes[:'date_actual_handover'] if attributes[:'date_actual_handover']

      self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

      raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

      self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

      self.associated_occ_handover_resource_block_list = attributes[:'associatedOccHandoverResourceBlockList'] if attributes[:'associatedOccHandoverResourceBlockList']

      raise 'You cannot provide both :associatedOccHandoverResourceBlockList and :associated_occ_handover_resource_block_list' if attributes.key?(:'associatedOccHandoverResourceBlockList') && attributes.key?(:'associated_occ_handover_resource_block_list')

      self.associated_occ_handover_resource_block_list = attributes[:'associated_occ_handover_resource_block_list'] if attributes[:'associated_occ_handover_resource_block_list']

      self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

      raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

      self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

      self.demand_quantity = attributes[:'demandQuantity'] if attributes[:'demandQuantity']

      raise 'You cannot provide both :demandQuantity and :demand_quantity' if attributes.key?(:'demandQuantity') && attributes.key?(:'demand_quantity')

      self.demand_quantity = attributes[:'demand_quantity'] if attributes[:'demand_quantity']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        resource_type == other.resource_type &&
        workload_type == other.workload_type &&
        source_workload_type == other.source_workload_type &&
        expected_handover_quantity == other.expected_handover_quantity &&
        date_expected_handover == other.date_expected_handover &&
        actual_handover_quantity == other.actual_handover_quantity &&
        date_actual_handover == other.date_actual_handover &&
        availability_domain == other.availability_domain &&
        associated_occ_handover_resource_block_list == other.associated_occ_handover_resource_block_list &&
        resource_name == other.resource_name &&
        demand_quantity == other.demand_quantity
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [resource_type, workload_type, source_workload_type, expected_handover_quantity, date_expected_handover, actual_handover_quantity, date_actual_handover, availability_domain, associated_occ_handover_resource_block_list, resource_name, demand_quantity].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
