# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20231107
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # A summary model containing information about various demand signal resource requests.
  #
  class CapacityManagement::Models::OccmDemandSignalItemSummary
    DEMAND_SIGNAL_NAMESPACE_ENUM = [
      DEMAND_SIGNAL_NAMESPACE_COMPUTE = 'COMPUTE'.freeze,
      DEMAND_SIGNAL_NAMESPACE_NETWORK = 'NETWORK'.freeze,
      DEMAND_SIGNAL_NAMESPACE_GPU = 'GPU'.freeze,
      DEMAND_SIGNAL_NAMESPACE_STORAGE = 'STORAGE'.freeze,
      DEMAND_SIGNAL_NAMESPACE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    REQUEST_TYPE_ENUM = [
      REQUEST_TYPE_DEMAND = 'DEMAND'.freeze,
      REQUEST_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The OCID of the demand signal resource request.
    #
    # @return [String]
    attr_accessor :id

    # **[Required]** The OCID of the tenancy from which the demand signal item was created.
    #
    # @return [String]
    attr_accessor :compartment_id

    # **[Required]** The OCID of the demand signal under which this item will be grouped.
    #
    # @return [String]
    attr_accessor :demand_signal_id

    # **[Required]** The name of the OCI service in consideration for demand signal submission. For example: COMPUTE, NETWORK, GPU etc.
    #
    # @return [String]
    attr_reader :demand_signal_namespace

    # **[Required]** The OCID of the corresponding demand signal catalog resource.
    #
    # @return [String]
    attr_accessor :demand_signal_catalog_resource_id

    # **[Required]** The type of request (DEMAND or RETURN) made against a particular demand signal item.
    #
    # @return [String]
    attr_reader :request_type

    # **[Required]** The name of the OCI resource that you want to request.
    #
    # @return [String]
    attr_accessor :resource_name

    # **[Required]** The name of region for which you want to request the OCI resource.
    #
    # @return [String]
    attr_accessor :region

    # The name of the availability domain for which you want to request the OCI resource.
    #
    # @return [String]
    attr_accessor :availability_domain

    # The ocid of the tenancy for which you want to request the OCI resource for. This is an optional parameter.
    #
    # @return [String]
    attr_accessor :target_compartment_id

    # **[Required]** The quantity of the resource that you want to demand from OCI or return to OCI.
    #
    # @return [Integer]
    attr_accessor :quantity

    # **[Required]** the date before which you would ideally like the OCI resource to be delivered to you.
    #
    # @return [DateTime]
    attr_accessor :time_needed_before

    # **[Required]** A map of various properties associated with the OCI resource.
    #
    # @return [Hash<String, String>]
    attr_accessor :resource_properties

    # This field will serve as notes section for you. You can use this section to convey a message to OCI regarding your resource request.
    #
    # NOTE: The previous value gets overwritten with the new one for this once updated.
    #
    # @return [String]
    attr_accessor :notes

    # **[Required]** The current lifecycle state of the demand signal item.
    #
    # @return [String]
    attr_accessor :lifecycle_state

    # Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
    # Example: `{\"bar-key\": \"value\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :freeform_tags

    # Defined tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :defined_tags

    # System tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :system_tags

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'compartment_id': :'compartmentId',
        'demand_signal_id': :'demandSignalId',
        'demand_signal_namespace': :'demandSignalNamespace',
        'demand_signal_catalog_resource_id': :'demandSignalCatalogResourceId',
        'request_type': :'requestType',
        'resource_name': :'resourceName',
        'region': :'region',
        'availability_domain': :'availabilityDomain',
        'target_compartment_id': :'targetCompartmentId',
        'quantity': :'quantity',
        'time_needed_before': :'timeNeededBefore',
        'resource_properties': :'resourceProperties',
        'notes': :'notes',
        'lifecycle_state': :'lifecycleState',
        'freeform_tags': :'freeformTags',
        'defined_tags': :'definedTags',
        'system_tags': :'systemTags'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'compartment_id': :'String',
        'demand_signal_id': :'String',
        'demand_signal_namespace': :'String',
        'demand_signal_catalog_resource_id': :'String',
        'request_type': :'String',
        'resource_name': :'String',
        'region': :'String',
        'availability_domain': :'String',
        'target_compartment_id': :'String',
        'quantity': :'Integer',
        'time_needed_before': :'DateTime',
        'resource_properties': :'Hash<String, String>',
        'notes': :'String',
        'lifecycle_state': :'String',
        'freeform_tags': :'Hash<String, String>',
        'defined_tags': :'Hash<String, Hash<String, Object>>',
        'system_tags': :'Hash<String, Hash<String, Object>>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [String] :demand_signal_id The value to assign to the {#demand_signal_id} property
    # @option attributes [String] :demand_signal_namespace The value to assign to the {#demand_signal_namespace} property
    # @option attributes [String] :demand_signal_catalog_resource_id The value to assign to the {#demand_signal_catalog_resource_id} property
    # @option attributes [String] :request_type The value to assign to the {#request_type} property
    # @option attributes [String] :resource_name The value to assign to the {#resource_name} property
    # @option attributes [String] :region The value to assign to the {#region} property
    # @option attributes [String] :availability_domain The value to assign to the {#availability_domain} property
    # @option attributes [String] :target_compartment_id The value to assign to the {#target_compartment_id} property
    # @option attributes [Integer] :quantity The value to assign to the {#quantity} property
    # @option attributes [DateTime] :time_needed_before The value to assign to the {#time_needed_before} property
    # @option attributes [Hash<String, String>] :resource_properties The value to assign to the {#resource_properties} property
    # @option attributes [String] :notes The value to assign to the {#notes} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [Hash<String, String>] :freeform_tags The value to assign to the {#freeform_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :defined_tags The value to assign to the {#defined_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :system_tags The value to assign to the {#system_tags} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.demand_signal_id = attributes[:'demandSignalId'] if attributes[:'demandSignalId']

      raise 'You cannot provide both :demandSignalId and :demand_signal_id' if attributes.key?(:'demandSignalId') && attributes.key?(:'demand_signal_id')

      self.demand_signal_id = attributes[:'demand_signal_id'] if attributes[:'demand_signal_id']

      self.demand_signal_namespace = attributes[:'demandSignalNamespace'] if attributes[:'demandSignalNamespace']

      raise 'You cannot provide both :demandSignalNamespace and :demand_signal_namespace' if attributes.key?(:'demandSignalNamespace') && attributes.key?(:'demand_signal_namespace')

      self.demand_signal_namespace = attributes[:'demand_signal_namespace'] if attributes[:'demand_signal_namespace']

      self.demand_signal_catalog_resource_id = attributes[:'demandSignalCatalogResourceId'] if attributes[:'demandSignalCatalogResourceId']

      raise 'You cannot provide both :demandSignalCatalogResourceId and :demand_signal_catalog_resource_id' if attributes.key?(:'demandSignalCatalogResourceId') && attributes.key?(:'demand_signal_catalog_resource_id')

      self.demand_signal_catalog_resource_id = attributes[:'demand_signal_catalog_resource_id'] if attributes[:'demand_signal_catalog_resource_id']

      self.request_type = attributes[:'requestType'] if attributes[:'requestType']

      raise 'You cannot provide both :requestType and :request_type' if attributes.key?(:'requestType') && attributes.key?(:'request_type')

      self.request_type = attributes[:'request_type'] if attributes[:'request_type']

      self.resource_name = attributes[:'resourceName'] if attributes[:'resourceName']

      raise 'You cannot provide both :resourceName and :resource_name' if attributes.key?(:'resourceName') && attributes.key?(:'resource_name')

      self.resource_name = attributes[:'resource_name'] if attributes[:'resource_name']

      self.region = attributes[:'region'] if attributes[:'region']

      self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

      raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

      self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

      self.target_compartment_id = attributes[:'targetCompartmentId'] if attributes[:'targetCompartmentId']

      raise 'You cannot provide both :targetCompartmentId and :target_compartment_id' if attributes.key?(:'targetCompartmentId') && attributes.key?(:'target_compartment_id')

      self.target_compartment_id = attributes[:'target_compartment_id'] if attributes[:'target_compartment_id']

      self.quantity = attributes[:'quantity'] if attributes[:'quantity']

      self.time_needed_before = attributes[:'timeNeededBefore'] if attributes[:'timeNeededBefore']

      raise 'You cannot provide both :timeNeededBefore and :time_needed_before' if attributes.key?(:'timeNeededBefore') && attributes.key?(:'time_needed_before')

      self.time_needed_before = attributes[:'time_needed_before'] if attributes[:'time_needed_before']

      self.resource_properties = attributes[:'resourceProperties'] if attributes[:'resourceProperties']

      raise 'You cannot provide both :resourceProperties and :resource_properties' if attributes.key?(:'resourceProperties') && attributes.key?(:'resource_properties')

      self.resource_properties = attributes[:'resource_properties'] if attributes[:'resource_properties']

      self.notes = attributes[:'notes'] if attributes[:'notes']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

      raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

      self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

      self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

      raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

      self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

      self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

      raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

      self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] demand_signal_namespace Object to be assigned
    def demand_signal_namespace=(demand_signal_namespace)
      # rubocop:disable Style/ConditionalAssignment
      if demand_signal_namespace && !DEMAND_SIGNAL_NAMESPACE_ENUM.include?(demand_signal_namespace)
        OCI.logger.debug("Unknown value for 'demand_signal_namespace' [" + demand_signal_namespace + "]. Mapping to 'DEMAND_SIGNAL_NAMESPACE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @demand_signal_namespace = DEMAND_SIGNAL_NAMESPACE_UNKNOWN_ENUM_VALUE
      else
        @demand_signal_namespace = demand_signal_namespace
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] request_type Object to be assigned
    def request_type=(request_type)
      # rubocop:disable Style/ConditionalAssignment
      if request_type && !REQUEST_TYPE_ENUM.include?(request_type)
        OCI.logger.debug("Unknown value for 'request_type' [" + request_type + "]. Mapping to 'REQUEST_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @request_type = REQUEST_TYPE_UNKNOWN_ENUM_VALUE
      else
        @request_type = request_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        compartment_id == other.compartment_id &&
        demand_signal_id == other.demand_signal_id &&
        demand_signal_namespace == other.demand_signal_namespace &&
        demand_signal_catalog_resource_id == other.demand_signal_catalog_resource_id &&
        request_type == other.request_type &&
        resource_name == other.resource_name &&
        region == other.region &&
        availability_domain == other.availability_domain &&
        target_compartment_id == other.target_compartment_id &&
        quantity == other.quantity &&
        time_needed_before == other.time_needed_before &&
        resource_properties == other.resource_properties &&
        notes == other.notes &&
        lifecycle_state == other.lifecycle_state &&
        freeform_tags == other.freeform_tags &&
        defined_tags == other.defined_tags &&
        system_tags == other.system_tags
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, compartment_id, demand_signal_id, demand_signal_namespace, demand_signal_catalog_resource_id, request_type, resource_name, region, availability_domain, target_compartment_id, quantity, time_needed_before, resource_properties, notes, lifecycle_state, freeform_tags, defined_tags, system_tags].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
