# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220509
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Describes association information for an Elastic IP address (IPv4).
  class CloudBridge::Models::InstanceNetworkInterfaceAssociation
    # The carrier IP address associated with the network interface.
    # @return [String]
    attr_accessor :carrier_ip

    # The customer-owned IP address associated with the network interface.
    # @return [String]
    attr_accessor :customer_owned_ip

    # The ID of the owner of the Elastic IP address.
    # @return [String]
    attr_accessor :ip_owner_key

    # The public DNS name.
    # @return [String]
    attr_accessor :public_dns_name

    # The public IP address or Elastic IP address bound to the network interface.
    # @return [String]
    attr_accessor :public_ip

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'carrier_ip': :'carrierIp',
        'customer_owned_ip': :'customerOwnedIp',
        'ip_owner_key': :'ipOwnerKey',
        'public_dns_name': :'publicDnsName',
        'public_ip': :'publicIp'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'carrier_ip': :'String',
        'customer_owned_ip': :'String',
        'ip_owner_key': :'String',
        'public_dns_name': :'String',
        'public_ip': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :carrier_ip The value to assign to the {#carrier_ip} property
    # @option attributes [String] :customer_owned_ip The value to assign to the {#customer_owned_ip} property
    # @option attributes [String] :ip_owner_key The value to assign to the {#ip_owner_key} property
    # @option attributes [String] :public_dns_name The value to assign to the {#public_dns_name} property
    # @option attributes [String] :public_ip The value to assign to the {#public_ip} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.carrier_ip = attributes[:'carrierIp'] if attributes[:'carrierIp']

      raise 'You cannot provide both :carrierIp and :carrier_ip' if attributes.key?(:'carrierIp') && attributes.key?(:'carrier_ip')

      self.carrier_ip = attributes[:'carrier_ip'] if attributes[:'carrier_ip']

      self.customer_owned_ip = attributes[:'customerOwnedIp'] if attributes[:'customerOwnedIp']

      raise 'You cannot provide both :customerOwnedIp and :customer_owned_ip' if attributes.key?(:'customerOwnedIp') && attributes.key?(:'customer_owned_ip')

      self.customer_owned_ip = attributes[:'customer_owned_ip'] if attributes[:'customer_owned_ip']

      self.ip_owner_key = attributes[:'ipOwnerKey'] if attributes[:'ipOwnerKey']

      raise 'You cannot provide both :ipOwnerKey and :ip_owner_key' if attributes.key?(:'ipOwnerKey') && attributes.key?(:'ip_owner_key')

      self.ip_owner_key = attributes[:'ip_owner_key'] if attributes[:'ip_owner_key']

      self.public_dns_name = attributes[:'publicDnsName'] if attributes[:'publicDnsName']

      raise 'You cannot provide both :publicDnsName and :public_dns_name' if attributes.key?(:'publicDnsName') && attributes.key?(:'public_dns_name')

      self.public_dns_name = attributes[:'public_dns_name'] if attributes[:'public_dns_name']

      self.public_ip = attributes[:'publicIp'] if attributes[:'publicIp']

      raise 'You cannot provide both :publicIp and :public_ip' if attributes.key?(:'publicIp') && attributes.key?(:'public_ip')

      self.public_ip = attributes[:'public_ip'] if attributes[:'public_ip']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        carrier_ip == other.carrier_ip &&
        customer_owned_ip == other.customer_owned_ip &&
        ip_owner_key == other.ip_owner_key &&
        public_dns_name == other.public_dns_name &&
        public_ip == other.public_ip
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [carrier_ip, customer_owned_ip, ip_owner_key, public_dns_name, public_ip].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
