# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20190101
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Retention setting details of the model.
  class DataScience::Models::RetentionSetting
    CUSTOMER_NOTIFICATION_TYPE_ENUM = [
      CUSTOMER_NOTIFICATION_TYPE_NONE = 'NONE'.freeze,
      CUSTOMER_NOTIFICATION_TYPE_ALL = 'ALL'.freeze,
      CUSTOMER_NOTIFICATION_TYPE_ON_FAILURE = 'ON_FAILURE'.freeze,
      CUSTOMER_NOTIFICATION_TYPE_ON_SUCCESS = 'ON_SUCCESS'.freeze,
      CUSTOMER_NOTIFICATION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** Number of days after which the model will be archived.
    # @return [Integer]
    attr_accessor :archive_after_days

    # Number of days after which the archived model will be deleted.
    # @return [Integer]
    attr_accessor :delete_after_days

    # Customer notification options on success/failure of archival, deletion events.
    # @return [String]
    attr_reader :customer_notification_type

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'archive_after_days': :'archiveAfterDays',
        'delete_after_days': :'deleteAfterDays',
        'customer_notification_type': :'customerNotificationType'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'archive_after_days': :'Integer',
        'delete_after_days': :'Integer',
        'customer_notification_type': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [Integer] :archive_after_days The value to assign to the {#archive_after_days} property
    # @option attributes [Integer] :delete_after_days The value to assign to the {#delete_after_days} property
    # @option attributes [String] :customer_notification_type The value to assign to the {#customer_notification_type} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.archive_after_days = attributes[:'archiveAfterDays'] if attributes[:'archiveAfterDays']

      raise 'You cannot provide both :archiveAfterDays and :archive_after_days' if attributes.key?(:'archiveAfterDays') && attributes.key?(:'archive_after_days')

      self.archive_after_days = attributes[:'archive_after_days'] if attributes[:'archive_after_days']

      self.delete_after_days = attributes[:'deleteAfterDays'] if attributes[:'deleteAfterDays']

      raise 'You cannot provide both :deleteAfterDays and :delete_after_days' if attributes.key?(:'deleteAfterDays') && attributes.key?(:'delete_after_days')

      self.delete_after_days = attributes[:'delete_after_days'] if attributes[:'delete_after_days']

      self.customer_notification_type = attributes[:'customerNotificationType'] if attributes[:'customerNotificationType']
      self.customer_notification_type = "NONE" if customer_notification_type.nil? && !attributes.key?(:'customerNotificationType') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :customerNotificationType and :customer_notification_type' if attributes.key?(:'customerNotificationType') && attributes.key?(:'customer_notification_type')

      self.customer_notification_type = attributes[:'customer_notification_type'] if attributes[:'customer_notification_type']
      self.customer_notification_type = "NONE" if customer_notification_type.nil? && !attributes.key?(:'customerNotificationType') && !attributes.key?(:'customer_notification_type') # rubocop:disable Style/StringLiterals
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] customer_notification_type Object to be assigned
    def customer_notification_type=(customer_notification_type)
      # rubocop:disable Style/ConditionalAssignment
      if customer_notification_type && !CUSTOMER_NOTIFICATION_TYPE_ENUM.include?(customer_notification_type)
        OCI.logger.debug("Unknown value for 'customer_notification_type' [" + customer_notification_type + "]. Mapping to 'CUSTOMER_NOTIFICATION_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @customer_notification_type = CUSTOMER_NOTIFICATION_TYPE_UNKNOWN_ENUM_VALUE
      else
        @customer_notification_type = customer_notification_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        archive_after_days == other.archive_after_days &&
        delete_after_days == other.delete_after_days &&
        customer_notification_type == other.customer_notification_type
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [archive_after_days, delete_after_days, customer_notification_type].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
