# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20160918
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # The properties that define Autonomous Container Databases Dataguard.
  #
  class Database::Models::AutonomousContainerDatabaseDataguard
    ROLE_ENUM = [
      ROLE_PRIMARY = 'PRIMARY'.freeze,
      ROLE_STANDBY = 'STANDBY'.freeze,
      ROLE_DISABLED_STANDBY = 'DISABLED_STANDBY'.freeze,
      ROLE_BACKUP_COPY = 'BACKUP_COPY'.freeze,
      ROLE_SNAPSHOT_STANDBY = 'SNAPSHOT_STANDBY'.freeze,
      ROLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    LIFECYCLE_STATE_ENUM = [
      LIFECYCLE_STATE_PROVISIONING = 'PROVISIONING'.freeze,
      LIFECYCLE_STATE_AVAILABLE = 'AVAILABLE'.freeze,
      LIFECYCLE_STATE_ROLE_CHANGE_IN_PROGRESS = 'ROLE_CHANGE_IN_PROGRESS'.freeze,
      LIFECYCLE_STATE_TERMINATING = 'TERMINATING'.freeze,
      LIFECYCLE_STATE_TERMINATED = 'TERMINATED'.freeze,
      LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
      LIFECYCLE_STATE_UNAVAILABLE = 'UNAVAILABLE'.freeze,
      LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
      LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    PROTECTION_MODE_ENUM = [
      PROTECTION_MODE_MAXIMUM_AVAILABILITY = 'MAXIMUM_AVAILABILITY'.freeze,
      PROTECTION_MODE_MAXIMUM_PERFORMANCE = 'MAXIMUM_PERFORMANCE'.freeze,
      PROTECTION_MODE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the Autonomous Container Database that has a relationship with the peer Autonomous Container Database. Used only by Autonomous Database on Dedicated Exadata Infrastructure.
    #
    # @return [String]
    attr_accessor :autonomous_container_database_id

    # **[Required]** The Data Guard role of the Autonomous Container Database or Autonomous Database, if Autonomous Data Guard is enabled.
    #
    # @return [String]
    attr_reader :role

    # **[Required]** The current state of Autonomous Data Guard.
    # @return [String]
    attr_reader :lifecycle_state

    # Additional information about the current lifecycleState, if available.
    #
    # @return [String]
    attr_accessor :lifecycle_details

    # The protection mode of this Autonomous Data Guard association. For more information, see
    # [Oracle Data Guard Protection Modes](http://docs.oracle.com/database/122/SBYDB/oracle-data-guard-protection-modes.htm#SBYDB02000)
    # in the Oracle Data Guard documentation.
    #
    # @return [String]
    attr_reader :protection_mode

    # The lag time for my preference based on data loss tolerance in seconds.
    # @return [Integer]
    attr_accessor :fast_start_fail_over_lag_limit_in_seconds

    # The lag time between updates to the primary Autonomous Container Database and application of the redo data on the standby Autonomous Container Database,
    # as computed by the reporting database.
    # Example: `9 seconds`
    #
    # @return [String]
    attr_accessor :apply_lag

    # The rate at which redo logs are synchronized between the associated Autonomous Container Databases.
    # Example: `180 Mb per second`
    #
    # @return [String]
    attr_accessor :apply_rate

    # Indicates whether Automatic Failover is enabled for Autonomous Container Database Dataguard Association
    #
    # @return [BOOLEAN]
    attr_accessor :is_automatic_failover_enabled

    # The approximate number of seconds of redo data not yet available on the standby Autonomous Container Database,
    # as computed by the reporting database.
    # Example: `7 seconds`
    #
    # @return [String]
    attr_accessor :transport_lag

    # The date and time of the last update to the apply lag, apply rate, and transport lag values.
    # @return [DateTime]
    attr_accessor :time_last_synced

    # The date and time the Autonomous DataGuard association was created.
    # @return [DateTime]
    attr_accessor :time_created

    # The date and time when the last role change action happened.
    # @return [DateTime]
    attr_accessor :time_last_role_changed

    # The domain of the Autonomous Container Database
    #
    # @return [String]
    attr_accessor :availability_domain

    # Timestamp when the lags were last calculated for a standby.
    # @return [DateTime]
    attr_accessor :time_lag_refreshed_on

    # Automatically selected by backend based on the protection mode.
    #
    # @return [String]
    attr_accessor :redo_transport_mode

    # Automatically selected by backend when observer is enabled.
    #
    # @return [String]
    attr_accessor :automatic_failover_target

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'autonomous_container_database_id': :'autonomousContainerDatabaseId',
        'role': :'role',
        'lifecycle_state': :'lifecycleState',
        'lifecycle_details': :'lifecycleDetails',
        'protection_mode': :'protectionMode',
        'fast_start_fail_over_lag_limit_in_seconds': :'fastStartFailOverLagLimitInSeconds',
        'apply_lag': :'applyLag',
        'apply_rate': :'applyRate',
        'is_automatic_failover_enabled': :'isAutomaticFailoverEnabled',
        'transport_lag': :'transportLag',
        'time_last_synced': :'timeLastSynced',
        'time_created': :'timeCreated',
        'time_last_role_changed': :'timeLastRoleChanged',
        'availability_domain': :'availabilityDomain',
        'time_lag_refreshed_on': :'timeLagRefreshedOn',
        'redo_transport_mode': :'redoTransportMode',
        'automatic_failover_target': :'automaticFailoverTarget'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'autonomous_container_database_id': :'String',
        'role': :'String',
        'lifecycle_state': :'String',
        'lifecycle_details': :'String',
        'protection_mode': :'String',
        'fast_start_fail_over_lag_limit_in_seconds': :'Integer',
        'apply_lag': :'String',
        'apply_rate': :'String',
        'is_automatic_failover_enabled': :'BOOLEAN',
        'transport_lag': :'String',
        'time_last_synced': :'DateTime',
        'time_created': :'DateTime',
        'time_last_role_changed': :'DateTime',
        'availability_domain': :'String',
        'time_lag_refreshed_on': :'DateTime',
        'redo_transport_mode': :'String',
        'automatic_failover_target': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :autonomous_container_database_id The value to assign to the {#autonomous_container_database_id} property
    # @option attributes [String] :role The value to assign to the {#role} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [String] :lifecycle_details The value to assign to the {#lifecycle_details} property
    # @option attributes [String] :protection_mode The value to assign to the {#protection_mode} property
    # @option attributes [Integer] :fast_start_fail_over_lag_limit_in_seconds The value to assign to the {#fast_start_fail_over_lag_limit_in_seconds} property
    # @option attributes [String] :apply_lag The value to assign to the {#apply_lag} property
    # @option attributes [String] :apply_rate The value to assign to the {#apply_rate} property
    # @option attributes [BOOLEAN] :is_automatic_failover_enabled The value to assign to the {#is_automatic_failover_enabled} property
    # @option attributes [String] :transport_lag The value to assign to the {#transport_lag} property
    # @option attributes [DateTime] :time_last_synced The value to assign to the {#time_last_synced} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_last_role_changed The value to assign to the {#time_last_role_changed} property
    # @option attributes [String] :availability_domain The value to assign to the {#availability_domain} property
    # @option attributes [DateTime] :time_lag_refreshed_on The value to assign to the {#time_lag_refreshed_on} property
    # @option attributes [String] :redo_transport_mode The value to assign to the {#redo_transport_mode} property
    # @option attributes [String] :automatic_failover_target The value to assign to the {#automatic_failover_target} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.autonomous_container_database_id = attributes[:'autonomousContainerDatabaseId'] if attributes[:'autonomousContainerDatabaseId']

      raise 'You cannot provide both :autonomousContainerDatabaseId and :autonomous_container_database_id' if attributes.key?(:'autonomousContainerDatabaseId') && attributes.key?(:'autonomous_container_database_id')

      self.autonomous_container_database_id = attributes[:'autonomous_container_database_id'] if attributes[:'autonomous_container_database_id']

      self.role = attributes[:'role'] if attributes[:'role']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

      raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

      self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

      self.protection_mode = attributes[:'protectionMode'] if attributes[:'protectionMode']

      raise 'You cannot provide both :protectionMode and :protection_mode' if attributes.key?(:'protectionMode') && attributes.key?(:'protection_mode')

      self.protection_mode = attributes[:'protection_mode'] if attributes[:'protection_mode']

      self.fast_start_fail_over_lag_limit_in_seconds = attributes[:'fastStartFailOverLagLimitInSeconds'] if attributes[:'fastStartFailOverLagLimitInSeconds']

      raise 'You cannot provide both :fastStartFailOverLagLimitInSeconds and :fast_start_fail_over_lag_limit_in_seconds' if attributes.key?(:'fastStartFailOverLagLimitInSeconds') && attributes.key?(:'fast_start_fail_over_lag_limit_in_seconds')

      self.fast_start_fail_over_lag_limit_in_seconds = attributes[:'fast_start_fail_over_lag_limit_in_seconds'] if attributes[:'fast_start_fail_over_lag_limit_in_seconds']

      self.apply_lag = attributes[:'applyLag'] if attributes[:'applyLag']

      raise 'You cannot provide both :applyLag and :apply_lag' if attributes.key?(:'applyLag') && attributes.key?(:'apply_lag')

      self.apply_lag = attributes[:'apply_lag'] if attributes[:'apply_lag']

      self.apply_rate = attributes[:'applyRate'] if attributes[:'applyRate']

      raise 'You cannot provide both :applyRate and :apply_rate' if attributes.key?(:'applyRate') && attributes.key?(:'apply_rate')

      self.apply_rate = attributes[:'apply_rate'] if attributes[:'apply_rate']

      self.is_automatic_failover_enabled = attributes[:'isAutomaticFailoverEnabled'] unless attributes[:'isAutomaticFailoverEnabled'].nil?

      raise 'You cannot provide both :isAutomaticFailoverEnabled and :is_automatic_failover_enabled' if attributes.key?(:'isAutomaticFailoverEnabled') && attributes.key?(:'is_automatic_failover_enabled')

      self.is_automatic_failover_enabled = attributes[:'is_automatic_failover_enabled'] unless attributes[:'is_automatic_failover_enabled'].nil?

      self.transport_lag = attributes[:'transportLag'] if attributes[:'transportLag']

      raise 'You cannot provide both :transportLag and :transport_lag' if attributes.key?(:'transportLag') && attributes.key?(:'transport_lag')

      self.transport_lag = attributes[:'transport_lag'] if attributes[:'transport_lag']

      self.time_last_synced = attributes[:'timeLastSynced'] if attributes[:'timeLastSynced']

      raise 'You cannot provide both :timeLastSynced and :time_last_synced' if attributes.key?(:'timeLastSynced') && attributes.key?(:'time_last_synced')

      self.time_last_synced = attributes[:'time_last_synced'] if attributes[:'time_last_synced']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_last_role_changed = attributes[:'timeLastRoleChanged'] if attributes[:'timeLastRoleChanged']

      raise 'You cannot provide both :timeLastRoleChanged and :time_last_role_changed' if attributes.key?(:'timeLastRoleChanged') && attributes.key?(:'time_last_role_changed')

      self.time_last_role_changed = attributes[:'time_last_role_changed'] if attributes[:'time_last_role_changed']

      self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

      raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

      self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

      self.time_lag_refreshed_on = attributes[:'timeLagRefreshedOn'] if attributes[:'timeLagRefreshedOn']

      raise 'You cannot provide both :timeLagRefreshedOn and :time_lag_refreshed_on' if attributes.key?(:'timeLagRefreshedOn') && attributes.key?(:'time_lag_refreshed_on')

      self.time_lag_refreshed_on = attributes[:'time_lag_refreshed_on'] if attributes[:'time_lag_refreshed_on']

      self.redo_transport_mode = attributes[:'redoTransportMode'] if attributes[:'redoTransportMode']

      raise 'You cannot provide both :redoTransportMode and :redo_transport_mode' if attributes.key?(:'redoTransportMode') && attributes.key?(:'redo_transport_mode')

      self.redo_transport_mode = attributes[:'redo_transport_mode'] if attributes[:'redo_transport_mode']

      self.automatic_failover_target = attributes[:'automaticFailoverTarget'] if attributes[:'automaticFailoverTarget']

      raise 'You cannot provide both :automaticFailoverTarget and :automatic_failover_target' if attributes.key?(:'automaticFailoverTarget') && attributes.key?(:'automatic_failover_target')

      self.automatic_failover_target = attributes[:'automatic_failover_target'] if attributes[:'automatic_failover_target']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] role Object to be assigned
    def role=(role)
      # rubocop:disable Style/ConditionalAssignment
      if role && !ROLE_ENUM.include?(role)
        OCI.logger.debug("Unknown value for 'role' [" + role + "]. Mapping to 'ROLE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @role = ROLE_UNKNOWN_ENUM_VALUE
      else
        @role = role
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_state Object to be assigned
    def lifecycle_state=(lifecycle_state)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_state && !LIFECYCLE_STATE_ENUM.include?(lifecycle_state)
        OCI.logger.debug("Unknown value for 'lifecycle_state' [" + lifecycle_state + "]. Mapping to 'LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_state = LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_state = lifecycle_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] protection_mode Object to be assigned
    def protection_mode=(protection_mode)
      # rubocop:disable Style/ConditionalAssignment
      if protection_mode && !PROTECTION_MODE_ENUM.include?(protection_mode)
        OCI.logger.debug("Unknown value for 'protection_mode' [" + protection_mode + "]. Mapping to 'PROTECTION_MODE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @protection_mode = PROTECTION_MODE_UNKNOWN_ENUM_VALUE
      else
        @protection_mode = protection_mode
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        autonomous_container_database_id == other.autonomous_container_database_id &&
        role == other.role &&
        lifecycle_state == other.lifecycle_state &&
        lifecycle_details == other.lifecycle_details &&
        protection_mode == other.protection_mode &&
        fast_start_fail_over_lag_limit_in_seconds == other.fast_start_fail_over_lag_limit_in_seconds &&
        apply_lag == other.apply_lag &&
        apply_rate == other.apply_rate &&
        is_automatic_failover_enabled == other.is_automatic_failover_enabled &&
        transport_lag == other.transport_lag &&
        time_last_synced == other.time_last_synced &&
        time_created == other.time_created &&
        time_last_role_changed == other.time_last_role_changed &&
        availability_domain == other.availability_domain &&
        time_lag_refreshed_on == other.time_lag_refreshed_on &&
        redo_transport_mode == other.redo_transport_mode &&
        automatic_failover_target == other.automatic_failover_target
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [autonomous_container_database_id, role, lifecycle_state, lifecycle_details, protection_mode, fast_start_fail_over_lag_limit_in_seconds, apply_lag, apply_rate, is_automatic_failover_enabled, transport_lag, time_last_synced, time_created, time_last_role_changed, availability_domain, time_lag_refreshed_on, redo_transport_mode, automatic_failover_target].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
