# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20160918
require 'date'
require_relative 'autonomous_database_encryption_key_details'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Details for AWS encryption key.
  class Database::Models::AwsKeyDetails < Database::Models::AutonomousDatabaseEncryptionKeyDetails
    # **[Required]** AWS key service endpoint URI
    # @return [String]
    attr_accessor :service_endpoint_uri

    # **[Required]** AWS key ARN
    # @return [String]
    attr_accessor :key_arn

    # AWS ARN role
    # @return [String]
    attr_accessor :arn_role

    # AWS external ID
    # @return [String]
    attr_accessor :external_id

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'provider': :'provider',
        'service_endpoint_uri': :'serviceEndpointUri',
        'key_arn': :'keyArn',
        'arn_role': :'arnRole',
        'external_id': :'externalId'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'provider': :'String',
        'service_endpoint_uri': :'String',
        'key_arn': :'String',
        'arn_role': :'String',
        'external_id': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :service_endpoint_uri The value to assign to the {#service_endpoint_uri} property
    # @option attributes [String] :key_arn The value to assign to the {#key_arn} property
    # @option attributes [String] :arn_role The value to assign to the {#arn_role} property
    # @option attributes [String] :external_id The value to assign to the {#external_id} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      attributes['provider'] = 'AWS'

      super(attributes)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.service_endpoint_uri = attributes[:'serviceEndpointUri'] if attributes[:'serviceEndpointUri']

      raise 'You cannot provide both :serviceEndpointUri and :service_endpoint_uri' if attributes.key?(:'serviceEndpointUri') && attributes.key?(:'service_endpoint_uri')

      self.service_endpoint_uri = attributes[:'service_endpoint_uri'] if attributes[:'service_endpoint_uri']

      self.key_arn = attributes[:'keyArn'] if attributes[:'keyArn']

      raise 'You cannot provide both :keyArn and :key_arn' if attributes.key?(:'keyArn') && attributes.key?(:'key_arn')

      self.key_arn = attributes[:'key_arn'] if attributes[:'key_arn']

      self.arn_role = attributes[:'arnRole'] if attributes[:'arnRole']

      raise 'You cannot provide both :arnRole and :arn_role' if attributes.key?(:'arnRole') && attributes.key?(:'arn_role')

      self.arn_role = attributes[:'arn_role'] if attributes[:'arn_role']

      self.external_id = attributes[:'externalId'] if attributes[:'externalId']

      raise 'You cannot provide both :externalId and :external_id' if attributes.key?(:'externalId') && attributes.key?(:'external_id')

      self.external_id = attributes[:'external_id'] if attributes[:'external_id']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        provider == other.provider &&
        service_endpoint_uri == other.service_endpoint_uri &&
        key_arn == other.key_arn &&
        arn_role == other.arn_role &&
        external_id == other.external_id
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [provider, service_endpoint_uri, key_arn, arn_role, external_id].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
