# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20160918
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Details of an execution action.
  #
  class Database::Models::ExecutionActionSummary
    LIFECYCLE_STATE_ENUM = [
      LIFECYCLE_STATE_SCHEDULED = 'SCHEDULED'.freeze,
      LIFECYCLE_STATE_IN_PROGRESS = 'IN_PROGRESS'.freeze,
      LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
      LIFECYCLE_STATE_CANCELED = 'CANCELED'.freeze,
      LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
      LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
      LIFECYCLE_STATE_SUCCEEDED = 'SUCCEEDED'.freeze,
      LIFECYCLE_STATE_PARTIAL_SUCCESS = 'PARTIAL_SUCCESS'.freeze,
      LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    LIFECYCLE_SUBSTATE_ENUM = [
      LIFECYCLE_SUBSTATE_DURATION_EXCEEDED = 'DURATION_EXCEEDED'.freeze,
      LIFECYCLE_SUBSTATE_MAINTENANCE_IN_PROGRESS = 'MAINTENANCE_IN_PROGRESS'.freeze,
      LIFECYCLE_SUBSTATE_WAITING = 'WAITING'.freeze,
      LIFECYCLE_SUBSTATE_RESCHEDULED = 'RESCHEDULED'.freeze,
      LIFECYCLE_SUBSTATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    ACTION_TYPE_ENUM = [
      ACTION_TYPE_DB_SERVER_FULL_SOFTWARE_UPDATE = 'DB_SERVER_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_STORAGE_SERVER_FULL_SOFTWARE_UPDATE = 'STORAGE_SERVER_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_NETWORK_SWITCH_FULL_SOFTWARE_UPDATE = 'NETWORK_SWITCH_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the execution action.
    # @return [String]
    attr_accessor :id

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the execution window resource the execution action belongs to.
    # @return [String]
    attr_accessor :execution_window_id

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment.
    # @return [String]
    attr_accessor :compartment_id

    # **[Required]** The user-friendly name for the execution action. The name does not need to be unique.
    # @return [String]
    attr_accessor :display_name

    # Description of the execution action.
    # @return [String]
    attr_accessor :description

    # **[Required]** The current state of the execution action. Valid states are SCHEDULED, IN_PROGRESS, FAILED, CANCELED,
    # UPDATING, DELETED, SUCCEEDED and PARTIAL_SUCCESS.
    #
    # @return [String]
    attr_reader :lifecycle_state

    # The current sub-state of the execution action. Valid states are DURATION_EXCEEDED, MAINTENANCE_IN_PROGRESS and WAITING.
    #
    # @return [String]
    attr_reader :lifecycle_substate

    # Additional information about the current lifecycle state.
    # @return [String]
    attr_accessor :lifecycle_details

    # The date and time the execution action was created.
    # @return [DateTime]
    attr_accessor :time_created

    # The last date and time that the execution action was updated.
    # @return [DateTime]
    attr_accessor :time_updated

    # The estimated time of the execution action in minutes.
    # @return [Integer]
    attr_accessor :estimated_time_in_mins

    # The total time taken by corresponding resource activity in minutes.
    # @return [Integer]
    attr_accessor :total_time_taken_in_mins

    # The priority order of the execution action.
    # @return [Integer]
    attr_accessor :execution_action_order

    # **[Required]** The action type of the execution action being performed
    # @return [String]
    attr_reader :action_type

    # **[Required]** Map<ParamName, ParamValue> where a key value pair describes the specific action parameter.
    # Example: `{\"count\": \"3\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :action_params

    # List of action members of this execution action.
    # @return [Array<OCI::Database::Models::ExecutionActionMember>]
    attr_accessor :action_members

    # Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
    # For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
    #
    # Example: `{\"Department\": \"Finance\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :freeform_tags

    # Defined tags for this resource. Each key is predefined and scoped to a namespace.
    # For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :defined_tags

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'execution_window_id': :'executionWindowId',
        'compartment_id': :'compartmentId',
        'display_name': :'displayName',
        'description': :'description',
        'lifecycle_state': :'lifecycleState',
        'lifecycle_substate': :'lifecycleSubstate',
        'lifecycle_details': :'lifecycleDetails',
        'time_created': :'timeCreated',
        'time_updated': :'timeUpdated',
        'estimated_time_in_mins': :'estimatedTimeInMins',
        'total_time_taken_in_mins': :'totalTimeTakenInMins',
        'execution_action_order': :'executionActionOrder',
        'action_type': :'actionType',
        'action_params': :'actionParams',
        'action_members': :'actionMembers',
        'freeform_tags': :'freeformTags',
        'defined_tags': :'definedTags'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'execution_window_id': :'String',
        'compartment_id': :'String',
        'display_name': :'String',
        'description': :'String',
        'lifecycle_state': :'String',
        'lifecycle_substate': :'String',
        'lifecycle_details': :'String',
        'time_created': :'DateTime',
        'time_updated': :'DateTime',
        'estimated_time_in_mins': :'Integer',
        'total_time_taken_in_mins': :'Integer',
        'execution_action_order': :'Integer',
        'action_type': :'String',
        'action_params': :'Hash<String, String>',
        'action_members': :'Array<OCI::Database::Models::ExecutionActionMember>',
        'freeform_tags': :'Hash<String, String>',
        'defined_tags': :'Hash<String, Hash<String, Object>>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :execution_window_id The value to assign to the {#execution_window_id} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :description The value to assign to the {#description} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [String] :lifecycle_substate The value to assign to the {#lifecycle_substate} property
    # @option attributes [String] :lifecycle_details The value to assign to the {#lifecycle_details} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_updated The value to assign to the {#time_updated} property
    # @option attributes [Integer] :estimated_time_in_mins The value to assign to the {#estimated_time_in_mins} property
    # @option attributes [Integer] :total_time_taken_in_mins The value to assign to the {#total_time_taken_in_mins} property
    # @option attributes [Integer] :execution_action_order The value to assign to the {#execution_action_order} property
    # @option attributes [String] :action_type The value to assign to the {#action_type} property
    # @option attributes [Hash<String, String>] :action_params The value to assign to the {#action_params} property
    # @option attributes [Array<OCI::Database::Models::ExecutionActionMember>] :action_members The value to assign to the {#action_members} property
    # @option attributes [Hash<String, String>] :freeform_tags The value to assign to the {#freeform_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :defined_tags The value to assign to the {#defined_tags} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.execution_window_id = attributes[:'executionWindowId'] if attributes[:'executionWindowId']

      raise 'You cannot provide both :executionWindowId and :execution_window_id' if attributes.key?(:'executionWindowId') && attributes.key?(:'execution_window_id')

      self.execution_window_id = attributes[:'execution_window_id'] if attributes[:'execution_window_id']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.description = attributes[:'description'] if attributes[:'description']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.lifecycle_substate = attributes[:'lifecycleSubstate'] if attributes[:'lifecycleSubstate']

      raise 'You cannot provide both :lifecycleSubstate and :lifecycle_substate' if attributes.key?(:'lifecycleSubstate') && attributes.key?(:'lifecycle_substate')

      self.lifecycle_substate = attributes[:'lifecycle_substate'] if attributes[:'lifecycle_substate']

      self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

      raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

      self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

      raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

      self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

      self.estimated_time_in_mins = attributes[:'estimatedTimeInMins'] if attributes[:'estimatedTimeInMins']

      raise 'You cannot provide both :estimatedTimeInMins and :estimated_time_in_mins' if attributes.key?(:'estimatedTimeInMins') && attributes.key?(:'estimated_time_in_mins')

      self.estimated_time_in_mins = attributes[:'estimated_time_in_mins'] if attributes[:'estimated_time_in_mins']

      self.total_time_taken_in_mins = attributes[:'totalTimeTakenInMins'] if attributes[:'totalTimeTakenInMins']

      raise 'You cannot provide both :totalTimeTakenInMins and :total_time_taken_in_mins' if attributes.key?(:'totalTimeTakenInMins') && attributes.key?(:'total_time_taken_in_mins')

      self.total_time_taken_in_mins = attributes[:'total_time_taken_in_mins'] if attributes[:'total_time_taken_in_mins']

      self.execution_action_order = attributes[:'executionActionOrder'] if attributes[:'executionActionOrder']

      raise 'You cannot provide both :executionActionOrder and :execution_action_order' if attributes.key?(:'executionActionOrder') && attributes.key?(:'execution_action_order')

      self.execution_action_order = attributes[:'execution_action_order'] if attributes[:'execution_action_order']

      self.action_type = attributes[:'actionType'] if attributes[:'actionType']

      raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type')

      self.action_type = attributes[:'action_type'] if attributes[:'action_type']

      self.action_params = attributes[:'actionParams'] if attributes[:'actionParams']

      raise 'You cannot provide both :actionParams and :action_params' if attributes.key?(:'actionParams') && attributes.key?(:'action_params')

      self.action_params = attributes[:'action_params'] if attributes[:'action_params']

      self.action_members = attributes[:'actionMembers'] if attributes[:'actionMembers']

      raise 'You cannot provide both :actionMembers and :action_members' if attributes.key?(:'actionMembers') && attributes.key?(:'action_members')

      self.action_members = attributes[:'action_members'] if attributes[:'action_members']

      self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

      raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

      self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

      self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

      raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

      self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_state Object to be assigned
    def lifecycle_state=(lifecycle_state)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_state && !LIFECYCLE_STATE_ENUM.include?(lifecycle_state)
        OCI.logger.debug("Unknown value for 'lifecycle_state' [" + lifecycle_state + "]. Mapping to 'LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_state = LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_state = lifecycle_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_substate Object to be assigned
    def lifecycle_substate=(lifecycle_substate)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_substate && !LIFECYCLE_SUBSTATE_ENUM.include?(lifecycle_substate)
        OCI.logger.debug("Unknown value for 'lifecycle_substate' [" + lifecycle_substate + "]. Mapping to 'LIFECYCLE_SUBSTATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_substate = LIFECYCLE_SUBSTATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_substate = lifecycle_substate
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] action_type Object to be assigned
    def action_type=(action_type)
      # rubocop:disable Style/ConditionalAssignment
      if action_type && !ACTION_TYPE_ENUM.include?(action_type)
        OCI.logger.debug("Unknown value for 'action_type' [" + action_type + "]. Mapping to 'ACTION_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @action_type = ACTION_TYPE_UNKNOWN_ENUM_VALUE
      else
        @action_type = action_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        execution_window_id == other.execution_window_id &&
        compartment_id == other.compartment_id &&
        display_name == other.display_name &&
        description == other.description &&
        lifecycle_state == other.lifecycle_state &&
        lifecycle_substate == other.lifecycle_substate &&
        lifecycle_details == other.lifecycle_details &&
        time_created == other.time_created &&
        time_updated == other.time_updated &&
        estimated_time_in_mins == other.estimated_time_in_mins &&
        total_time_taken_in_mins == other.total_time_taken_in_mins &&
        execution_action_order == other.execution_action_order &&
        action_type == other.action_type &&
        action_params == other.action_params &&
        action_members == other.action_members &&
        freeform_tags == other.freeform_tags &&
        defined_tags == other.defined_tags
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, execution_window_id, compartment_id, display_name, description, lifecycle_state, lifecycle_substate, lifecycle_details, time_created, time_updated, estimated_time_in_mins, total_time_taken_in_mins, execution_action_order, action_type, action_params, action_members, freeform_tags, defined_tags].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
