# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20160918
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Details of the scheduled action that is used in getRecommendedScheduledActions.
  #
  class Database::Models::RecommendedScheduledActionSummary
    ACTION_TYPE_ENUM = [
      ACTION_TYPE_DB_SERVER_FULL_SOFTWARE_UPDATE = 'DB_SERVER_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_STORAGE_SERVER_FULL_SOFTWARE_UPDATE = 'STORAGE_SERVER_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_NETWORK_SWITCH_FULL_SOFTWARE_UPDATE = 'NETWORK_SWITCH_FULL_SOFTWARE_UPDATE'.freeze,
      ACTION_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The order of the scheduled action.
    # @return [Integer]
    attr_accessor :action_order

    # **[Required]** The type of the scheduled action being performed
    # @return [String]
    attr_reader :action_type

    # Description of the scheduled action being performed, i.e. apply full update to DB Servers 1,2,3,4.
    # @return [String]
    attr_accessor :display_name

    # **[Required]** The id of the scheduling window this scheduled action belongs to.
    # @return [String]
    attr_accessor :scheduling_window_id

    # The estimated patching time in minutes for the entire scheduled action.
    # @return [Integer]
    attr_accessor :estimated_time_in_mins

    # The list of action members in a scheduled action.
    # @return [Array<OCI::Database::Models::ActionMember>]
    attr_accessor :action_members

    # Map<ParamName, ParamValue> where a key value pair describes the specific action parameter.
    # Example: `{\"count\": \"3\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :action_params

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'action_order': :'actionOrder',
        'action_type': :'actionType',
        'display_name': :'displayName',
        'scheduling_window_id': :'schedulingWindowId',
        'estimated_time_in_mins': :'estimatedTimeInMins',
        'action_members': :'actionMembers',
        'action_params': :'actionParams'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'action_order': :'Integer',
        'action_type': :'String',
        'display_name': :'String',
        'scheduling_window_id': :'String',
        'estimated_time_in_mins': :'Integer',
        'action_members': :'Array<OCI::Database::Models::ActionMember>',
        'action_params': :'Hash<String, String>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [Integer] :action_order The value to assign to the {#action_order} property
    # @option attributes [String] :action_type The value to assign to the {#action_type} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :scheduling_window_id The value to assign to the {#scheduling_window_id} property
    # @option attributes [Integer] :estimated_time_in_mins The value to assign to the {#estimated_time_in_mins} property
    # @option attributes [Array<OCI::Database::Models::ActionMember>] :action_members The value to assign to the {#action_members} property
    # @option attributes [Hash<String, String>] :action_params The value to assign to the {#action_params} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.action_order = attributes[:'actionOrder'] if attributes[:'actionOrder']

      raise 'You cannot provide both :actionOrder and :action_order' if attributes.key?(:'actionOrder') && attributes.key?(:'action_order')

      self.action_order = attributes[:'action_order'] if attributes[:'action_order']

      self.action_type = attributes[:'actionType'] if attributes[:'actionType']
      self.action_type = "DB_SERVER_FULL_SOFTWARE_UPDATE" if action_type.nil? && !attributes.key?(:'actionType') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :actionType and :action_type' if attributes.key?(:'actionType') && attributes.key?(:'action_type')

      self.action_type = attributes[:'action_type'] if attributes[:'action_type']
      self.action_type = "DB_SERVER_FULL_SOFTWARE_UPDATE" if action_type.nil? && !attributes.key?(:'actionType') && !attributes.key?(:'action_type') # rubocop:disable Style/StringLiterals

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.scheduling_window_id = attributes[:'schedulingWindowId'] if attributes[:'schedulingWindowId']

      raise 'You cannot provide both :schedulingWindowId and :scheduling_window_id' if attributes.key?(:'schedulingWindowId') && attributes.key?(:'scheduling_window_id')

      self.scheduling_window_id = attributes[:'scheduling_window_id'] if attributes[:'scheduling_window_id']

      self.estimated_time_in_mins = attributes[:'estimatedTimeInMins'] if attributes[:'estimatedTimeInMins']

      raise 'You cannot provide both :estimatedTimeInMins and :estimated_time_in_mins' if attributes.key?(:'estimatedTimeInMins') && attributes.key?(:'estimated_time_in_mins')

      self.estimated_time_in_mins = attributes[:'estimated_time_in_mins'] if attributes[:'estimated_time_in_mins']

      self.action_members = attributes[:'actionMembers'] if attributes[:'actionMembers']

      raise 'You cannot provide both :actionMembers and :action_members' if attributes.key?(:'actionMembers') && attributes.key?(:'action_members')

      self.action_members = attributes[:'action_members'] if attributes[:'action_members']

      self.action_params = attributes[:'actionParams'] if attributes[:'actionParams']

      raise 'You cannot provide both :actionParams and :action_params' if attributes.key?(:'actionParams') && attributes.key?(:'action_params')

      self.action_params = attributes[:'action_params'] if attributes[:'action_params']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] action_type Object to be assigned
    def action_type=(action_type)
      # rubocop:disable Style/ConditionalAssignment
      if action_type && !ACTION_TYPE_ENUM.include?(action_type)
        OCI.logger.debug("Unknown value for 'action_type' [" + action_type + "]. Mapping to 'ACTION_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @action_type = ACTION_TYPE_UNKNOWN_ENUM_VALUE
      else
        @action_type = action_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        action_order == other.action_order &&
        action_type == other.action_type &&
        display_name == other.display_name &&
        scheduling_window_id == other.scheduling_window_id &&
        estimated_time_in_mins == other.estimated_time_in_mins &&
        action_members == other.action_members &&
        action_params == other.action_params
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [action_order, action_type, display_name, scheduling_window_id, estimated_time_in_mins, action_members, action_params].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
