# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20230801
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Summary of Delegated Resource Access Request status changes.
  class DelegateAccessControl::Models::DelegatedResourceAccessRequestHistorySummary
    REQUEST_STATUS_ENUM = [
      REQUEST_STATUS_CREATED = 'CREATED'.freeze,
      REQUEST_STATUS_APPROVAL_WAITING = 'APPROVAL_WAITING'.freeze,
      REQUEST_STATUS_OPERATOR_ASSIGNMENT_WAITING = 'OPERATOR_ASSIGNMENT_WAITING'.freeze,
      REQUEST_STATUS_PREAPPROVED = 'PREAPPROVED'.freeze,
      REQUEST_STATUS_APPROVED = 'APPROVED'.freeze,
      REQUEST_STATUS_APPROVED_FOR_FUTURE = 'APPROVED_FOR_FUTURE'.freeze,
      REQUEST_STATUS_REJECTED = 'REJECTED'.freeze,
      REQUEST_STATUS_DEPLOYED = 'DEPLOYED'.freeze,
      REQUEST_STATUS_DEPLOY_FAILED = 'DEPLOY_FAILED'.freeze,
      REQUEST_STATUS_UNDEPLOYED = 'UNDEPLOYED'.freeze,
      REQUEST_STATUS_UNDEPLOY_FAILED = 'UNDEPLOY_FAILED'.freeze,
      REQUEST_STATUS_CLOSE_FAILED = 'CLOSE_FAILED'.freeze,
      REQUEST_STATUS_REVOKE_FAILED = 'REVOKE_FAILED'.freeze,
      REQUEST_STATUS_EXPIRY_FAILED = 'EXPIRY_FAILED'.freeze,
      REQUEST_STATUS_REVOKING = 'REVOKING'.freeze,
      REQUEST_STATUS_REVOKED = 'REVOKED'.freeze,
      REQUEST_STATUS_EXTENDING = 'EXTENDING'.freeze,
      REQUEST_STATUS_EXTENDED = 'EXTENDED'.freeze,
      REQUEST_STATUS_EXTENSION_REJECTED = 'EXTENSION_REJECTED'.freeze,
      REQUEST_STATUS_EXTENSION_FAILED = 'EXTENSION_FAILED'.freeze,
      REQUEST_STATUS_COMPLETING = 'COMPLETING'.freeze,
      REQUEST_STATUS_COMPLETED = 'COMPLETED'.freeze,
      REQUEST_STATUS_EXPIRED = 'EXPIRED'.freeze,
      REQUEST_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # The current lifecycle state of the Delegated Resource Access Request.
    # @return [String]
    attr_accessor :lifecycle_state

    # The current status of the Delegated Resource Access Request.
    # @return [String]
    attr_reader :request_status

    # ID of user who modified the Delegated Resource Access Request. For operator, this field is \"Operator\".
    # @return [String]
    attr_accessor :user_id

    # Comment about the status change.
    # @return [String]
    attr_accessor :comment

    # Time when the respective action happened in [RFC 3339](https://tools.ietf.org/html/rfc3339)timestamp format, e.g. '2020-05-22T21:10:29.600Z'.
    #
    # @return [DateTime]
    attr_accessor :timestamp

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'lifecycle_state': :'lifecycleState',
        'request_status': :'requestStatus',
        'user_id': :'userId',
        'comment': :'comment',
        'timestamp': :'timestamp'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'lifecycle_state': :'String',
        'request_status': :'String',
        'user_id': :'String',
        'comment': :'String',
        'timestamp': :'DateTime'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [String] :request_status The value to assign to the {#request_status} property
    # @option attributes [String] :user_id The value to assign to the {#user_id} property
    # @option attributes [String] :comment The value to assign to the {#comment} property
    # @option attributes [DateTime] :timestamp The value to assign to the {#timestamp} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.request_status = attributes[:'requestStatus'] if attributes[:'requestStatus']

      raise 'You cannot provide both :requestStatus and :request_status' if attributes.key?(:'requestStatus') && attributes.key?(:'request_status')

      self.request_status = attributes[:'request_status'] if attributes[:'request_status']

      self.user_id = attributes[:'userId'] if attributes[:'userId']

      raise 'You cannot provide both :userId and :user_id' if attributes.key?(:'userId') && attributes.key?(:'user_id')

      self.user_id = attributes[:'user_id'] if attributes[:'user_id']

      self.comment = attributes[:'comment'] if attributes[:'comment']

      self.timestamp = attributes[:'timestamp'] if attributes[:'timestamp']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] request_status Object to be assigned
    def request_status=(request_status)
      # rubocop:disable Style/ConditionalAssignment
      if request_status && !REQUEST_STATUS_ENUM.include?(request_status)
        OCI.logger.debug("Unknown value for 'request_status' [" + request_status + "]. Mapping to 'REQUEST_STATUS_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @request_status = REQUEST_STATUS_UNKNOWN_ENUM_VALUE
      else
        @request_status = request_status
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        lifecycle_state == other.lifecycle_state &&
        request_status == other.request_status &&
        user_id == other.user_id &&
        comment == other.comment &&
        timestamp == other.timestamp
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [lifecycle_state, request_status, user_id, comment, timestamp].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
