# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20210630
require 'date'
require_relative 'pull_request_activity_summary'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # activity describing commit updates to a pull request
  class Devops::Models::CommitActivitySummary < Devops::Models::PullRequestActivitySummary
    # **[Required]** list of commits added to a PR source branch after git push
    # @return [Array<OCI::Devops::Models::RepositoryCommit>]
    attr_accessor :commits_added

    # **[Required]** list of commits removed from a PR source branch after git push
    # @return [Array<OCI::Devops::Models::RepositoryCommit>]
    attr_accessor :commits_removed

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'principal': :'principal',
        'pull_request_id': :'pullRequestId',
        'time_occurred': :'timeOccurred',
        'activity_type': :'activityType',
        'commits_added': :'commitsAdded',
        'commits_removed': :'commitsRemoved'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'principal': :'OCI::Devops::Models::PrincipalDetails',
        'pull_request_id': :'String',
        'time_occurred': :'DateTime',
        'activity_type': :'String',
        'commits_added': :'Array<OCI::Devops::Models::RepositoryCommit>',
        'commits_removed': :'Array<OCI::Devops::Models::RepositoryCommit>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {OCI::Devops::Models::PullRequestActivitySummary#id #id} proprety
    # @option attributes [OCI::Devops::Models::PrincipalDetails] :principal The value to assign to the {OCI::Devops::Models::PullRequestActivitySummary#principal #principal} proprety
    # @option attributes [String] :pull_request_id The value to assign to the {OCI::Devops::Models::PullRequestActivitySummary#pull_request_id #pull_request_id} proprety
    # @option attributes [DateTime] :time_occurred The value to assign to the {OCI::Devops::Models::PullRequestActivitySummary#time_occurred #time_occurred} proprety
    # @option attributes [Array<OCI::Devops::Models::RepositoryCommit>] :commits_added The value to assign to the {#commits_added} property
    # @option attributes [Array<OCI::Devops::Models::RepositoryCommit>] :commits_removed The value to assign to the {#commits_removed} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      attributes['activityType'] = 'COMMIT'

      super(attributes)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.commits_added = attributes[:'commitsAdded'] if attributes[:'commitsAdded']

      raise 'You cannot provide both :commitsAdded and :commits_added' if attributes.key?(:'commitsAdded') && attributes.key?(:'commits_added')

      self.commits_added = attributes[:'commits_added'] if attributes[:'commits_added']

      self.commits_removed = attributes[:'commitsRemoved'] if attributes[:'commitsRemoved']

      raise 'You cannot provide both :commitsRemoved and :commits_removed' if attributes.key?(:'commitsRemoved') && attributes.key?(:'commits_removed')

      self.commits_removed = attributes[:'commits_removed'] if attributes[:'commits_removed']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        principal == other.principal &&
        pull_request_id == other.pull_request_id &&
        time_occurred == other.time_occurred &&
        activity_type == other.activity_type &&
        commits_added == other.commits_added &&
        commits_removed == other.commits_removed
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, principal, pull_request_id, time_occurred, activity_type, commits_added, commits_removed].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
