# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20220125
require 'date'
require_relative 'update_dr_protection_group_member_details'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Update properties for a volume group member.
  class DisasterRecovery::Models::UpdateDrProtectionGroupMemberVolumeGroupDetails < DisasterRecovery::Models::UpdateDrProtectionGroupMemberDetails
    # The OCID of the backup policy to use in the destination region. This policy will be used to create backups for this volume group after it moves the destination region.
    #
    # Example: `ocid1.volumebackuppolicy.oc1..uniqueID`
    #
    # @return [String]
    attr_accessor :destination_backup_policy_id

    # A list of mappings between source volume IDs in the volume group and customer-managed encryption keys in the
    # destination region which will be used to encrypt the volume after it moves to the destination region.
    #
    # If you add the entry for source volumes and its corresponding vault and encryption keys here, you can not use
    # 'commonDestinationKey' for encrypting all volumes with common encryption key. Similarly, if you specify common
    # vault and encryption key using 'commonDestinationKey', you cannot specify vaults and encryption keys individually
    # for each volume using 'sourceVolumeToDestinationEncryptionKeyMappings'.
    #
    # An entry for each volume in volume group should be added in this list. The encryption key will not be updated
    # for the volumes that are part of volume group but missing in this list.
    #
    # @return [Array<OCI::DisasterRecovery::Models::UpdateSourceVolumeToDestinationEncryptionKeyMappingDetails>]
    attr_accessor :source_volume_to_destination_encryption_key_mappings

    # @return [OCI::DisasterRecovery::Models::UpdateVaultAndEncryptionKeyDetails]
    attr_accessor :common_destination_key

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'member_id': :'memberId',
        'member_type': :'memberType',
        'destination_backup_policy_id': :'destinationBackupPolicyId',
        'source_volume_to_destination_encryption_key_mappings': :'sourceVolumeToDestinationEncryptionKeyMappings',
        'common_destination_key': :'commonDestinationKey'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'member_id': :'String',
        'member_type': :'String',
        'destination_backup_policy_id': :'String',
        'source_volume_to_destination_encryption_key_mappings': :'Array<OCI::DisasterRecovery::Models::UpdateSourceVolumeToDestinationEncryptionKeyMappingDetails>',
        'common_destination_key': :'OCI::DisasterRecovery::Models::UpdateVaultAndEncryptionKeyDetails'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :member_id The value to assign to the {OCI::DisasterRecovery::Models::UpdateDrProtectionGroupMemberDetails#member_id #member_id} proprety
    # @option attributes [String] :destination_backup_policy_id The value to assign to the {#destination_backup_policy_id} property
    # @option attributes [Array<OCI::DisasterRecovery::Models::UpdateSourceVolumeToDestinationEncryptionKeyMappingDetails>] :source_volume_to_destination_encryption_key_mappings The value to assign to the {#source_volume_to_destination_encryption_key_mappings} property
    # @option attributes [OCI::DisasterRecovery::Models::UpdateVaultAndEncryptionKeyDetails] :common_destination_key The value to assign to the {#common_destination_key} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      attributes['memberType'] = 'VOLUME_GROUP'

      super(attributes)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.destination_backup_policy_id = attributes[:'destinationBackupPolicyId'] if attributes[:'destinationBackupPolicyId']

      raise 'You cannot provide both :destinationBackupPolicyId and :destination_backup_policy_id' if attributes.key?(:'destinationBackupPolicyId') && attributes.key?(:'destination_backup_policy_id')

      self.destination_backup_policy_id = attributes[:'destination_backup_policy_id'] if attributes[:'destination_backup_policy_id']

      self.source_volume_to_destination_encryption_key_mappings = attributes[:'sourceVolumeToDestinationEncryptionKeyMappings'] if attributes[:'sourceVolumeToDestinationEncryptionKeyMappings']

      raise 'You cannot provide both :sourceVolumeToDestinationEncryptionKeyMappings and :source_volume_to_destination_encryption_key_mappings' if attributes.key?(:'sourceVolumeToDestinationEncryptionKeyMappings') && attributes.key?(:'source_volume_to_destination_encryption_key_mappings')

      self.source_volume_to_destination_encryption_key_mappings = attributes[:'source_volume_to_destination_encryption_key_mappings'] if attributes[:'source_volume_to_destination_encryption_key_mappings']

      self.common_destination_key = attributes[:'commonDestinationKey'] if attributes[:'commonDestinationKey']

      raise 'You cannot provide both :commonDestinationKey and :common_destination_key' if attributes.key?(:'commonDestinationKey') && attributes.key?(:'common_destination_key')

      self.common_destination_key = attributes[:'common_destination_key'] if attributes[:'common_destination_key']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        member_id == other.member_id &&
        member_type == other.member_type &&
        destination_backup_policy_id == other.destination_backup_policy_id &&
        source_volume_to_destination_encryption_key_mappings == other.source_volume_to_destination_encryption_key_mappings &&
        common_destination_key == other.common_destination_key
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [member_id, member_type, destination_backup_policy_id, source_volume_to_destination_encryption_key_mappings, common_destination_key].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
