# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20171215
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # An NFS file system. To allow access to a file system, add it
  # to an export set and associate the export set with a mount
  # target. The same file system can be in multiple export sets and
  # associated with multiple mount targets.
  #
  # To use any of the API operations, you must be authorized in an
  # IAM policy. If you're not authorized, talk to an
  # administrator. If you're an administrator who needs to write
  # policies to give users access, see [Getting Started with
  # Policies](https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm).
  #
  class FileStorage::Models::FileSystem
    LIFECYCLE_STATE_ENUM = [
      LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
      LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
      LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
      LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
      LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
      LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
      LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    CLONE_ATTACH_STATUS_ENUM = [
      CLONE_ATTACH_STATUS_ATTACHED = 'ATTACHED'.freeze,
      CLONE_ATTACH_STATUS_DETACHING = 'DETACHING'.freeze,
      CLONE_ATTACH_STATUS_DETACHED = 'DETACHED'.freeze,
      CLONE_ATTACH_STATUS_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    QUOTA_ENFORCEMENT_STATE_ENUM = [
      QUOTA_ENFORCEMENT_STATE_ENABLING = 'ENABLING'.freeze,
      QUOTA_ENFORCEMENT_STATE_ENABLED = 'ENABLED'.freeze,
      QUOTA_ENFORCEMENT_STATE_DISABLING = 'DISABLING'.freeze,
      QUOTA_ENFORCEMENT_STATE_DISABLED = 'DISABLED'.freeze,
      QUOTA_ENFORCEMENT_STATE_SYNCING = 'SYNCING'.freeze,
      QUOTA_ENFORCEMENT_STATE_FAILED = 'FAILED'.freeze,
      QUOTA_ENFORCEMENT_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # The availability domain the file system is in. May be unset
    # as a blank or NULL value.
    #
    # Example: `Uocm:PHX-AD-1`
    #
    # @return [String]
    attr_accessor :availability_domain

    # **[Required]** The number of bytes consumed by the file system, including
    # any snapshots. This number reflects the metered size of the file
    # system and is updated asynchronously with respect to
    # updates to the file system.
    # For more information, see [File System Usage and Metering](https://docs.cloud.oracle.com/Content/File/Concepts/FSutilization.htm).
    #
    # @return [Integer]
    attr_accessor :metered_bytes

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the compartment that contains the file system.
    # @return [String]
    attr_accessor :compartment_id

    # **[Required]** A user-friendly name. It does not have to be unique, and it is changeable.
    # Avoid entering confidential information.
    #
    # Example: `My file system`
    #
    # @return [String]
    attr_accessor :display_name

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system.
    # @return [String]
    attr_accessor :id

    # **[Required]** The current state of the file system.
    # @return [String]
    attr_reader :lifecycle_state

    # **[Required]** The date and time the file system was created, expressed in
    # [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
    #
    # Example: `2016-08-25T21:10:29.600Z`
    #
    # @return [DateTime]
    attr_accessor :time_created

    # Free-form tags for this resource. Each tag is a simple key-value pair
    #  with no predefined name, type, or namespace.
    # For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
    # Example: `{\"Department\": \"Finance\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :freeform_tags

    # Defined tags for this resource. Each key is predefined and scoped to a namespace.
    # For more information, see [Resource Tags](https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm).
    # Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :defined_tags

    # System tags for this resource.
    # System tags are applied to resources by internal OCI services.
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :system_tags

    # The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the KMS key which is the master encryption key for the file system.
    #
    # @return [String]
    attr_accessor :kms_key_id

    # @return [OCI::FileStorage::Models::SourceDetails]
    attr_accessor :source_details

    # Specifies whether the file system has been cloned.
    # See [Cloning a File System](https://docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningFS.htm).
    #
    # @return [BOOLEAN]
    attr_accessor :is_clone_parent

    # Specifies whether the data has finished copying from the source to the clone.
    # Hydration can take up to several hours to complete depending on the size of the source.
    # The source and clone remain available during hydration, but there may be some performance impact.
    # See [Cloning a File System](https://docs.cloud.oracle.com/iaas/Content/File/Tasks/cloningFS.htm#hydration).
    #
    # @return [BOOLEAN]
    attr_accessor :is_hydrated

    # Specifies the total number of children of a file system.
    # @return [Integer]
    attr_accessor :clone_count

    # Specifies whether the file system is attached to its parent file system.
    # @return [String]
    attr_reader :clone_attach_status

    # Locks associated with this resource.
    # @return [Array<OCI::FileStorage::Models::ResourceLock>]
    attr_accessor :locks

    # Additional information about the current 'lifecycleState'.
    # @return [String]
    attr_accessor :lifecycle_details

    # Specifies whether the file system can be used as a target file system for replication. The system sets this value to `true` if the file system is unexported, hasn't yet been specified as a target file system in any replication resource, and has no user snapshots. After the file system has been specified as a target in a replication, or if the file system contains user snapshots, the system sets this value to `false`.
    # For more information, see [Using Replication](https://docs.cloud.oracle.com/iaas/Content/File/Tasks/using-replication.htm).
    #
    # @return [BOOLEAN]
    attr_accessor :is_targetable

    # The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the replication target associated with the file system.
    # Empty if the file system is not being used as target in a replication.
    #
    # @return [String]
    attr_accessor :replication_target_id

    # The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the associated file system snapshot policy, which
    # controls the frequency of snapshot creation and retention period of the taken snapshots.
    #
    # @return [String]
    attr_accessor :filesystem_snapshot_policy_id

    # Specifies the enforcement of quota rules on the file system.
    # @return [BOOLEAN]
    attr_accessor :are_quota_rules_enabled

    # Displays the state of enforcement of quota rules on the file system.
    # @return [String]
    attr_reader :quota_enforcement_state

    # Specifies the total number of replications for which this file system is a source.
    # @return [Integer]
    attr_accessor :replication_source_count

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'availability_domain': :'availabilityDomain',
        'metered_bytes': :'meteredBytes',
        'compartment_id': :'compartmentId',
        'display_name': :'displayName',
        'id': :'id',
        'lifecycle_state': :'lifecycleState',
        'time_created': :'timeCreated',
        'freeform_tags': :'freeformTags',
        'defined_tags': :'definedTags',
        'system_tags': :'systemTags',
        'kms_key_id': :'kmsKeyId',
        'source_details': :'sourceDetails',
        'is_clone_parent': :'isCloneParent',
        'is_hydrated': :'isHydrated',
        'clone_count': :'cloneCount',
        'clone_attach_status': :'cloneAttachStatus',
        'locks': :'locks',
        'lifecycle_details': :'lifecycleDetails',
        'is_targetable': :'isTargetable',
        'replication_target_id': :'replicationTargetId',
        'filesystem_snapshot_policy_id': :'filesystemSnapshotPolicyId',
        'are_quota_rules_enabled': :'areQuotaRulesEnabled',
        'quota_enforcement_state': :'quotaEnforcementState',
        'replication_source_count': :'replicationSourceCount'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'availability_domain': :'String',
        'metered_bytes': :'Integer',
        'compartment_id': :'String',
        'display_name': :'String',
        'id': :'String',
        'lifecycle_state': :'String',
        'time_created': :'DateTime',
        'freeform_tags': :'Hash<String, String>',
        'defined_tags': :'Hash<String, Hash<String, Object>>',
        'system_tags': :'Hash<String, Hash<String, Object>>',
        'kms_key_id': :'String',
        'source_details': :'OCI::FileStorage::Models::SourceDetails',
        'is_clone_parent': :'BOOLEAN',
        'is_hydrated': :'BOOLEAN',
        'clone_count': :'Integer',
        'clone_attach_status': :'String',
        'locks': :'Array<OCI::FileStorage::Models::ResourceLock>',
        'lifecycle_details': :'String',
        'is_targetable': :'BOOLEAN',
        'replication_target_id': :'String',
        'filesystem_snapshot_policy_id': :'String',
        'are_quota_rules_enabled': :'BOOLEAN',
        'quota_enforcement_state': :'String',
        'replication_source_count': :'Integer'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :availability_domain The value to assign to the {#availability_domain} property
    # @option attributes [Integer] :metered_bytes The value to assign to the {#metered_bytes} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [Hash<String, String>] :freeform_tags The value to assign to the {#freeform_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :defined_tags The value to assign to the {#defined_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :system_tags The value to assign to the {#system_tags} property
    # @option attributes [String] :kms_key_id The value to assign to the {#kms_key_id} property
    # @option attributes [OCI::FileStorage::Models::SourceDetails] :source_details The value to assign to the {#source_details} property
    # @option attributes [BOOLEAN] :is_clone_parent The value to assign to the {#is_clone_parent} property
    # @option attributes [BOOLEAN] :is_hydrated The value to assign to the {#is_hydrated} property
    # @option attributes [Integer] :clone_count The value to assign to the {#clone_count} property
    # @option attributes [String] :clone_attach_status The value to assign to the {#clone_attach_status} property
    # @option attributes [Array<OCI::FileStorage::Models::ResourceLock>] :locks The value to assign to the {#locks} property
    # @option attributes [String] :lifecycle_details The value to assign to the {#lifecycle_details} property
    # @option attributes [BOOLEAN] :is_targetable The value to assign to the {#is_targetable} property
    # @option attributes [String] :replication_target_id The value to assign to the {#replication_target_id} property
    # @option attributes [String] :filesystem_snapshot_policy_id The value to assign to the {#filesystem_snapshot_policy_id} property
    # @option attributes [BOOLEAN] :are_quota_rules_enabled The value to assign to the {#are_quota_rules_enabled} property
    # @option attributes [String] :quota_enforcement_state The value to assign to the {#quota_enforcement_state} property
    # @option attributes [Integer] :replication_source_count The value to assign to the {#replication_source_count} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.availability_domain = attributes[:'availabilityDomain'] if attributes[:'availabilityDomain']

      raise 'You cannot provide both :availabilityDomain and :availability_domain' if attributes.key?(:'availabilityDomain') && attributes.key?(:'availability_domain')

      self.availability_domain = attributes[:'availability_domain'] if attributes[:'availability_domain']

      self.metered_bytes = attributes[:'meteredBytes'] if attributes[:'meteredBytes']

      raise 'You cannot provide both :meteredBytes and :metered_bytes' if attributes.key?(:'meteredBytes') && attributes.key?(:'metered_bytes')

      self.metered_bytes = attributes[:'metered_bytes'] if attributes[:'metered_bytes']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.id = attributes[:'id'] if attributes[:'id']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

      raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

      self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

      self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

      raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

      self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

      self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

      raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

      self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

      self.kms_key_id = attributes[:'kmsKeyId'] if attributes[:'kmsKeyId']

      raise 'You cannot provide both :kmsKeyId and :kms_key_id' if attributes.key?(:'kmsKeyId') && attributes.key?(:'kms_key_id')

      self.kms_key_id = attributes[:'kms_key_id'] if attributes[:'kms_key_id']

      self.source_details = attributes[:'sourceDetails'] if attributes[:'sourceDetails']

      raise 'You cannot provide both :sourceDetails and :source_details' if attributes.key?(:'sourceDetails') && attributes.key?(:'source_details')

      self.source_details = attributes[:'source_details'] if attributes[:'source_details']

      self.is_clone_parent = attributes[:'isCloneParent'] unless attributes[:'isCloneParent'].nil?

      raise 'You cannot provide both :isCloneParent and :is_clone_parent' if attributes.key?(:'isCloneParent') && attributes.key?(:'is_clone_parent')

      self.is_clone_parent = attributes[:'is_clone_parent'] unless attributes[:'is_clone_parent'].nil?

      self.is_hydrated = attributes[:'isHydrated'] unless attributes[:'isHydrated'].nil?

      raise 'You cannot provide both :isHydrated and :is_hydrated' if attributes.key?(:'isHydrated') && attributes.key?(:'is_hydrated')

      self.is_hydrated = attributes[:'is_hydrated'] unless attributes[:'is_hydrated'].nil?

      self.clone_count = attributes[:'cloneCount'] if attributes[:'cloneCount']

      raise 'You cannot provide both :cloneCount and :clone_count' if attributes.key?(:'cloneCount') && attributes.key?(:'clone_count')

      self.clone_count = attributes[:'clone_count'] if attributes[:'clone_count']

      self.clone_attach_status = attributes[:'cloneAttachStatus'] if attributes[:'cloneAttachStatus']

      raise 'You cannot provide both :cloneAttachStatus and :clone_attach_status' if attributes.key?(:'cloneAttachStatus') && attributes.key?(:'clone_attach_status')

      self.clone_attach_status = attributes[:'clone_attach_status'] if attributes[:'clone_attach_status']

      self.locks = attributes[:'locks'] if attributes[:'locks']

      self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

      raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

      self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

      self.is_targetable = attributes[:'isTargetable'] unless attributes[:'isTargetable'].nil?

      raise 'You cannot provide both :isTargetable and :is_targetable' if attributes.key?(:'isTargetable') && attributes.key?(:'is_targetable')

      self.is_targetable = attributes[:'is_targetable'] unless attributes[:'is_targetable'].nil?

      self.replication_target_id = attributes[:'replicationTargetId'] if attributes[:'replicationTargetId']

      raise 'You cannot provide both :replicationTargetId and :replication_target_id' if attributes.key?(:'replicationTargetId') && attributes.key?(:'replication_target_id')

      self.replication_target_id = attributes[:'replication_target_id'] if attributes[:'replication_target_id']

      self.filesystem_snapshot_policy_id = attributes[:'filesystemSnapshotPolicyId'] if attributes[:'filesystemSnapshotPolicyId']

      raise 'You cannot provide both :filesystemSnapshotPolicyId and :filesystem_snapshot_policy_id' if attributes.key?(:'filesystemSnapshotPolicyId') && attributes.key?(:'filesystem_snapshot_policy_id')

      self.filesystem_snapshot_policy_id = attributes[:'filesystem_snapshot_policy_id'] if attributes[:'filesystem_snapshot_policy_id']

      self.are_quota_rules_enabled = attributes[:'areQuotaRulesEnabled'] unless attributes[:'areQuotaRulesEnabled'].nil?
      self.are_quota_rules_enabled = false if are_quota_rules_enabled.nil? && !attributes.key?(:'areQuotaRulesEnabled') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :areQuotaRulesEnabled and :are_quota_rules_enabled' if attributes.key?(:'areQuotaRulesEnabled') && attributes.key?(:'are_quota_rules_enabled')

      self.are_quota_rules_enabled = attributes[:'are_quota_rules_enabled'] unless attributes[:'are_quota_rules_enabled'].nil?
      self.are_quota_rules_enabled = false if are_quota_rules_enabled.nil? && !attributes.key?(:'areQuotaRulesEnabled') && !attributes.key?(:'are_quota_rules_enabled') # rubocop:disable Style/StringLiterals

      self.quota_enforcement_state = attributes[:'quotaEnforcementState'] if attributes[:'quotaEnforcementState']

      raise 'You cannot provide both :quotaEnforcementState and :quota_enforcement_state' if attributes.key?(:'quotaEnforcementState') && attributes.key?(:'quota_enforcement_state')

      self.quota_enforcement_state = attributes[:'quota_enforcement_state'] if attributes[:'quota_enforcement_state']

      self.replication_source_count = attributes[:'replicationSourceCount'] if attributes[:'replicationSourceCount']

      raise 'You cannot provide both :replicationSourceCount and :replication_source_count' if attributes.key?(:'replicationSourceCount') && attributes.key?(:'replication_source_count')

      self.replication_source_count = attributes[:'replication_source_count'] if attributes[:'replication_source_count']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_state Object to be assigned
    def lifecycle_state=(lifecycle_state)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_state && !LIFECYCLE_STATE_ENUM.include?(lifecycle_state)
        OCI.logger.debug("Unknown value for 'lifecycle_state' [" + lifecycle_state + "]. Mapping to 'LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_state = LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_state = lifecycle_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] clone_attach_status Object to be assigned
    def clone_attach_status=(clone_attach_status)
      # rubocop:disable Style/ConditionalAssignment
      if clone_attach_status && !CLONE_ATTACH_STATUS_ENUM.include?(clone_attach_status)
        OCI.logger.debug("Unknown value for 'clone_attach_status' [" + clone_attach_status + "]. Mapping to 'CLONE_ATTACH_STATUS_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @clone_attach_status = CLONE_ATTACH_STATUS_UNKNOWN_ENUM_VALUE
      else
        @clone_attach_status = clone_attach_status
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] quota_enforcement_state Object to be assigned
    def quota_enforcement_state=(quota_enforcement_state)
      # rubocop:disable Style/ConditionalAssignment
      if quota_enforcement_state && !QUOTA_ENFORCEMENT_STATE_ENUM.include?(quota_enforcement_state)
        OCI.logger.debug("Unknown value for 'quota_enforcement_state' [" + quota_enforcement_state + "]. Mapping to 'QUOTA_ENFORCEMENT_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @quota_enforcement_state = QUOTA_ENFORCEMENT_STATE_UNKNOWN_ENUM_VALUE
      else
        @quota_enforcement_state = quota_enforcement_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        availability_domain == other.availability_domain &&
        metered_bytes == other.metered_bytes &&
        compartment_id == other.compartment_id &&
        display_name == other.display_name &&
        id == other.id &&
        lifecycle_state == other.lifecycle_state &&
        time_created == other.time_created &&
        freeform_tags == other.freeform_tags &&
        defined_tags == other.defined_tags &&
        system_tags == other.system_tags &&
        kms_key_id == other.kms_key_id &&
        source_details == other.source_details &&
        is_clone_parent == other.is_clone_parent &&
        is_hydrated == other.is_hydrated &&
        clone_count == other.clone_count &&
        clone_attach_status == other.clone_attach_status &&
        locks == other.locks &&
        lifecycle_details == other.lifecycle_details &&
        is_targetable == other.is_targetable &&
        replication_target_id == other.replication_target_id &&
        filesystem_snapshot_policy_id == other.filesystem_snapshot_policy_id &&
        are_quota_rules_enabled == other.are_quota_rules_enabled &&
        quota_enforcement_state == other.quota_enforcement_state &&
        replication_source_count == other.replication_source_count
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [availability_domain, metered_bytes, compartment_id, display_name, id, lifecycle_state, time_created, freeform_tags, defined_tags, system_tags, kms_key_id, source_details, is_clone_parent, is_hydrated, clone_count, clone_attach_status, locks, lifecycle_details, is_targetable, replication_target_id, filesystem_snapshot_policy_id, are_quota_rules_enabled, quota_enforcement_state, replication_source_count].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
