# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20171215
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Summary information for a principal's usage and quota rule.
  #
  class FileStorage::Models::QuotaRuleSummary
    PRINCIPAL_TYPE_ENUM = [
      PRINCIPAL_TYPE_FILE_SYSTEM_LEVEL = 'FILE_SYSTEM_LEVEL'.freeze,
      PRINCIPAL_TYPE_DEFAULT_GROUP = 'DEFAULT_GROUP'.freeze,
      PRINCIPAL_TYPE_DEFAULT_USER = 'DEFAULT_USER'.freeze,
      PRINCIPAL_TYPE_INDIVIDUAL_GROUP = 'INDIVIDUAL_GROUP'.freeze,
      PRINCIPAL_TYPE_INDIVIDUAL_USER = 'INDIVIDUAL_USER'.freeze,
      PRINCIPAL_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # The identifier of the quota rule. It is the base64 encoded string of the tuple <principalId, principalType, isHardQuota>.
    # @return [String]
    attr_accessor :id

    # **[Required]** The [OCID](https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm) of the file system.
    # @return [String]
    attr_accessor :file_system_id

    # **[Required]** The type of the owner of this quota rule and usage.
    #
    # @return [String]
    attr_reader :principal_type

    # **[Required]** An identifier for the user or the group associated with quota rule and usage. UNIX-like operating systems use this integer value to
    # identify a user or group to manage access control.
    #
    # @return [Integer]
    attr_accessor :principal_id

    # Whether the quota rule will be enforced.
    # If `isHardQuota` is true, the quota rule is enforced so that the write is blocked if usage
    # exceeds the hard quota limit.
    # If `isHardQuota` is false, writes succeed even if usage exceeds the soft quota limit, but the quota rule is violated.
    #
    # @return [BOOLEAN]
    attr_accessor :is_hard_quota

    # A user-friendly name. It does not have to be unique, and it is changeable.
    # Avoid entering confidential information.
    # Example: `UserXYZ's quota`
    #
    # @return [String]
    attr_accessor :display_name

    # **[Required]** The usage value corresponding to this principal in bytes.
    #
    # @return [Integer]
    attr_accessor :usage_in_bytes

    # The value of the quota rule in gigabytes.
    #
    # @return [Integer]
    attr_accessor :quota_limit_in_gigabytes

    # The date and time the quota rule was created, expressed in
    # [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
    #
    # Example: `2016-08-25T21:10:29.600Z`
    #
    # @return [DateTime]
    attr_accessor :time_created

    # The date and time the quota rule was last updated, expressed in
    # [RFC 3339](https://tools.ietf.org/rfc/rfc3339) timestamp format.
    #
    # Example: `2016-08-25T21:10:29.600Z`
    #
    # @return [DateTime]
    attr_accessor :time_updated

    # An option to display only the users or groups that violate their quota rules.
    # If `areViolatorsOnly` is false, results report all the quota and usage.
    # If `areViolatorsOnly` is true, results only report the quota and usage for
    # the users or groups that violate their quota rules.
    #
    # @return [BOOLEAN]
    attr_accessor :are_violators_only

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'file_system_id': :'fileSystemId',
        'principal_type': :'principalType',
        'principal_id': :'principalId',
        'is_hard_quota': :'isHardQuota',
        'display_name': :'displayName',
        'usage_in_bytes': :'usageInBytes',
        'quota_limit_in_gigabytes': :'quotaLimitInGigabytes',
        'time_created': :'timeCreated',
        'time_updated': :'timeUpdated',
        'are_violators_only': :'areViolatorsOnly'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'file_system_id': :'String',
        'principal_type': :'String',
        'principal_id': :'Integer',
        'is_hard_quota': :'BOOLEAN',
        'display_name': :'String',
        'usage_in_bytes': :'Integer',
        'quota_limit_in_gigabytes': :'Integer',
        'time_created': :'DateTime',
        'time_updated': :'DateTime',
        'are_violators_only': :'BOOLEAN'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :file_system_id The value to assign to the {#file_system_id} property
    # @option attributes [String] :principal_type The value to assign to the {#principal_type} property
    # @option attributes [Integer] :principal_id The value to assign to the {#principal_id} property
    # @option attributes [BOOLEAN] :is_hard_quota The value to assign to the {#is_hard_quota} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [Integer] :usage_in_bytes The value to assign to the {#usage_in_bytes} property
    # @option attributes [Integer] :quota_limit_in_gigabytes The value to assign to the {#quota_limit_in_gigabytes} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_updated The value to assign to the {#time_updated} property
    # @option attributes [BOOLEAN] :are_violators_only The value to assign to the {#are_violators_only} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.file_system_id = attributes[:'fileSystemId'] if attributes[:'fileSystemId']

      raise 'You cannot provide both :fileSystemId and :file_system_id' if attributes.key?(:'fileSystemId') && attributes.key?(:'file_system_id')

      self.file_system_id = attributes[:'file_system_id'] if attributes[:'file_system_id']

      self.principal_type = attributes[:'principalType'] if attributes[:'principalType']

      raise 'You cannot provide both :principalType and :principal_type' if attributes.key?(:'principalType') && attributes.key?(:'principal_type')

      self.principal_type = attributes[:'principal_type'] if attributes[:'principal_type']

      self.principal_id = attributes[:'principalId'] if attributes[:'principalId']

      raise 'You cannot provide both :principalId and :principal_id' if attributes.key?(:'principalId') && attributes.key?(:'principal_id')

      self.principal_id = attributes[:'principal_id'] if attributes[:'principal_id']

      self.is_hard_quota = attributes[:'isHardQuota'] unless attributes[:'isHardQuota'].nil?

      raise 'You cannot provide both :isHardQuota and :is_hard_quota' if attributes.key?(:'isHardQuota') && attributes.key?(:'is_hard_quota')

      self.is_hard_quota = attributes[:'is_hard_quota'] unless attributes[:'is_hard_quota'].nil?

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.usage_in_bytes = attributes[:'usageInBytes'] if attributes[:'usageInBytes']

      raise 'You cannot provide both :usageInBytes and :usage_in_bytes' if attributes.key?(:'usageInBytes') && attributes.key?(:'usage_in_bytes')

      self.usage_in_bytes = attributes[:'usage_in_bytes'] if attributes[:'usage_in_bytes']

      self.quota_limit_in_gigabytes = attributes[:'quotaLimitInGigabytes'] if attributes[:'quotaLimitInGigabytes']

      raise 'You cannot provide both :quotaLimitInGigabytes and :quota_limit_in_gigabytes' if attributes.key?(:'quotaLimitInGigabytes') && attributes.key?(:'quota_limit_in_gigabytes')

      self.quota_limit_in_gigabytes = attributes[:'quota_limit_in_gigabytes'] if attributes[:'quota_limit_in_gigabytes']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

      raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

      self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

      self.are_violators_only = attributes[:'areViolatorsOnly'] unless attributes[:'areViolatorsOnly'].nil?
      self.are_violators_only = false if are_violators_only.nil? && !attributes.key?(:'areViolatorsOnly') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :areViolatorsOnly and :are_violators_only' if attributes.key?(:'areViolatorsOnly') && attributes.key?(:'are_violators_only')

      self.are_violators_only = attributes[:'are_violators_only'] unless attributes[:'are_violators_only'].nil?
      self.are_violators_only = false if are_violators_only.nil? && !attributes.key?(:'areViolatorsOnly') && !attributes.key?(:'are_violators_only') # rubocop:disable Style/StringLiterals
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] principal_type Object to be assigned
    def principal_type=(principal_type)
      # rubocop:disable Style/ConditionalAssignment
      if principal_type && !PRINCIPAL_TYPE_ENUM.include?(principal_type)
        OCI.logger.debug("Unknown value for 'principal_type' [" + principal_type + "]. Mapping to 'PRINCIPAL_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @principal_type = PRINCIPAL_TYPE_UNKNOWN_ENUM_VALUE
      else
        @principal_type = principal_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        file_system_id == other.file_system_id &&
        principal_type == other.principal_type &&
        principal_id == other.principal_id &&
        is_hard_quota == other.is_hard_quota &&
        display_name == other.display_name &&
        usage_in_bytes == other.usage_in_bytes &&
        quota_limit_in_gigabytes == other.quota_limit_in_gigabytes &&
        time_created == other.time_created &&
        time_updated == other.time_updated &&
        are_violators_only == other.are_violators_only
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, file_system_id, principal_type, principal_id, is_hard_quota, display_name, usage_in_bytes, quota_limit_in_gigabytes, time_created, time_updated, are_violators_only].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
