# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20250228

require 'uri'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Fleet Application Management provides a centralized platform to help you automate resource management tasks, validate patch compliance, and enhance operational efficiency across an enterprise.
  class FleetAppsManagement::FleetAppsManagementOperationsClient
    # Client used to make HTTP requests.
    # @return [OCI::ApiClient]
    attr_reader :api_client

    # Fully qualified endpoint URL
    # @return [String]
    attr_reader :endpoint

    # The default retry configuration to apply to all operations in this service client. This can be overridden
    # on a per-operation basis. The default retry configuration value is `nil`, which means that an operation
    # will not perform any retries
    # @return [OCI::Retry::RetryConfig]
    attr_reader :retry_config

    # The region, which will usually correspond to a value in {OCI::Regions::REGION_ENUM}.
    # @return [String]
    attr_reader :region

    # rubocop:disable Metrics/AbcSize, Metrics/CyclomaticComplexity, Layout/EmptyLines, Metrics/PerceivedComplexity


    # Creates a new FleetAppsManagementOperationsClient.
    # Notes:
    #   If a config is not specified, then the global OCI.config will be used.
    #
    #   This client is not thread-safe
    #
    #   Either a region or an endpoint must be specified.  If an endpoint is specified, it will be used instead of the
    #     region. A region may be specified in the config or via or the region parameter. If specified in both, then the
    #     region parameter will be used.
    # @param [Config] config A Config object.
    # @param [String] region A region used to determine the service endpoint. This will usually
    #   correspond to a value in {OCI::Regions::REGION_ENUM}, but may be an arbitrary string.
    # @param [String] endpoint The fully qualified endpoint URL
    # @param [OCI::BaseSigner] signer A signer implementation which can be used by this client. If this is not provided then
    #   a signer will be constructed via the provided config. One use case of this parameter is instance principals authentication,
    #   so that the instance principals signer can be provided to the client
    # @param [OCI::ApiClientProxySettings] proxy_settings If your environment requires you to use a proxy server for outgoing HTTP requests
    #   the details for the proxy can be provided in this parameter
    # @param [OCI::Retry::RetryConfig] retry_config The retry configuration for this service client. This represents the default retry configuration to
    #   apply across all operations. This can be overridden on a per-operation basis. The default retry configuration value is `nil`, which means that an operation
    #   will not perform any retries
    def initialize(config: nil, region: nil, endpoint: nil, signer: nil, proxy_settings: nil, retry_config: nil)
      # If the signer is an InstancePrincipalsSecurityTokenSigner or SecurityTokenSigner and no config was supplied (they are self-sufficient signers)
      # then create a dummy config to pass to the ApiClient constructor. If customers wish to create a client which uses instance principals
      # and has config (either populated programmatically or loaded from a file), they must construct that config themselves and then
      # pass it to this constructor.
      #
      # If there is no signer (or the signer is not an instance principals signer) and no config was supplied, this is not valid
      # so try and load the config from the default file.
      config = OCI::Config.validate_and_build_config_with_signer(config, signer)

      signer = OCI::Signer.config_file_auth_builder(config) if signer.nil?

      @api_client = OCI::ApiClient.new(config, signer, proxy_settings: proxy_settings)
      @retry_config = retry_config

      if endpoint
        @endpoint = endpoint + '/20250228'
      else
        region ||= config.region
        region ||= signer.region if signer.respond_to?(:region)
        self.region = region
      end
      logger.info "FleetAppsManagementOperationsClient endpoint set to '#{@endpoint}'." if logger
    end
    # rubocop:enable Metrics/AbcSize, Metrics/CyclomaticComplexity, Layout/EmptyLines, Metrics/PerceivedComplexity

    # Set the region that will be used to determine the service endpoint.
    # This will usually correspond to a value in {OCI::Regions::REGION_ENUM},
    # but may be an arbitrary string.
    def region=(new_region)
      @region = new_region

      raise 'A region must be specified.' unless @region

      @endpoint = OCI::Regions.get_service_endpoint_for_template(@region, 'https://fams.{region}.oci.{secondLevelDomain}') + '/20250228'
      logger.info "FleetAppsManagementOperationsClient endpoint set to '#{@endpoint} from region #{@region}'." if logger
    end

    # @return [Logger] The logger for this client. May be nil.
    def logger
      @api_client.config.logger
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Moves a Patch into a different compartment within the same tenancy. For information about moving resources between
    # compartments, see [Moving Resources to a Different Compartment](https://docs.cloud.oracle.com/iaas/Content/Identity/Tasks/managingcompartments.htm#moveRes).
    #
    # @param [String] patch_id Unique Patch identifier.
    # @param [OCI::FleetAppsManagement::Models::ChangePatchCompartmentDetails] change_patch_compartment_details Details of the target compartment.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [String] :opc_retry_token A token that uniquely identifies a request so it can be retried in case of a timeout or
    #   server error without risk of executing that same action again. Retry tokens expire after 24
    #   hours, but can be invalidated before then due to conflicting operations. For example, if a resource
    #   has been deleted and purged from the system, then a retry of the original creation request
    #   might be rejected.
    #
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/change_patch_compartment.rb.html) to see an example of how to use change_patch_compartment API.
    def change_patch_compartment(patch_id, change_patch_compartment_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#change_patch_compartment.' if logger

      raise "Missing the required parameter 'patch_id' when calling change_patch_compartment." if patch_id.nil?
      raise "Missing the required parameter 'change_patch_compartment_details' when calling change_patch_compartment." if change_patch_compartment_details.nil?
      raise "Parameter value for 'patch_id' must not be blank" if OCI::Internal::Util.blank_string?(patch_id)

      path = '/patches/{patchId}/actions/changeCompartment'.sub('{patchId}', patch_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
      # rubocop:enable Style/NegatedIf
      header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

      post_body = @api_client.object_to_http_body(change_patch_compartment_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#change_patch_compartment') do
        @api_client.call_api(
          :POST,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Creates a new Patch.
    #
    # @param [OCI::FleetAppsManagement::Models::CreatePatchDetails] create_patch_details Details for the new Patch.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_retry_token A token that uniquely identifies a request so it can be retried in case of a timeout or
    #   server error without risk of executing that same action again. Retry tokens expire after 24
    #   hours, but can be invalidated before then due to conflicting operations. For example, if a resource
    #   has been deleted and purged from the system, then a retry of the original creation request
    #   might be rejected.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::Patch Patch}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/create_patch.rb.html) to see an example of how to use create_patch API.
    def create_patch(create_patch_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#create_patch.' if logger

      raise "Missing the required parameter 'create_patch_details' when calling create_patch." if create_patch_details.nil?

      path = '/patches'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf
      header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

      post_body = @api_client.object_to_http_body(create_patch_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#create_patch') do
        @api_client.call_api(
          :POST,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::Patch'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Create a SchedulerDefinition to perform lifecycle operations.
    #
    # @param [OCI::FleetAppsManagement::Models::CreateSchedulerDefinitionDetails] create_scheduler_definition_details Details for the new SchedulerDefinition.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_retry_token A token that uniquely identifies a request so it can be retried in case of a timeout or
    #   server error without risk of executing that same action again. Retry tokens expire after 24
    #   hours, but can be invalidated before then due to conflicting operations. For example, if a resource
    #   has been deleted and purged from the system, then a retry of the original creation request
    #   might be rejected.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerDefinition SchedulerDefinition}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/create_scheduler_definition.rb.html) to see an example of how to use create_scheduler_definition API.
    def create_scheduler_definition(create_scheduler_definition_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#create_scheduler_definition.' if logger

      raise "Missing the required parameter 'create_scheduler_definition_details' when calling create_scheduler_definition." if create_scheduler_definition_details.nil?

      path = '/schedulerDefinitions'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf
      header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

      post_body = @api_client.object_to_http_body(create_scheduler_definition_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#create_scheduler_definition') do
        @api_client.call_api(
          :POST,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerDefinition'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Deletes the patch specified by identifier.
    # @param [String] patch_id Unique Patch identifier.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/delete_patch.rb.html) to see an example of how to use delete_patch API.
    def delete_patch(patch_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#delete_patch.' if logger

      raise "Missing the required parameter 'patch_id' when calling delete_patch." if patch_id.nil?
      raise "Parameter value for 'patch_id' must not be blank" if OCI::Internal::Util.blank_string?(patch_id)

      path = '/patches/{patchId}'.sub('{patchId}', patch_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#delete_patch') do
        @api_client.call_api(
          :DELETE,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Deletes a SchedulerDefinition resource by identifier
    # @param [String] scheduler_definition_id unique SchedulerDefinition identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/delete_scheduler_definition.rb.html) to see an example of how to use delete_scheduler_definition API.
    def delete_scheduler_definition(scheduler_definition_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#delete_scheduler_definition.' if logger

      raise "Missing the required parameter 'scheduler_definition_id' when calling delete_scheduler_definition." if scheduler_definition_id.nil?
      raise "Parameter value for 'scheduler_definition_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_definition_id)

      path = '/schedulerDefinitions/{schedulerDefinitionId}'.sub('{schedulerDefinitionId}', scheduler_definition_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#delete_scheduler_definition') do
        @api_client.call_api(
          :DELETE,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Deletes the schedule job specified by an identifier.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/delete_scheduler_job.rb.html) to see an example of how to use delete_scheduler_job API.
    def delete_scheduler_job(scheduler_job_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#delete_scheduler_job.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling delete_scheduler_job." if scheduler_job_id.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)

      path = '/schedulerJobs/{schedulerJobId}'.sub('{schedulerJobId}', scheduler_job_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#delete_scheduler_job') do
        @api_client.call_api(
          :DELETE,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Generate Compliance Report
    #
    # @param [OCI::FleetAppsManagement::Models::ExportComplianceReportDetails] export_compliance_report_details Details for generating compliance report
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_retry_token A token that uniquely identifies a request so it can be retried in case of a timeout or
    #   server error without risk of executing that same action again. Retry tokens expire after 24
    #   hours, but can be invalidated before then due to conflicting operations. For example, if a resource
    #   has been deleted and purged from the system, then a retry of the original creation request
    #   might be rejected.
    #
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [String, IO] :response_target Streaming http body into a file (specified by file name or File object) or IO object if the block is not given
    # @option [Block] &block Streaming http body to the block
    # @return [Response] A Response object with data of type String if response_target and block are not given, otherwise with nil data
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/export_compliance_report.rb.html) to see an example of how to use export_compliance_report API.
    def export_compliance_report(export_compliance_report_details, opts = {}, &block)
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#export_compliance_report.' if logger

      raise "Missing the required parameter 'export_compliance_report_details' when calling export_compliance_report." if export_compliance_report_details.nil?

      path = '/complianceRecords/actions/exportComplianceReport'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = opts[:accept] if opts[:accept]
      header_params[:accept] ||= 'application/json'
      header_params[:'accept-encoding'] = opts[:accept_encoding] if opts[:accept_encoding]
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf
      header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

      post_body = @api_client.object_to_http_body(export_compliance_report_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#export_compliance_report') do
        if !block.nil?
          @api_client.call_api(
            :POST,
            path,
            endpoint,
            header_params: header_params,
            query_params: query_params,
            operation_signing_strategy: operation_signing_strategy,
            body: post_body,
            return_type: 'Stream',
            &block
          )
        elsif opts[:response_target]
          if opts[:response_target].respond_to? :write
            @api_client.call_api(
              :POST,
              path,
              endpoint,
              header_params: header_params,
              query_params: query_params,
              operation_signing_strategy: operation_signing_strategy,
              body: post_body,
              return_type: 'Stream',
              &proc { |chunk, _response| opts[:response_target].write(chunk) }
            )
          elsif opts[:response_target].is_a?(String)
            File.open(opts[:response_target], 'wb') do |output|
              return @api_client.call_api(
                :POST,
                path,
                endpoint,
                header_params: header_params,
                query_params: query_params,
                operation_signing_strategy: operation_signing_strategy,
                body: post_body,
                return_type: 'Stream',
                &proc { |chunk, _response| output.write(chunk) }
              )
            end
          end
        else
          @api_client.call_api(
            :POST,
            path,
            endpoint,
            header_params: header_params,
            query_params: query_params,
            operation_signing_strategy: operation_signing_strategy,
            body: post_body,
            return_type: 'String'
          )
        end
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Get Task Execution by Identifier for a Resource within an action group.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [String] job_activity_id unique jobActivity identifier
    # @param [String] resource_id unique Resource identifier
    # @param [String] execution_id Execution Id
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::Execution Execution}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/get_execution.rb.html) to see an example of how to use get_execution API.
    def get_execution(scheduler_job_id, job_activity_id, resource_id, execution_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#get_execution.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling get_execution." if scheduler_job_id.nil?
      raise "Missing the required parameter 'job_activity_id' when calling get_execution." if job_activity_id.nil?
      raise "Missing the required parameter 'resource_id' when calling get_execution." if resource_id.nil?
      raise "Missing the required parameter 'execution_id' when calling get_execution." if execution_id.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)
      raise "Parameter value for 'job_activity_id' must not be blank" if OCI::Internal::Util.blank_string?(job_activity_id)
      raise "Parameter value for 'resource_id' must not be blank" if OCI::Internal::Util.blank_string?(resource_id)
      raise "Parameter value for 'execution_id' must not be blank" if OCI::Internal::Util.blank_string?(execution_id)

      path = '/schedulerJobs/{schedulerJobId}/jobActivities/{jobActivityId}/resources/{resourceId}/executions/{executionId}'.sub('{schedulerJobId}', scheduler_job_id.to_s).sub('{jobActivityId}', job_activity_id.to_s).sub('{resourceId}', resource_id.to_s).sub('{executionId}', execution_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#get_execution') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::Execution'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Gets activity details by identifier for a job.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [String] job_activity_id unique jobActivity identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::JobActivity JobActivity}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/get_job_activity.rb.html) to see an example of how to use get_job_activity API.
    def get_job_activity(scheduler_job_id, job_activity_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#get_job_activity.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling get_job_activity." if scheduler_job_id.nil?
      raise "Missing the required parameter 'job_activity_id' when calling get_job_activity." if job_activity_id.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)
      raise "Parameter value for 'job_activity_id' must not be blank" if OCI::Internal::Util.blank_string?(job_activity_id)

      path = '/schedulerJobs/{schedulerJobId}/jobActivities/{jobActivityId}'.sub('{schedulerJobId}', scheduler_job_id.to_s).sub('{jobActivityId}', job_activity_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#get_job_activity') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::JobActivity'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Gets a Patch by identifier.
    # @param [String] patch_id Unique Patch identifier.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::Patch Patch}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/get_patch.rb.html) to see an example of how to use get_patch API.
    def get_patch(patch_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#get_patch.' if logger

      raise "Missing the required parameter 'patch_id' when calling get_patch." if patch_id.nil?
      raise "Parameter value for 'patch_id' must not be blank" if OCI::Internal::Util.blank_string?(patch_id)

      path = '/patches/{patchId}'.sub('{patchId}', patch_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#get_patch') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::Patch'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Get the details of a SchedulerDefinition that performs lifecycle management operations.
    # @param [String] scheduler_definition_id unique SchedulerDefinition identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerDefinition SchedulerDefinition}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/get_scheduler_definition.rb.html) to see an example of how to use get_scheduler_definition API.
    def get_scheduler_definition(scheduler_definition_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#get_scheduler_definition.' if logger

      raise "Missing the required parameter 'scheduler_definition_id' when calling get_scheduler_definition." if scheduler_definition_id.nil?
      raise "Parameter value for 'scheduler_definition_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_definition_id)

      path = '/schedulerDefinitions/{schedulerDefinitionId}'.sub('{schedulerDefinitionId}', scheduler_definition_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#get_scheduler_definition') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerDefinition'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Get the details of a lifecycle management operations job in Fleet Application Management.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerJob SchedulerJob}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/get_scheduler_job.rb.html) to see an example of how to use get_scheduler_job API.
    def get_scheduler_job(scheduler_job_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#get_scheduler_job.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling get_scheduler_job." if scheduler_job_id.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)

      path = '/schedulerJobs/{schedulerJobId}'.sub('{schedulerJobId}', scheduler_job_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#get_scheduler_job') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerJob'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Gets a list of complianceDetails.
    #
    # @param [String] compartment_id The ID of the compartment in which to list resources.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :resource_id Resource identifier.
    # @option opts [String] :entity_id Entity identifier.Ex:FleetId
    # @option opts [String] :product_name Product Name.
    # @option opts [String] :product_stack ProductStack name.
    # @option opts [String] :target_name Unique target name
    # @option opts [String] :compliance_state Target Compliance State.
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeCreated is descending. Default order for displayName is ascending.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ComplianceRecordCollection ComplianceRecordCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_compliance_records.rb.html) to see an example of how to use list_compliance_records API.
    def list_compliance_records(compartment_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_compliance_records.' if logger

      raise "Missing the required parameter 'compartment_id' when calling list_compliance_records." if compartment_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !OCI::FleetAppsManagement::Models::COMPLIANCE_RECORD_SORT_BY_ENUM.include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of the values in OCI::FleetAppsManagement::Models::COMPLIANCE_RECORD_SORT_BY_ENUM.'
      end

      path = '/complianceRecords'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = compartment_id
      query_params[:resourceId] = opts[:resource_id] if opts[:resource_id]
      query_params[:entityId] = opts[:entity_id] if opts[:entity_id]
      query_params[:productName] = opts[:product_name] if opts[:product_name]
      query_params[:productStack] = opts[:product_stack] if opts[:product_stack]
      query_params[:targetName] = opts[:target_name] if opts[:target_name]
      query_params[:complianceState] = opts[:compliance_state] if opts[:compliance_state]
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_compliance_records') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ComplianceRecordCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of Task Executions for a Resource.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [String] job_activity_id unique jobActivity identifier
    # @param [String] resource_id unique Resource identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :resource_task_id Task Id
    # @option opts [String] :step_name Unique step name
    # @option opts [String] :target_name Unique target name
    # @option opts [String] :sequence Task Order Sequence
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeStarted is descending.
    #    (default to timeStarted)
    #   Allowed values are: timeStarted
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ExecutionCollection ExecutionCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_executions.rb.html) to see an example of how to use list_executions API.
    def list_executions(scheduler_job_id, job_activity_id, resource_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_executions.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling list_executions." if scheduler_job_id.nil?
      raise "Missing the required parameter 'job_activity_id' when calling list_executions." if job_activity_id.nil?
      raise "Missing the required parameter 'resource_id' when calling list_executions." if resource_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeStarted].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeStarted.'
      end
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)
      raise "Parameter value for 'job_activity_id' must not be blank" if OCI::Internal::Util.blank_string?(job_activity_id)
      raise "Parameter value for 'resource_id' must not be blank" if OCI::Internal::Util.blank_string?(resource_id)

      path = '/schedulerJobs/{schedulerJobId}/jobActivities/{jobActivityId}/resources/{resourceId}/executions'.sub('{schedulerJobId}', scheduler_job_id.to_s).sub('{jobActivityId}', job_activity_id.to_s).sub('{resourceId}', resource_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:resourceTaskId] = opts[:resource_task_id] if opts[:resource_task_id]
      query_params[:stepName] = opts[:step_name] if opts[:step_name]
      query_params[:targetName] = opts[:target_name] if opts[:target_name]
      query_params[:sequence] = opts[:sequence] if opts[:sequence]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_executions') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ExecutionCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Gets a list of inventoryDetails.
    #
    # @param [String] compartment_id The ID of the compartment in which to list resources.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [String] :fleet_id unique Fleet identifier
    # @option opts [String] :resource_id Resource Identifier
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided.
    #    (default to targetName)
    #   Allowed values are: targetName, targetProductName, targetResourceId, osType, architecture
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::InventoryRecordCollection InventoryRecordCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_inventory_records.rb.html) to see an example of how to use list_inventory_records API.
    def list_inventory_records(compartment_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_inventory_records.' if logger

      raise "Missing the required parameter 'compartment_id' when calling list_inventory_records." if compartment_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[targetName targetProductName targetResourceId osType architecture].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of targetName, targetProductName, targetResourceId, osType, architecture.'
      end

      path = '/inventoryRecords'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = compartment_id
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:fleetId] = opts[:fleet_id] if opts[:fleet_id]
      query_params[:resourceId] = opts[:resource_id] if opts[:resource_id]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_inventory_records') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::InventoryRecordCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of all the Patches in the specified compartment.
    # The query parameter `compartmentId` is required unless the query parameter `id` is specified.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [String] :product_id Product platformConfigurationId associated with the Patch.
    # @option opts [String] :version Product version.
    # @option opts [String] :type DefinedBy type.
    # @option opts [String] :patch_type_id Patch Type platformConfigurationId associated with the Patch.
    # @option opts [String] :name A filter to return only resources that match the entire name given.
    # @option opts [String] :id Unique identifier or OCID for listing a single Patch by id.
    #   Either compartmentId or id must be provided.
    #
    # @option opts [DateTime] :time_released_greater_than_or_equal_to A filter to return patches whose release date is greater than or equal to the given date.
    # @option opts [DateTime] :time_released_less_than A filter to return patches whose release date is less than the given date.
    # @option opts [BOOLEAN] :should_compliance_policy_rules_be_applied Filter patch based on compliance policy rules for the Product.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :lifecycle_state The current state of the Patch.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeCreated is descending. Default order for name is ascending.
    #
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::PatchCollection PatchCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_patches.rb.html) to see an example of how to use list_patches API.
    def list_patches(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_patches.' if logger


      if opts[:type] && !OCI::FleetAppsManagement::Models::Patch::TYPE_ENUM.include?(opts[:type])
        raise 'Invalid value for "type", must be one of the values in OCI::FleetAppsManagement::Models::Patch::TYPE_ENUM.'
      end

      if opts[:lifecycle_state] && !OCI::FleetAppsManagement::Models::Patch::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state])
        raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::FleetAppsManagement::Models::Patch::LIFECYCLE_STATE_ENUM.'
      end

      if opts[:sort_by] && !OCI::FleetAppsManagement::Models::PATCH_SORT_BY_ENUM.include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of the values in OCI::FleetAppsManagement::Models::PATCH_SORT_BY_ENUM.'
      end

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      path = '/patches'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:productId] = opts[:product_id] if opts[:product_id]
      query_params[:version] = opts[:version] if opts[:version]
      query_params[:type] = opts[:type] if opts[:type]
      query_params[:patchTypeId] = opts[:patch_type_id] if opts[:patch_type_id]
      query_params[:name] = opts[:name] if opts[:name]
      query_params[:id] = opts[:id] if opts[:id]
      query_params[:timeReleasedGreaterThanOrEqualTo] = opts[:time_released_greater_than_or_equal_to] if opts[:time_released_greater_than_or_equal_to]
      query_params[:timeReleasedLessThan] = opts[:time_released_less_than] if opts[:time_released_less_than]
      query_params[:shouldCompliancePolicyRulesBeApplied] = opts[:should_compliance_policy_rules_be_applied] if !opts[:should_compliance_policy_rules_be_applied].nil?
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_patches') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::PatchCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of resources for an Activity Execution.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [String] job_activity_id unique jobActivity identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :resource_task_id Task Id
    # @option opts [String] :step_name Unique step name
    # @option opts [String] :target_name Unique target name
    # @option opts [String] :sequence Task Order Sequence
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeStarted is descending.
    #    (default to timeStarted)
    #   Allowed values are: timeStarted
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ResourceCollection ResourceCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_resources.rb.html) to see an example of how to use list_resources API.
    def list_resources(scheduler_job_id, job_activity_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_resources.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling list_resources." if scheduler_job_id.nil?
      raise "Missing the required parameter 'job_activity_id' when calling list_resources." if job_activity_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeStarted].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeStarted.'
      end
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)
      raise "Parameter value for 'job_activity_id' must not be blank" if OCI::Internal::Util.blank_string?(job_activity_id)

      path = '/schedulerJobs/{schedulerJobId}/jobActivities/{jobActivityId}/resources'.sub('{schedulerJobId}', scheduler_job_id.to_s).sub('{jobActivityId}', job_activity_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:resourceTaskId] = opts[:resource_task_id] if opts[:resource_task_id]
      query_params[:stepName] = opts[:step_name] if opts[:step_name]
      query_params[:targetName] = opts[:target_name] if opts[:target_name]
      query_params[:sequence] = opts[:sequence] if opts[:sequence]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_resources') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ResourceCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of ScheduledFleets.
    #
    # @param [String] scheduler_definition_id unique SchedulerDefinition identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :display_name A filter to return only resources that match the entire display name given.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for displayName is ascending.
    #    (default to displayName)
    #   Allowed values are: displayName
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ScheduledFleetCollection ScheduledFleetCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_scheduled_fleets.rb.html) to see an example of how to use list_scheduled_fleets API.
    def list_scheduled_fleets(scheduler_definition_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_scheduled_fleets.' if logger

      raise "Missing the required parameter 'scheduler_definition_id' when calling list_scheduled_fleets." if scheduler_definition_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[displayName].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of displayName.'
      end
      raise "Parameter value for 'scheduler_definition_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_definition_id)

      path = '/schedulerDefinitions/{schedulerDefinitionId}/scheduledFleets'.sub('{schedulerDefinitionId}', scheduler_definition_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:displayName] = opts[:display_name] if opts[:display_name]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_scheduled_fleets') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ScheduledFleetCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of all the Schedule Definitions in the specified compartment.
    # The query parameter `compartmentId` is required unless the query parameter `id` is specified.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [String] :lifecycle_state A filter to return only scheduleDefinitions whose lifecycleState matches the given lifecycleState.
    # @option opts [String] :display_name A filter to return only resources that match the entire display name given.
    # @option opts [String] :product A filter to return only dchedule definitions whose assocaited product matches the given product
    # @option opts [String] :id Unique identifier or OCID for listing a single Schedule Definition by id.
    #   Either compartmentId or id must be provided.
    #
    # @option opts [String] :maintenance_window_id A filter to return only schedule definitions whose associated maintenanceWindowId matches the given maintenanceWindowId.
    # @option opts [String] :runbook_id A filter to return only schedule definitions whose associated runbookId matches the given runbookId.
    # @option opts [String] :runbook_version_name RunbookVersion Name filter
    # @option opts [DateTime] :time_scheduled_greater_than_or_equal_to Scheduled Time
    # @option opts [DateTime] :time_scheduled_less_than Scheduled Time
    # @option opts [String] :fleet_id unique Fleet identifier
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeCreated and timeOfNextRun is descending. Default order for displayName is ascending.
    #    (default to displayName)
    #   Allowed values are: timeCreated, displayName, timeOfNextRun
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerDefinitionCollection SchedulerDefinitionCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_scheduler_definitions.rb.html) to see an example of how to use list_scheduler_definitions API.
    def list_scheduler_definitions(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_scheduler_definitions.' if logger


      if opts[:lifecycle_state] && !OCI::FleetAppsManagement::Models::SchedulerDefinition::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state])
        raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::FleetAppsManagement::Models::SchedulerDefinition::LIFECYCLE_STATE_ENUM.'
      end

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeCreated displayName timeOfNextRun].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeCreated, displayName, timeOfNextRun.'
      end

      path = '/schedulerDefinitions'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state]
      query_params[:displayName] = opts[:display_name] if opts[:display_name]
      query_params[:product] = opts[:product] if opts[:product]
      query_params[:id] = opts[:id] if opts[:id]
      query_params[:maintenanceWindowId] = opts[:maintenance_window_id] if opts[:maintenance_window_id]
      query_params[:runbookId] = opts[:runbook_id] if opts[:runbook_id]
      query_params[:runbookVersionName] = opts[:runbook_version_name] if opts[:runbook_version_name]
      query_params[:timeScheduledGreaterThanOrEqualTo] = opts[:time_scheduled_greater_than_or_equal_to] if opts[:time_scheduled_greater_than_or_equal_to]
      query_params[:timeScheduledLessThan] = opts[:time_scheduled_less_than] if opts[:time_scheduled_less_than]
      query_params[:fleetId] = opts[:fleet_id] if opts[:fleet_id]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_scheduler_definitions') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerDefinitionCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of all Fleets that are scheduled.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [String] :display_name A filter to return only resources that match the entire display name given.
    # @option opts [DateTime] :time_scheduled_greater_than_or_equal_to Scheduled Time
    # @option opts [DateTime] :time_scheduled_less_than Scheduled Time
    # @option opts [String] :scheduler_defintion_id SchedulerDefinition identifier
    # @option opts [String] :scheduler_job_id SchedulerJob identifier filter
    # @option opts [String] :resource_id ResourceId filter (Example FleetId)
    # @option opts [String] :runbook_id A filter to return only schedule definitions whose associated runbookId matches the given runbookId.
    # @option opts [String] :runbook_version_name RunbookVersion Name filter
    # @option opts [String] :substate A filter to return only resources their subState matches the given subState.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided.  Default order for timeCreated and timeScheduled is descending.
    #    (default to timeScheduled)
    #   Allowed values are: timeCreated, timeScheduled
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerExecutionCollection SchedulerExecutionCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_scheduler_executions.rb.html) to see an example of how to use list_scheduler_executions API.
    def list_scheduler_executions(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_scheduler_executions.' if logger


      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeCreated timeScheduled].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeCreated, timeScheduled.'
      end

      path = '/schedulerExecutions'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:displayName] = opts[:display_name] if opts[:display_name]
      query_params[:timeScheduledGreaterThanOrEqualTo] = opts[:time_scheduled_greater_than_or_equal_to] if opts[:time_scheduled_greater_than_or_equal_to]
      query_params[:timeScheduledLessThan] = opts[:time_scheduled_less_than] if opts[:time_scheduled_less_than]
      query_params[:schedulerDefintionId] = opts[:scheduler_defintion_id] if opts[:scheduler_defintion_id]
      query_params[:schedulerJobId] = opts[:scheduler_job_id] if opts[:scheduler_job_id]
      query_params[:resourceId] = opts[:resource_id] if opts[:resource_id]
      query_params[:runbookId] = opts[:runbook_id] if opts[:runbook_id]
      query_params[:runbookVersionName] = opts[:runbook_version_name] if opts[:runbook_version_name]
      query_params[:substate] = opts[:substate] if opts[:substate]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_scheduler_executions') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerExecutionCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of all schedule jobs in the specified compartment.
    # The query parameter `compartmentId` is required unless the query parameter `id` is specified.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [String] :lifecycle_state A filter to return only resources whose lifecycleState matches the given lifecycleState.
    # @option opts [String] :fleet_id unique Fleet identifier
    # @option opts [DateTime] :time_scheduled_greater_than_or_equal_to Scheduled Time
    # @option opts [DateTime] :time_scheduled_less_than Scheduled Time
    # @option opts [BOOLEAN] :is_remediation_job_needed Fetch next remediation Job
    # @option opts [String] :substate A filter to return only resources their subState matches the given subState.
    # @option opts [String] :display_name A filter to return only resources that match the entire display name given.
    # @option opts [String] :id Unique identifier or OCID for listing a single Schedule Job by id.
    #   Either compartmentId or id must be provided.
    #
    # @option opts [String] :scheduler_defintion_id SchedulerDefinition identifier
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeCreated and timeScheduled is descending. Default order for displayName is ascending.
    #    (default to timeCreated)
    #   Allowed values are: timeCreated, timeScheduled, displayName
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerJobCollection SchedulerJobCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_scheduler_jobs.rb.html) to see an example of how to use list_scheduler_jobs API.
    def list_scheduler_jobs(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_scheduler_jobs.' if logger


      if opts[:lifecycle_state] && !OCI::FleetAppsManagement::Models::SchedulerJob::LIFECYCLE_STATE_ENUM.include?(opts[:lifecycle_state])
        raise 'Invalid value for "lifecycle_state", must be one of the values in OCI::FleetAppsManagement::Models::SchedulerJob::LIFECYCLE_STATE_ENUM.'
      end

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeCreated timeScheduled displayName].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeCreated, timeScheduled, displayName.'
      end

      path = '/schedulerJobs'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:lifecycleState] = opts[:lifecycle_state] if opts[:lifecycle_state]
      query_params[:fleetId] = opts[:fleet_id] if opts[:fleet_id]
      query_params[:timeScheduledGreaterThanOrEqualTo] = opts[:time_scheduled_greater_than_or_equal_to] if opts[:time_scheduled_greater_than_or_equal_to]
      query_params[:timeScheduledLessThan] = opts[:time_scheduled_less_than] if opts[:time_scheduled_less_than]
      query_params[:isRemediationJobNeeded] = opts[:is_remediation_job_needed] if !opts[:is_remediation_job_needed].nil?
      query_params[:substate] = opts[:substate] if opts[:substate]
      query_params[:displayName] = opts[:display_name] if opts[:display_name]
      query_params[:id] = opts[:id] if opts[:id]
      query_params[:schedulerDefintionId] = opts[:scheduler_defintion_id] if opts[:scheduler_defintion_id]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_scheduler_jobs') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerJobCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Returns a list of Steps for an Activity Execution.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [String] job_activity_id unique jobActivity identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :resource_task_id Task Id
    # @option opts [String] :step_name Unique step name
    # @option opts [String] :target_name Unique target name
    # @option opts [String] :sequence Task Order Sequence
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @option opts [String] :sort_by The field to sort by. Only one sort order may be provided. Default order for timeStarted is descending.
    #    (default to timeStarted)
    #   Allowed values are: timeStarted
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::StepCollection StepCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/list_steps.rb.html) to see an example of how to use list_steps API.
    def list_steps(scheduler_job_id, job_activity_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#list_steps.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling list_steps." if scheduler_job_id.nil?
      raise "Missing the required parameter 'job_activity_id' when calling list_steps." if job_activity_id.nil?

      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      if opts[:sort_by] && !%w[timeStarted].include?(opts[:sort_by])
        raise 'Invalid value for "sort_by", must be one of timeStarted.'
      end
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)
      raise "Parameter value for 'job_activity_id' must not be blank" if OCI::Internal::Util.blank_string?(job_activity_id)

      path = '/schedulerJobs/{schedulerJobId}/jobActivities/{jobActivityId}/steps'.sub('{schedulerJobId}', scheduler_job_id.to_s).sub('{jobActivityId}', job_activity_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:resourceTaskId] = opts[:resource_task_id] if opts[:resource_task_id]
      query_params[:stepName] = opts[:step_name] if opts[:step_name]
      query_params[:targetName] = opts[:target_name] if opts[:target_name]
      query_params[:sequence] = opts[:sequence] if opts[:sequence]
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]
      query_params[:sortBy] = opts[:sort_by] if opts[:sort_by]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#list_steps') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::StepCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Manage execution actions for a Job like retrying or pausing a task.
    #
    # @param [OCI::FleetAppsManagement::Models::ManageJobExecutionDetails] manage_job_execution_details Details for confirming Targets.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :opc_retry_token A token that uniquely identifies a request so it can be retried in case of a timeout or
    #   server error without risk of executing that same action again. Retry tokens expire after 24
    #   hours, but can be invalidated before then due to conflicting operations. For example, if a resource
    #   has been deleted and purged from the system, then a retry of the original creation request
    #   might be rejected.
    #
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/manage_job_execution.rb.html) to see an example of how to use manage_job_execution API.
    def manage_job_execution(manage_job_execution_details, scheduler_job_id, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#manage_job_execution.' if logger

      raise "Missing the required parameter 'manage_job_execution_details' when calling manage_job_execution." if manage_job_execution_details.nil?
      raise "Missing the required parameter 'scheduler_job_id' when calling manage_job_execution." if scheduler_job_id.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)

      path = '/schedulerJobs/{schedulerJobId}/actions/manageJobExecution'.sub('{schedulerJobId}', scheduler_job_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-retry-token'] = opts[:opc_retry_token] if opts[:opc_retry_token]
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf
      header_params[:'opc-retry-token'] ||= OCI::Retry.generate_opc_retry_token

      post_body = @api_client.object_to_http_body(manage_job_execution_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#manage_job_execution') do
        @api_client.call_api(
          :POST,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Retrieve  aggregated summary information of ComplianceRecords within a Compartment.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ComplianceRecordAggregationCollection ComplianceRecordAggregationCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/summarize_compliance_record_counts.rb.html) to see an example of how to use summarize_compliance_record_counts API.
    def summarize_compliance_record_counts(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#summarize_compliance_record_counts.' if logger


      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      path = '/complianceRecordCounts'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#summarize_compliance_record_counts') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ComplianceRecordAggregationCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Retrieve  aggregated summary information of Managed entities within a Compartment.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::ManagedEntityAggregationCollection ManagedEntityAggregationCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/summarize_managed_entity_counts.rb.html) to see an example of how to use summarize_managed_entity_counts API.
    def summarize_managed_entity_counts(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#summarize_managed_entity_counts.' if logger


      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      path = '/managedEntityCounts'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#summarize_managed_entity_counts') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::ManagedEntityAggregationCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Retrieve aggregated summary information of Scheduler Jobs within a Compartment.
    #
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :compartment_id The ID of the compartment in which to list resources.
    #   Empty only if the resource OCID query param is not specified.
    #
    # @option opts [BOOLEAN] :compartment_id_in_subtree If set to true, resources will be returned for not only the provided compartment, but all compartments which
    #   descend from it. Which resources are returned and their field contents depends on the value of accessLevel.
    #    (default to false)
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @option opts [Integer] :limit The maximum number of items to return. (default to 10)
    # @option opts [String] :page A token representing the position at which to start retrieving results. This must come from the `opc-next-page` header field of a previous response.
    # @option opts [String] :sort_order The sort order to use, either 'ASC' or 'DESC'.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerJobAggregationCollection SchedulerJobAggregationCollection}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/summarize_scheduler_job_counts.rb.html) to see an example of how to use summarize_scheduler_job_counts API.
    def summarize_scheduler_job_counts(opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#summarize_scheduler_job_counts.' if logger


      if opts[:sort_order] && !OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.include?(opts[:sort_order])
        raise 'Invalid value for "sort_order", must be one of the values in OCI::FleetAppsManagement::Models::SORT_ORDER_ENUM.'
      end

      path = '/schedulerJobCounts'
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}
      query_params[:compartmentId] = opts[:compartment_id] if opts[:compartment_id]
      query_params[:compartmentIdInSubtree] = opts[:compartment_id_in_subtree] if !opts[:compartment_id_in_subtree].nil?
      query_params[:limit] = opts[:limit] if opts[:limit]
      query_params[:page] = opts[:page] if opts[:page]
      query_params[:sortOrder] = opts[:sort_order] if opts[:sort_order]

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = nil

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#summarize_scheduler_job_counts') do
        @api_client.call_api(
          :GET,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerJobAggregationCollection'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Updates the patch specified by the identifier.
    # @param [String] patch_id Unique Patch identifier.
    # @param [OCI::FleetAppsManagement::Models::UpdatePatchDetails] update_patch_details The information to be updated.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/update_patch.rb.html) to see an example of how to use update_patch API.
    def update_patch(patch_id, update_patch_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#update_patch.' if logger

      raise "Missing the required parameter 'patch_id' when calling update_patch." if patch_id.nil?
      raise "Missing the required parameter 'update_patch_details' when calling update_patch." if update_patch_details.nil?
      raise "Parameter value for 'patch_id' must not be blank" if OCI::Internal::Util.blank_string?(patch_id)

      path = '/patches/{patchId}'.sub('{patchId}', patch_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = @api_client.object_to_http_body(update_patch_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#update_patch') do
        @api_client.call_api(
          :PUT,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Update the details of a SchedulerDefinition that performs lifecycle management operations.
    # @param [String] scheduler_definition_id unique SchedulerDefinition identifier
    # @param [OCI::FleetAppsManagement::Models::UpdateSchedulerDefinitionDetails] update_scheduler_definition_details The information to be updated.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type nil
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/update_scheduler_definition.rb.html) to see an example of how to use update_scheduler_definition API.
    def update_scheduler_definition(scheduler_definition_id, update_scheduler_definition_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#update_scheduler_definition.' if logger

      raise "Missing the required parameter 'scheduler_definition_id' when calling update_scheduler_definition." if scheduler_definition_id.nil?
      raise "Missing the required parameter 'update_scheduler_definition_details' when calling update_scheduler_definition." if update_scheduler_definition_details.nil?
      raise "Parameter value for 'scheduler_definition_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_definition_id)

      path = '/schedulerDefinitions/{schedulerDefinitionId}'.sub('{schedulerDefinitionId}', scheduler_definition_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = @api_client.object_to_http_body(update_scheduler_definition_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#update_scheduler_definition') do
        @api_client.call_api(
          :PUT,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines


    # Updates certain attributes for the specified schedule job.
    # @param [String] scheduler_job_id unique SchedulerJob identifier
    # @param [OCI::FleetAppsManagement::Models::UpdateSchedulerJobDetails] update_scheduler_job_details Attributes to update a schedule job.
    # @param [Hash] opts the optional parameters
    # @option opts [OCI::Retry::RetryConfig] :retry_config The retry configuration to apply to this operation. If no key is provided then the service-level
    #   retry configuration defined by {#retry_config} will be used. If an explicit `nil` value is provided then the operation will not retry
    # @option opts [String] :if_match For optimistic concurrency control. In the PUT or DELETE call
    #   for a resource, set the `if-match` parameter to the value of the
    #   etag from a previous GET or POST response for that resource.
    #   The resource will be updated or deleted only if the etag you
    #   provide matches the resource's current etag value.
    #
    # @option opts [String] :opc_request_id The client request ID for tracing.
    # @return [Response] A Response object with data of type {OCI::FleetAppsManagement::Models::SchedulerJob SchedulerJob}
    # @note Click [here](https://docs.cloud.oracle.com/en-us/iaas/tools/ruby-sdk-examples/latest/fleetappsmanagement/update_scheduler_job.rb.html) to see an example of how to use update_scheduler_job API.
    def update_scheduler_job(scheduler_job_id, update_scheduler_job_details, opts = {})
      logger.debug 'Calling operation FleetAppsManagementOperationsClient#update_scheduler_job.' if logger

      raise "Missing the required parameter 'scheduler_job_id' when calling update_scheduler_job." if scheduler_job_id.nil?
      raise "Missing the required parameter 'update_scheduler_job_details' when calling update_scheduler_job." if update_scheduler_job_details.nil?
      raise "Parameter value for 'scheduler_job_id' must not be blank" if OCI::Internal::Util.blank_string?(scheduler_job_id)

      path = '/schedulerJobs/{schedulerJobId}'.sub('{schedulerJobId}', scheduler_job_id.to_s)
      operation_signing_strategy = :standard

      # rubocop:disable Style/NegatedIf
      # Query Params
      query_params = {}

      # Header Params
      header_params = {}
      header_params[:accept] = 'application/json'
      header_params[:'content-type'] = 'application/json'
      header_params[:'if-match'] = opts[:if_match] if opts[:if_match]
      header_params[:'opc-request-id'] = opts[:opc_request_id] if opts[:opc_request_id]
      # rubocop:enable Style/NegatedIf

      post_body = @api_client.object_to_http_body(update_scheduler_job_details)

      # rubocop:disable Metrics/BlockLength
      OCI::Retry.make_retrying_call(applicable_retry_config(opts), call_name: 'FleetAppsManagementOperationsClient#update_scheduler_job') do
        @api_client.call_api(
          :PUT,
          path,
          endpoint,
          header_params: header_params,
          query_params: query_params,
          operation_signing_strategy: operation_signing_strategy,
          body: post_body,
          return_type: 'OCI::FleetAppsManagement::Models::SchedulerJob'
        )
      end
      # rubocop:enable Metrics/BlockLength
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Style/IfUnlessModifier, Metrics/ParameterLists
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines

    private

    def applicable_retry_config(opts = {})
      return @retry_config unless opts.key?(:retry_config)

      opts[:retry_config]
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
