# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20250228
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Summary of the FleetResource.
  class FleetAppsManagement::Models::FleetResourceSummary
    COMPLIANCE_STATE_ENUM = [
      COMPLIANCE_STATE_UNKNOWN = 'UNKNOWN'.freeze,
      COMPLIANCE_STATE_COMPLIANT = 'COMPLIANT'.freeze,
      COMPLIANCE_STATE_NON_COMPLIANT = 'NON_COMPLIANT'.freeze,
      COMPLIANCE_STATE_WARNING = 'WARNING'.freeze,
      COMPLIANCE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The unique id of the resource.
    # @return [String]
    attr_accessor :id

    # **[Required]** OCID of the tenancy to which the resource belongs to.
    # @return [String]
    attr_accessor :tenancy_id

    # Associated region
    # @return [String]
    attr_accessor :resource_region

    # **[Required]** The time this resource was created. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_created

    # The time this resource was last updated. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_updated

    # **[Required]** OCID of the compartment to which the resource belongs to.
    # @return [String]
    attr_accessor :compartment_id

    # **[Required]** A user-friendly name. Does not have to be unique, and it's changeable.
    # Avoid entering confidential information.
    #
    # Example: `My new resource`
    #
    # @return [String]
    attr_accessor :display_name

    # **[Required]** The OCID of the resource.
    # @return [String]
    attr_accessor :resource_id

    # Compliance State of the Resource.
    # @return [String]
    attr_reader :compliance_state

    # The compliance percentage.
    # @return [Float]
    attr_accessor :percent_compliant

    # Resource Tenancy Name.
    # @return [String]
    attr_accessor :tenancy_name

    # Resource Compartment name.
    # @return [String]
    attr_accessor :compartment

    # **[Required]** Type of the Resource.
    # @return [String]
    attr_accessor :resource_type

    # Count of products within the resource.
    # @return [Integer]
    attr_accessor :product_count

    # Count of targets within the resource.
    # @return [Integer]
    attr_accessor :target_count

    # Product associated with the resource when the resource type is fleet.
    # Will only be returned for PRODUCT fleets that are part of a GROUP Fleet.
    #
    # @return [String]
    attr_accessor :product

    # Environment Type associated with the Fleet when the resource type is fleet.
    # Will only be returned for ENVIRONMENT fleets that are part of a GROUP Fleet.
    #
    # @return [String]
    attr_accessor :environment_type

    # **[Required]** The current state of the FleetResource.
    # @return [String]
    attr_accessor :lifecycle_state

    # A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
    # @return [String]
    attr_accessor :lifecycle_details

    # System tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :system_tags

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'tenancy_id': :'tenancyId',
        'resource_region': :'resourceRegion',
        'time_created': :'timeCreated',
        'time_updated': :'timeUpdated',
        'compartment_id': :'compartmentId',
        'display_name': :'displayName',
        'resource_id': :'resourceId',
        'compliance_state': :'complianceState',
        'percent_compliant': :'percentCompliant',
        'tenancy_name': :'tenancyName',
        'compartment': :'compartment',
        'resource_type': :'resourceType',
        'product_count': :'productCount',
        'target_count': :'targetCount',
        'product': :'product',
        'environment_type': :'environmentType',
        'lifecycle_state': :'lifecycleState',
        'lifecycle_details': :'lifecycleDetails',
        'system_tags': :'systemTags'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'tenancy_id': :'String',
        'resource_region': :'String',
        'time_created': :'DateTime',
        'time_updated': :'DateTime',
        'compartment_id': :'String',
        'display_name': :'String',
        'resource_id': :'String',
        'compliance_state': :'String',
        'percent_compliant': :'Float',
        'tenancy_name': :'String',
        'compartment': :'String',
        'resource_type': :'String',
        'product_count': :'Integer',
        'target_count': :'Integer',
        'product': :'String',
        'environment_type': :'String',
        'lifecycle_state': :'String',
        'lifecycle_details': :'String',
        'system_tags': :'Hash<String, Hash<String, Object>>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :tenancy_id The value to assign to the {#tenancy_id} property
    # @option attributes [String] :resource_region The value to assign to the {#resource_region} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_updated The value to assign to the {#time_updated} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :resource_id The value to assign to the {#resource_id} property
    # @option attributes [String] :compliance_state The value to assign to the {#compliance_state} property
    # @option attributes [Float] :percent_compliant The value to assign to the {#percent_compliant} property
    # @option attributes [String] :tenancy_name The value to assign to the {#tenancy_name} property
    # @option attributes [String] :compartment The value to assign to the {#compartment} property
    # @option attributes [String] :resource_type The value to assign to the {#resource_type} property
    # @option attributes [Integer] :product_count The value to assign to the {#product_count} property
    # @option attributes [Integer] :target_count The value to assign to the {#target_count} property
    # @option attributes [String] :product The value to assign to the {#product} property
    # @option attributes [String] :environment_type The value to assign to the {#environment_type} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [String] :lifecycle_details The value to assign to the {#lifecycle_details} property
    # @option attributes [Hash<String, Hash<String, Object>>] :system_tags The value to assign to the {#system_tags} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.tenancy_id = attributes[:'tenancyId'] if attributes[:'tenancyId']

      raise 'You cannot provide both :tenancyId and :tenancy_id' if attributes.key?(:'tenancyId') && attributes.key?(:'tenancy_id')

      self.tenancy_id = attributes[:'tenancy_id'] if attributes[:'tenancy_id']

      self.resource_region = attributes[:'resourceRegion'] if attributes[:'resourceRegion']

      raise 'You cannot provide both :resourceRegion and :resource_region' if attributes.key?(:'resourceRegion') && attributes.key?(:'resource_region')

      self.resource_region = attributes[:'resource_region'] if attributes[:'resource_region']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

      raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

      self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

      raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

      self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

      self.compliance_state = attributes[:'complianceState'] if attributes[:'complianceState']

      raise 'You cannot provide both :complianceState and :compliance_state' if attributes.key?(:'complianceState') && attributes.key?(:'compliance_state')

      self.compliance_state = attributes[:'compliance_state'] if attributes[:'compliance_state']

      self.percent_compliant = attributes[:'percentCompliant'] if attributes[:'percentCompliant']

      raise 'You cannot provide both :percentCompliant and :percent_compliant' if attributes.key?(:'percentCompliant') && attributes.key?(:'percent_compliant')

      self.percent_compliant = attributes[:'percent_compliant'] if attributes[:'percent_compliant']

      self.tenancy_name = attributes[:'tenancyName'] if attributes[:'tenancyName']

      raise 'You cannot provide both :tenancyName and :tenancy_name' if attributes.key?(:'tenancyName') && attributes.key?(:'tenancy_name')

      self.tenancy_name = attributes[:'tenancy_name'] if attributes[:'tenancy_name']

      self.compartment = attributes[:'compartment'] if attributes[:'compartment']

      self.resource_type = attributes[:'resourceType'] if attributes[:'resourceType']

      raise 'You cannot provide both :resourceType and :resource_type' if attributes.key?(:'resourceType') && attributes.key?(:'resource_type')

      self.resource_type = attributes[:'resource_type'] if attributes[:'resource_type']

      self.product_count = attributes[:'productCount'] if attributes[:'productCount']

      raise 'You cannot provide both :productCount and :product_count' if attributes.key?(:'productCount') && attributes.key?(:'product_count')

      self.product_count = attributes[:'product_count'] if attributes[:'product_count']

      self.target_count = attributes[:'targetCount'] if attributes[:'targetCount']

      raise 'You cannot provide both :targetCount and :target_count' if attributes.key?(:'targetCount') && attributes.key?(:'target_count')

      self.target_count = attributes[:'target_count'] if attributes[:'target_count']

      self.product = attributes[:'product'] if attributes[:'product']

      self.environment_type = attributes[:'environmentType'] if attributes[:'environmentType']

      raise 'You cannot provide both :environmentType and :environment_type' if attributes.key?(:'environmentType') && attributes.key?(:'environment_type')

      self.environment_type = attributes[:'environment_type'] if attributes[:'environment_type']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

      raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

      self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

      self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

      raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

      self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] compliance_state Object to be assigned
    def compliance_state=(compliance_state)
      # rubocop:disable Style/ConditionalAssignment
      if compliance_state && !COMPLIANCE_STATE_ENUM.include?(compliance_state)
        OCI.logger.debug("Unknown value for 'compliance_state' [" + compliance_state + "]. Mapping to 'COMPLIANCE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @compliance_state = COMPLIANCE_STATE_UNKNOWN_ENUM_VALUE
      else
        @compliance_state = compliance_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        tenancy_id == other.tenancy_id &&
        resource_region == other.resource_region &&
        time_created == other.time_created &&
        time_updated == other.time_updated &&
        compartment_id == other.compartment_id &&
        display_name == other.display_name &&
        resource_id == other.resource_id &&
        compliance_state == other.compliance_state &&
        percent_compliant == other.percent_compliant &&
        tenancy_name == other.tenancy_name &&
        compartment == other.compartment &&
        resource_type == other.resource_type &&
        product_count == other.product_count &&
        target_count == other.target_count &&
        product == other.product &&
        environment_type == other.environment_type &&
        lifecycle_state == other.lifecycle_state &&
        lifecycle_details == other.lifecycle_details &&
        system_tags == other.system_tags
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, tenancy_id, resource_region, time_created, time_updated, compartment_id, display_name, resource_id, compliance_state, percent_compliant, tenancy_name, compartment, resource_type, product_count, target_count, product, environment_type, lifecycle_state, lifecycle_details, system_tags].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
