# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20250228
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Fleet Application Management onboarding resource.
  # The onboarding process lets\u00A0Fleet Application Management\u00A0create a few required policies that you need to start using it and its features.
  #
  class FleetAppsManagement::Models::Onboarding
    LIFECYCLE_STATE_ENUM = [
      LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
      LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
      LIFECYCLE_STATE_CREATING = 'CREATING'.freeze,
      LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
      LIFECYCLE_STATE_DELETING = 'DELETING'.freeze,
      LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
      LIFECYCLE_STATE_UPDATING = 'UPDATING'.freeze,
      LIFECYCLE_STATE_NEEDS_ATTENTION = 'NEEDS_ATTENTION'.freeze,
      LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The unique id of the resource.
    # @return [String]
    attr_accessor :id

    # **[Required]** Tenancy OCID
    # @return [String]
    attr_accessor :compartment_id

    # Associated region
    # @return [String]
    attr_accessor :resource_region

    # The time this resource was created. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_created

    # The time this resource was last updated. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_updated

    # A value determining if the Fleet Application Management tagging is enabled or not.
    # Allow Fleet Application Management to tag resources with fleet name using \"Oracle$FAMS-Tags.FleetName\" tag.
    #
    # @return [BOOLEAN]
    attr_accessor :is_fams_tag_enabled

    # The version of Fleet Application Management that the tenant is onboarded to.
    # @return [String]
    attr_accessor :version

    # A value determining if the cost tracking tag is enabled or not.
    # Allow Fleet Application Management to tag resources with cost tracking tag using \"Oracle$FAMS-Tags.FAMSManaged\" tag.
    #
    # @return [BOOLEAN]
    attr_accessor :is_cost_tracking_tag_enabled

    # @return [OCI::FleetAppsManagement::Models::OnboardingPolicySummary]
    attr_accessor :applied_policies

    # Provide discovery frequency.
    # @return [String]
    attr_accessor :discovery_frequency

    # **[Required]** The current state of the Onboarding.
    # @return [String]
    attr_reader :lifecycle_state

    # System tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :system_tags

    # Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
    # Example: `{\"bar-key\": \"value\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :freeform_tags

    # Defined tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :defined_tags

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'compartment_id': :'compartmentId',
        'resource_region': :'resourceRegion',
        'time_created': :'timeCreated',
        'time_updated': :'timeUpdated',
        'is_fams_tag_enabled': :'isFamsTagEnabled',
        'version': :'version',
        'is_cost_tracking_tag_enabled': :'isCostTrackingTagEnabled',
        'applied_policies': :'appliedPolicies',
        'discovery_frequency': :'discoveryFrequency',
        'lifecycle_state': :'lifecycleState',
        'system_tags': :'systemTags',
        'freeform_tags': :'freeformTags',
        'defined_tags': :'definedTags'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'compartment_id': :'String',
        'resource_region': :'String',
        'time_created': :'DateTime',
        'time_updated': :'DateTime',
        'is_fams_tag_enabled': :'BOOLEAN',
        'version': :'String',
        'is_cost_tracking_tag_enabled': :'BOOLEAN',
        'applied_policies': :'OCI::FleetAppsManagement::Models::OnboardingPolicySummary',
        'discovery_frequency': :'String',
        'lifecycle_state': :'String',
        'system_tags': :'Hash<String, Hash<String, Object>>',
        'freeform_tags': :'Hash<String, String>',
        'defined_tags': :'Hash<String, Hash<String, Object>>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [String] :resource_region The value to assign to the {#resource_region} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_updated The value to assign to the {#time_updated} property
    # @option attributes [BOOLEAN] :is_fams_tag_enabled The value to assign to the {#is_fams_tag_enabled} property
    # @option attributes [String] :version The value to assign to the {#version} property
    # @option attributes [BOOLEAN] :is_cost_tracking_tag_enabled The value to assign to the {#is_cost_tracking_tag_enabled} property
    # @option attributes [OCI::FleetAppsManagement::Models::OnboardingPolicySummary] :applied_policies The value to assign to the {#applied_policies} property
    # @option attributes [String] :discovery_frequency The value to assign to the {#discovery_frequency} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [Hash<String, Hash<String, Object>>] :system_tags The value to assign to the {#system_tags} property
    # @option attributes [Hash<String, String>] :freeform_tags The value to assign to the {#freeform_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :defined_tags The value to assign to the {#defined_tags} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.resource_region = attributes[:'resourceRegion'] if attributes[:'resourceRegion']

      raise 'You cannot provide both :resourceRegion and :resource_region' if attributes.key?(:'resourceRegion') && attributes.key?(:'resource_region')

      self.resource_region = attributes[:'resource_region'] if attributes[:'resource_region']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

      raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

      self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

      self.is_fams_tag_enabled = attributes[:'isFamsTagEnabled'] unless attributes[:'isFamsTagEnabled'].nil?
      self.is_fams_tag_enabled = false if is_fams_tag_enabled.nil? && !attributes.key?(:'isFamsTagEnabled') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :isFamsTagEnabled and :is_fams_tag_enabled' if attributes.key?(:'isFamsTagEnabled') && attributes.key?(:'is_fams_tag_enabled')

      self.is_fams_tag_enabled = attributes[:'is_fams_tag_enabled'] unless attributes[:'is_fams_tag_enabled'].nil?
      self.is_fams_tag_enabled = false if is_fams_tag_enabled.nil? && !attributes.key?(:'isFamsTagEnabled') && !attributes.key?(:'is_fams_tag_enabled') # rubocop:disable Style/StringLiterals

      self.version = attributes[:'version'] if attributes[:'version']

      self.is_cost_tracking_tag_enabled = attributes[:'isCostTrackingTagEnabled'] unless attributes[:'isCostTrackingTagEnabled'].nil?
      self.is_cost_tracking_tag_enabled = false if is_cost_tracking_tag_enabled.nil? && !attributes.key?(:'isCostTrackingTagEnabled') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :isCostTrackingTagEnabled and :is_cost_tracking_tag_enabled' if attributes.key?(:'isCostTrackingTagEnabled') && attributes.key?(:'is_cost_tracking_tag_enabled')

      self.is_cost_tracking_tag_enabled = attributes[:'is_cost_tracking_tag_enabled'] unless attributes[:'is_cost_tracking_tag_enabled'].nil?
      self.is_cost_tracking_tag_enabled = false if is_cost_tracking_tag_enabled.nil? && !attributes.key?(:'isCostTrackingTagEnabled') && !attributes.key?(:'is_cost_tracking_tag_enabled') # rubocop:disable Style/StringLiterals

      self.applied_policies = attributes[:'appliedPolicies'] if attributes[:'appliedPolicies']

      raise 'You cannot provide both :appliedPolicies and :applied_policies' if attributes.key?(:'appliedPolicies') && attributes.key?(:'applied_policies')

      self.applied_policies = attributes[:'applied_policies'] if attributes[:'applied_policies']

      self.discovery_frequency = attributes[:'discoveryFrequency'] if attributes[:'discoveryFrequency']

      raise 'You cannot provide both :discoveryFrequency and :discovery_frequency' if attributes.key?(:'discoveryFrequency') && attributes.key?(:'discovery_frequency')

      self.discovery_frequency = attributes[:'discovery_frequency'] if attributes[:'discovery_frequency']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

      raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

      self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']

      self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

      raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

      self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

      self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

      raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

      self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_state Object to be assigned
    def lifecycle_state=(lifecycle_state)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_state && !LIFECYCLE_STATE_ENUM.include?(lifecycle_state)
        OCI.logger.debug("Unknown value for 'lifecycle_state' [" + lifecycle_state + "]. Mapping to 'LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_state = LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_state = lifecycle_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        compartment_id == other.compartment_id &&
        resource_region == other.resource_region &&
        time_created == other.time_created &&
        time_updated == other.time_updated &&
        is_fams_tag_enabled == other.is_fams_tag_enabled &&
        version == other.version &&
        is_cost_tracking_tag_enabled == other.is_cost_tracking_tag_enabled &&
        applied_policies == other.applied_policies &&
        discovery_frequency == other.discovery_frequency &&
        lifecycle_state == other.lifecycle_state &&
        system_tags == other.system_tags &&
        freeform_tags == other.freeform_tags &&
        defined_tags == other.defined_tags
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, compartment_id, resource_region, time_created, time_updated, is_fams_tag_enabled, version, is_cost_tracking_tag_enabled, applied_policies, discovery_frequency, lifecycle_state, system_tags, freeform_tags, defined_tags].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
