# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20250228
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Summary of the Scheduler Executions.
  class FleetAppsManagement::Models::SchedulerExecutionSummary
    LIFECYCLE_STATE_ENUM = [
      LIFECYCLE_STATE_ACTIVE = 'ACTIVE'.freeze,
      LIFECYCLE_STATE_DELETED = 'DELETED'.freeze,
      LIFECYCLE_STATE_FAILED = 'FAILED'.freeze,
      LIFECYCLE_STATE_INACTIVE = 'INACTIVE'.freeze,
      LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The OCID of the resource.
    # @return [String]
    attr_accessor :id

    # **[Required]** A user-friendly name. Does not have to be unique, and it's changeable.
    # Avoid entering confidential information.
    #
    # Example: `My new resource`
    #
    # @return [String]
    attr_accessor :display_name

    # **[Required]** Compartment OCID
    # @return [String]
    attr_accessor :compartment_id

    # **[Required]** The time this resource was created. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_created

    # The time this resource was last updated. An RFC3339 formatted datetime string.
    # @return [DateTime]
    attr_accessor :time_updated

    # The scheduled date and time for the Job.
    # @return [DateTime]
    attr_accessor :time_scheduled

    # Action Group associated with the Schedule.
    # @return [String]
    attr_accessor :activity_id

    # ResourceId associated with the Schedule.
    # @return [String]
    attr_accessor :resource_id

    # jobId associated with the Schedule.
    # @return [String]
    attr_accessor :scheduler_job_id

    # Resource DsiplayName associated with the Schedule.
    # @return [String]
    attr_accessor :resource_display_name

    # RunbookId associated with the Schedule.
    # @return [String]
    attr_accessor :runbook_id

    # Name of the Runbook version associated with the Schedule.
    # @return [String]
    attr_accessor :runbook_version_name

    # DsiplayName of Runbook associated with the Schedule.
    # @return [String]
    attr_accessor :runbook_display_name

    # Latest Runbook version available.
    # @return [String]
    attr_accessor :latest_runbook_version_name

    # @return [OCI::FleetAppsManagement::Models::AssociatedSchedulerDefinition]
    attr_accessor :scheduler_definition

    # Actual start date and time for the Execution.
    # @return [DateTime]
    attr_accessor :time_started

    # Actual end date and time for the Execution.
    # @return [DateTime]
    attr_accessor :time_ended

    # **[Required]** The current state of the Scheduler Execution.
    # @return [String]
    attr_reader :lifecycle_state

    # A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
    # @return [String]
    attr_accessor :lifecycle_details

    # **[Required]** Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
    # Example: `{\"bar-key\": \"value\"}`
    #
    # @return [Hash<String, String>]
    attr_accessor :freeform_tags

    # **[Required]** Defined tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :defined_tags

    # System tags for this resource. Each key is predefined and scoped to a namespace.
    # Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
    #
    # @return [Hash<String, Hash<String, Object>>]
    attr_accessor :system_tags

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'id',
        'display_name': :'displayName',
        'compartment_id': :'compartmentId',
        'time_created': :'timeCreated',
        'time_updated': :'timeUpdated',
        'time_scheduled': :'timeScheduled',
        'activity_id': :'activityId',
        'resource_id': :'resourceId',
        'scheduler_job_id': :'schedulerJobId',
        'resource_display_name': :'resourceDisplayName',
        'runbook_id': :'runbookId',
        'runbook_version_name': :'runbookVersionName',
        'runbook_display_name': :'runbookDisplayName',
        'latest_runbook_version_name': :'latestRunbookVersionName',
        'scheduler_definition': :'schedulerDefinition',
        'time_started': :'timeStarted',
        'time_ended': :'timeEnded',
        'lifecycle_state': :'lifecycleState',
        'lifecycle_details': :'lifecycleDetails',
        'freeform_tags': :'freeformTags',
        'defined_tags': :'definedTags',
        'system_tags': :'systemTags'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'id': :'String',
        'display_name': :'String',
        'compartment_id': :'String',
        'time_created': :'DateTime',
        'time_updated': :'DateTime',
        'time_scheduled': :'DateTime',
        'activity_id': :'String',
        'resource_id': :'String',
        'scheduler_job_id': :'String',
        'resource_display_name': :'String',
        'runbook_id': :'String',
        'runbook_version_name': :'String',
        'runbook_display_name': :'String',
        'latest_runbook_version_name': :'String',
        'scheduler_definition': :'OCI::FleetAppsManagement::Models::AssociatedSchedulerDefinition',
        'time_started': :'DateTime',
        'time_ended': :'DateTime',
        'lifecycle_state': :'String',
        'lifecycle_details': :'String',
        'freeform_tags': :'Hash<String, String>',
        'defined_tags': :'Hash<String, Hash<String, Object>>',
        'system_tags': :'Hash<String, Hash<String, Object>>'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :id The value to assign to the {#id} property
    # @option attributes [String] :display_name The value to assign to the {#display_name} property
    # @option attributes [String] :compartment_id The value to assign to the {#compartment_id} property
    # @option attributes [DateTime] :time_created The value to assign to the {#time_created} property
    # @option attributes [DateTime] :time_updated The value to assign to the {#time_updated} property
    # @option attributes [DateTime] :time_scheduled The value to assign to the {#time_scheduled} property
    # @option attributes [String] :activity_id The value to assign to the {#activity_id} property
    # @option attributes [String] :resource_id The value to assign to the {#resource_id} property
    # @option attributes [String] :scheduler_job_id The value to assign to the {#scheduler_job_id} property
    # @option attributes [String] :resource_display_name The value to assign to the {#resource_display_name} property
    # @option attributes [String] :runbook_id The value to assign to the {#runbook_id} property
    # @option attributes [String] :runbook_version_name The value to assign to the {#runbook_version_name} property
    # @option attributes [String] :runbook_display_name The value to assign to the {#runbook_display_name} property
    # @option attributes [String] :latest_runbook_version_name The value to assign to the {#latest_runbook_version_name} property
    # @option attributes [OCI::FleetAppsManagement::Models::AssociatedSchedulerDefinition] :scheduler_definition The value to assign to the {#scheduler_definition} property
    # @option attributes [DateTime] :time_started The value to assign to the {#time_started} property
    # @option attributes [DateTime] :time_ended The value to assign to the {#time_ended} property
    # @option attributes [String] :lifecycle_state The value to assign to the {#lifecycle_state} property
    # @option attributes [String] :lifecycle_details The value to assign to the {#lifecycle_details} property
    # @option attributes [Hash<String, String>] :freeform_tags The value to assign to the {#freeform_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :defined_tags The value to assign to the {#defined_tags} property
    # @option attributes [Hash<String, Hash<String, Object>>] :system_tags The value to assign to the {#system_tags} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.id = attributes[:'id'] if attributes[:'id']

      self.display_name = attributes[:'displayName'] if attributes[:'displayName']

      raise 'You cannot provide both :displayName and :display_name' if attributes.key?(:'displayName') && attributes.key?(:'display_name')

      self.display_name = attributes[:'display_name'] if attributes[:'display_name']

      self.compartment_id = attributes[:'compartmentId'] if attributes[:'compartmentId']

      raise 'You cannot provide both :compartmentId and :compartment_id' if attributes.key?(:'compartmentId') && attributes.key?(:'compartment_id')

      self.compartment_id = attributes[:'compartment_id'] if attributes[:'compartment_id']

      self.time_created = attributes[:'timeCreated'] if attributes[:'timeCreated']

      raise 'You cannot provide both :timeCreated and :time_created' if attributes.key?(:'timeCreated') && attributes.key?(:'time_created')

      self.time_created = attributes[:'time_created'] if attributes[:'time_created']

      self.time_updated = attributes[:'timeUpdated'] if attributes[:'timeUpdated']

      raise 'You cannot provide both :timeUpdated and :time_updated' if attributes.key?(:'timeUpdated') && attributes.key?(:'time_updated')

      self.time_updated = attributes[:'time_updated'] if attributes[:'time_updated']

      self.time_scheduled = attributes[:'timeScheduled'] if attributes[:'timeScheduled']

      raise 'You cannot provide both :timeScheduled and :time_scheduled' if attributes.key?(:'timeScheduled') && attributes.key?(:'time_scheduled')

      self.time_scheduled = attributes[:'time_scheduled'] if attributes[:'time_scheduled']

      self.activity_id = attributes[:'activityId'] if attributes[:'activityId']

      raise 'You cannot provide both :activityId and :activity_id' if attributes.key?(:'activityId') && attributes.key?(:'activity_id')

      self.activity_id = attributes[:'activity_id'] if attributes[:'activity_id']

      self.resource_id = attributes[:'resourceId'] if attributes[:'resourceId']

      raise 'You cannot provide both :resourceId and :resource_id' if attributes.key?(:'resourceId') && attributes.key?(:'resource_id')

      self.resource_id = attributes[:'resource_id'] if attributes[:'resource_id']

      self.scheduler_job_id = attributes[:'schedulerJobId'] if attributes[:'schedulerJobId']

      raise 'You cannot provide both :schedulerJobId and :scheduler_job_id' if attributes.key?(:'schedulerJobId') && attributes.key?(:'scheduler_job_id')

      self.scheduler_job_id = attributes[:'scheduler_job_id'] if attributes[:'scheduler_job_id']

      self.resource_display_name = attributes[:'resourceDisplayName'] if attributes[:'resourceDisplayName']

      raise 'You cannot provide both :resourceDisplayName and :resource_display_name' if attributes.key?(:'resourceDisplayName') && attributes.key?(:'resource_display_name')

      self.resource_display_name = attributes[:'resource_display_name'] if attributes[:'resource_display_name']

      self.runbook_id = attributes[:'runbookId'] if attributes[:'runbookId']

      raise 'You cannot provide both :runbookId and :runbook_id' if attributes.key?(:'runbookId') && attributes.key?(:'runbook_id')

      self.runbook_id = attributes[:'runbook_id'] if attributes[:'runbook_id']

      self.runbook_version_name = attributes[:'runbookVersionName'] if attributes[:'runbookVersionName']

      raise 'You cannot provide both :runbookVersionName and :runbook_version_name' if attributes.key?(:'runbookVersionName') && attributes.key?(:'runbook_version_name')

      self.runbook_version_name = attributes[:'runbook_version_name'] if attributes[:'runbook_version_name']

      self.runbook_display_name = attributes[:'runbookDisplayName'] if attributes[:'runbookDisplayName']

      raise 'You cannot provide both :runbookDisplayName and :runbook_display_name' if attributes.key?(:'runbookDisplayName') && attributes.key?(:'runbook_display_name')

      self.runbook_display_name = attributes[:'runbook_display_name'] if attributes[:'runbook_display_name']

      self.latest_runbook_version_name = attributes[:'latestRunbookVersionName'] if attributes[:'latestRunbookVersionName']

      raise 'You cannot provide both :latestRunbookVersionName and :latest_runbook_version_name' if attributes.key?(:'latestRunbookVersionName') && attributes.key?(:'latest_runbook_version_name')

      self.latest_runbook_version_name = attributes[:'latest_runbook_version_name'] if attributes[:'latest_runbook_version_name']

      self.scheduler_definition = attributes[:'schedulerDefinition'] if attributes[:'schedulerDefinition']

      raise 'You cannot provide both :schedulerDefinition and :scheduler_definition' if attributes.key?(:'schedulerDefinition') && attributes.key?(:'scheduler_definition')

      self.scheduler_definition = attributes[:'scheduler_definition'] if attributes[:'scheduler_definition']

      self.time_started = attributes[:'timeStarted'] if attributes[:'timeStarted']

      raise 'You cannot provide both :timeStarted and :time_started' if attributes.key?(:'timeStarted') && attributes.key?(:'time_started')

      self.time_started = attributes[:'time_started'] if attributes[:'time_started']

      self.time_ended = attributes[:'timeEnded'] if attributes[:'timeEnded']

      raise 'You cannot provide both :timeEnded and :time_ended' if attributes.key?(:'timeEnded') && attributes.key?(:'time_ended')

      self.time_ended = attributes[:'time_ended'] if attributes[:'time_ended']

      self.lifecycle_state = attributes[:'lifecycleState'] if attributes[:'lifecycleState']

      raise 'You cannot provide both :lifecycleState and :lifecycle_state' if attributes.key?(:'lifecycleState') && attributes.key?(:'lifecycle_state')

      self.lifecycle_state = attributes[:'lifecycle_state'] if attributes[:'lifecycle_state']

      self.lifecycle_details = attributes[:'lifecycleDetails'] if attributes[:'lifecycleDetails']

      raise 'You cannot provide both :lifecycleDetails and :lifecycle_details' if attributes.key?(:'lifecycleDetails') && attributes.key?(:'lifecycle_details')

      self.lifecycle_details = attributes[:'lifecycle_details'] if attributes[:'lifecycle_details']

      self.freeform_tags = attributes[:'freeformTags'] if attributes[:'freeformTags']

      raise 'You cannot provide both :freeformTags and :freeform_tags' if attributes.key?(:'freeformTags') && attributes.key?(:'freeform_tags')

      self.freeform_tags = attributes[:'freeform_tags'] if attributes[:'freeform_tags']

      self.defined_tags = attributes[:'definedTags'] if attributes[:'definedTags']

      raise 'You cannot provide both :definedTags and :defined_tags' if attributes.key?(:'definedTags') && attributes.key?(:'defined_tags')

      self.defined_tags = attributes[:'defined_tags'] if attributes[:'defined_tags']

      self.system_tags = attributes[:'systemTags'] if attributes[:'systemTags']

      raise 'You cannot provide both :systemTags and :system_tags' if attributes.key?(:'systemTags') && attributes.key?(:'system_tags')

      self.system_tags = attributes[:'system_tags'] if attributes[:'system_tags']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] lifecycle_state Object to be assigned
    def lifecycle_state=(lifecycle_state)
      # rubocop:disable Style/ConditionalAssignment
      if lifecycle_state && !LIFECYCLE_STATE_ENUM.include?(lifecycle_state)
        OCI.logger.debug("Unknown value for 'lifecycle_state' [" + lifecycle_state + "]. Mapping to 'LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @lifecycle_state = LIFECYCLE_STATE_UNKNOWN_ENUM_VALUE
      else
        @lifecycle_state = lifecycle_state
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        id == other.id &&
        display_name == other.display_name &&
        compartment_id == other.compartment_id &&
        time_created == other.time_created &&
        time_updated == other.time_updated &&
        time_scheduled == other.time_scheduled &&
        activity_id == other.activity_id &&
        resource_id == other.resource_id &&
        scheduler_job_id == other.scheduler_job_id &&
        resource_display_name == other.resource_display_name &&
        runbook_id == other.runbook_id &&
        runbook_version_name == other.runbook_version_name &&
        runbook_display_name == other.runbook_display_name &&
        latest_runbook_version_name == other.latest_runbook_version_name &&
        scheduler_definition == other.scheduler_definition &&
        time_started == other.time_started &&
        time_ended == other.time_ended &&
        lifecycle_state == other.lifecycle_state &&
        lifecycle_details == other.lifecycle_details &&
        freeform_tags == other.freeform_tags &&
        defined_tags == other.defined_tags &&
        system_tags == other.system_tags
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [id, display_name, compartment_id, time_created, time_updated, time_scheduled, activity_id, resource_id, scheduler_job_id, resource_display_name, runbook_id, runbook_version_name, runbook_display_name, latest_runbook_version_name, scheduler_definition, time_started, time_ended, lifecycle_state, lifecycle_details, freeform_tags, defined_tags, system_tags].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
