# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240531
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Auth related information to be used when invoking external endpoint
  #
  # This class has direct subclasses. If you are using this class as input to a service operations then you should favor using a subclass over the base class
  class GenerativeAiAgent::Models::HttpEndpointAuthConfig
    HTTP_ENDPOINT_AUTH_CONFIG_TYPE_ENUM = [
      HTTP_ENDPOINT_AUTH_CONFIG_TYPE_HTTP_ENDPOINT_NO_AUTH_CONFIG = 'HTTP_ENDPOINT_NO_AUTH_CONFIG'.freeze,
      HTTP_ENDPOINT_AUTH_CONFIG_TYPE_HTTP_ENDPOINT_DELEGATED_BEARER_AUTH_CONFIG = 'HTTP_ENDPOINT_DELEGATED_BEARER_AUTH_CONFIG'.freeze,
      HTTP_ENDPOINT_AUTH_CONFIG_TYPE_HTTP_ENDPOINT_OCI_RESOURCE_PRINCIPAL_AUTH_CONFIG = 'HTTP_ENDPOINT_OCI_RESOURCE_PRINCIPAL_AUTH_CONFIG'.freeze,
      HTTP_ENDPOINT_AUTH_CONFIG_TYPE_HTTP_ENDPOINT_IDCS_AUTH_CONFIG = 'HTTP_ENDPOINT_IDCS_AUTH_CONFIG'.freeze,
      HTTP_ENDPOINT_AUTH_CONFIG_TYPE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** The type of Auth config to be used when invoking an external endpoint.
    # The allowed values are:
    # - `HTTP_ENDPOINT_NO_AUTH_CONFIG`: Indicates that no authentication is required for invoking the endpoint.
    # - `HTTP_ENDPOINT_DELEGATED_BEARER_AUTH_CONFIG`: Specifies Bearer Token Authentication, where the same Bearer token received as part of the Agent Chat
    # API request is used to invoke the external endpoint.
    # - `HTTP_ENDPOINT_OCI_RESOURCE_PRINCIPAL_AUTH_CONFIG`: Specifies authentication using Oracle Cloud Infrastructure (OCI) Resource Principal, leveraging
    # OCI's identity-based authentication mechanism.
    # - `HTTP_ENDPOINT_IDCS_AUTH_CONFIG`: Specifies authentication using Oracle Identity Cloud Service (IDCS), leveraging OAuth 2.0 for token-based authentication.
    #
    # @return [String]
    attr_reader :http_endpoint_auth_config_type

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'http_endpoint_auth_config_type': :'httpEndpointAuthConfigType'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'http_endpoint_auth_config_type': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Layout/EmptyLines, Metrics/PerceivedComplexity, Metrics/AbcSize


    # Given the hash representation of a subtype of this class,
    # use the info in the hash to return the class of the subtype.
    def self.get_subtype(object_hash)
      type = object_hash[:'httpEndpointAuthConfigType'] # rubocop:disable Style/SymbolLiteral

      return 'OCI::GenerativeAiAgent::Models::HttpEndpointIdcsAuthConfig' if type == 'HTTP_ENDPOINT_IDCS_AUTH_CONFIG'
      return 'OCI::GenerativeAiAgent::Models::HttpEndpointDelegatedBearerAuthConfig' if type == 'HTTP_ENDPOINT_DELEGATED_BEARER_AUTH_CONFIG'
      return 'OCI::GenerativeAiAgent::Models::HttpEndpointNoAuthConfig' if type == 'HTTP_ENDPOINT_NO_AUTH_CONFIG'
      return 'OCI::GenerativeAiAgent::Models::HttpEndpointOciResourcePrincipalAuthConfig' if type == 'HTTP_ENDPOINT_OCI_RESOURCE_PRINCIPAL_AUTH_CONFIG'

      # TODO: Log a warning when the subtype is not found.
      'OCI::GenerativeAiAgent::Models::HttpEndpointAuthConfig'
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Layout/EmptyLines, Metrics/PerceivedComplexity, Metrics/AbcSize

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :http_endpoint_auth_config_type The value to assign to the {#http_endpoint_auth_config_type} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.http_endpoint_auth_config_type = attributes[:'httpEndpointAuthConfigType'] if attributes[:'httpEndpointAuthConfigType']

      raise 'You cannot provide both :httpEndpointAuthConfigType and :http_endpoint_auth_config_type' if attributes.key?(:'httpEndpointAuthConfigType') && attributes.key?(:'http_endpoint_auth_config_type')

      self.http_endpoint_auth_config_type = attributes[:'http_endpoint_auth_config_type'] if attributes[:'http_endpoint_auth_config_type']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] http_endpoint_auth_config_type Object to be assigned
    def http_endpoint_auth_config_type=(http_endpoint_auth_config_type)
      # rubocop:disable Style/ConditionalAssignment
      if http_endpoint_auth_config_type && !HTTP_ENDPOINT_AUTH_CONFIG_TYPE_ENUM.include?(http_endpoint_auth_config_type)
        OCI.logger.debug("Unknown value for 'http_endpoint_auth_config_type' [" + http_endpoint_auth_config_type + "]. Mapping to 'HTTP_ENDPOINT_AUTH_CONFIG_TYPE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @http_endpoint_auth_config_type = HTTP_ENDPOINT_AUTH_CONFIG_TYPE_UNKNOWN_ENUM_VALUE
      else
        @http_endpoint_auth_config_type = http_endpoint_auth_config_type
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        http_endpoint_auth_config_type == other.http_endpoint_auth_config_type
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [http_endpoint_auth_config_type].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
