# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240531
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # The index schema details.
  #
  class GenerativeAiAgent::Models::IndexSchema
    # **[Required]** Body key name.
    # @return [String]
    attr_accessor :body_key

    # URL key that stores the URL of a document, if available.
    # @return [String]
    attr_accessor :url_key

    # Title key that stores the Title of a document, if available.
    # @return [String]
    attr_accessor :title_key

    # Field within customer managed OCI OpenSearch document containing the vector embedding for queries.
    # @return [String]
    attr_accessor :embedding_body_key

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'body_key': :'bodyKey',
        'url_key': :'urlKey',
        'title_key': :'titleKey',
        'embedding_body_key': :'embeddingBodyKey'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'body_key': :'String',
        'url_key': :'String',
        'title_key': :'String',
        'embedding_body_key': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :body_key The value to assign to the {#body_key} property
    # @option attributes [String] :url_key The value to assign to the {#url_key} property
    # @option attributes [String] :title_key The value to assign to the {#title_key} property
    # @option attributes [String] :embedding_body_key The value to assign to the {#embedding_body_key} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.body_key = attributes[:'bodyKey'] if attributes[:'bodyKey']

      raise 'You cannot provide both :bodyKey and :body_key' if attributes.key?(:'bodyKey') && attributes.key?(:'body_key')

      self.body_key = attributes[:'body_key'] if attributes[:'body_key']

      self.url_key = attributes[:'urlKey'] if attributes[:'urlKey']

      raise 'You cannot provide both :urlKey and :url_key' if attributes.key?(:'urlKey') && attributes.key?(:'url_key')

      self.url_key = attributes[:'url_key'] if attributes[:'url_key']

      self.title_key = attributes[:'titleKey'] if attributes[:'titleKey']

      raise 'You cannot provide both :titleKey and :title_key' if attributes.key?(:'titleKey') && attributes.key?(:'title_key')

      self.title_key = attributes[:'title_key'] if attributes[:'title_key']

      self.embedding_body_key = attributes[:'embeddingBodyKey'] if attributes[:'embeddingBodyKey']

      raise 'You cannot provide both :embeddingBodyKey and :embedding_body_key' if attributes.key?(:'embeddingBodyKey') && attributes.key?(:'embedding_body_key')

      self.embedding_body_key = attributes[:'embedding_body_key'] if attributes[:'embedding_body_key']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        body_key == other.body_key &&
        url_key == other.url_key &&
        title_key == other.title_key &&
        embedding_body_key == other.embedding_body_key
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [body_key, url_key, title_key, embedding_body_key].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
