# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20200407
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Options required for the pipeline Initial Data Load. If enabled, copies existing data from source to target before replication.
  #
  class GoldenGate::Models::InitialDataLoad
    IS_INITIAL_LOAD_ENUM = [
      IS_INITIAL_LOAD_ENABLED = 'ENABLED'.freeze,
      IS_INITIAL_LOAD_DISABLED = 'DISABLED'.freeze,
      IS_INITIAL_LOAD_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    ACTION_ON_EXISTING_TABLE_ENUM = [
      ACTION_ON_EXISTING_TABLE_TRUNCATE = 'TRUNCATE'.freeze,
      ACTION_ON_EXISTING_TABLE_REPLACE = 'REPLACE'.freeze,
      ACTION_ON_EXISTING_TABLE_APPEND = 'APPEND'.freeze,
      ACTION_ON_EXISTING_TABLE_SKIP = 'SKIP'.freeze,
      ACTION_ON_EXISTING_TABLE_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** If ENABLED, then existing source data is also synchronized to the target when creating or updating the pipeline.
    #
    # @return [String]
    attr_reader :is_initial_load

    # Action upon existing tables in target when initial Data Load is set i.e., isInitialLoad=true.
    #
    # @return [String]
    attr_reader :action_on_existing_table

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'is_initial_load': :'isInitialLoad',
        'action_on_existing_table': :'actionOnExistingTable'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'is_initial_load': :'String',
        'action_on_existing_table': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :is_initial_load The value to assign to the {#is_initial_load} property
    # @option attributes [String] :action_on_existing_table The value to assign to the {#action_on_existing_table} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.is_initial_load = attributes[:'isInitialLoad'] if attributes[:'isInitialLoad']
      self.is_initial_load = "ENABLED" if is_initial_load.nil? && !attributes.key?(:'isInitialLoad') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :isInitialLoad and :is_initial_load' if attributes.key?(:'isInitialLoad') && attributes.key?(:'is_initial_load')

      self.is_initial_load = attributes[:'is_initial_load'] if attributes[:'is_initial_load']
      self.is_initial_load = "ENABLED" if is_initial_load.nil? && !attributes.key?(:'isInitialLoad') && !attributes.key?(:'is_initial_load') # rubocop:disable Style/StringLiterals

      self.action_on_existing_table = attributes[:'actionOnExistingTable'] if attributes[:'actionOnExistingTable']
      self.action_on_existing_table = "REPLACE" if action_on_existing_table.nil? && !attributes.key?(:'actionOnExistingTable') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :actionOnExistingTable and :action_on_existing_table' if attributes.key?(:'actionOnExistingTable') && attributes.key?(:'action_on_existing_table')

      self.action_on_existing_table = attributes[:'action_on_existing_table'] if attributes[:'action_on_existing_table']
      self.action_on_existing_table = "REPLACE" if action_on_existing_table.nil? && !attributes.key?(:'actionOnExistingTable') && !attributes.key?(:'action_on_existing_table') # rubocop:disable Style/StringLiterals
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] is_initial_load Object to be assigned
    def is_initial_load=(is_initial_load)
      # rubocop:disable Style/ConditionalAssignment
      if is_initial_load && !IS_INITIAL_LOAD_ENUM.include?(is_initial_load)
        OCI.logger.debug("Unknown value for 'is_initial_load' [" + is_initial_load + "]. Mapping to 'IS_INITIAL_LOAD_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @is_initial_load = IS_INITIAL_LOAD_UNKNOWN_ENUM_VALUE
      else
        @is_initial_load = is_initial_load
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] action_on_existing_table Object to be assigned
    def action_on_existing_table=(action_on_existing_table)
      # rubocop:disable Style/ConditionalAssignment
      if action_on_existing_table && !ACTION_ON_EXISTING_TABLE_ENUM.include?(action_on_existing_table)
        OCI.logger.debug("Unknown value for 'action_on_existing_table' [" + action_on_existing_table + "]. Mapping to 'ACTION_ON_EXISTING_TABLE_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @action_on_existing_table = ACTION_ON_EXISTING_TABLE_UNKNOWN_ENUM_VALUE
      else
        @action_on_existing_table = action_on_existing_table
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        is_initial_load == other.is_initial_load &&
        action_on_existing_table == other.action_on_existing_table
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [is_initial_load, action_on_existing_table].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
