# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20190415
require 'date'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Data Storage information.
  #
  class Mysql::Models::DataStorage
    # The actual allocated storage size for the DB System. This may be higher than dataStorageSizeInGBs
    # if an automatic storage expansion has occurred.
    #
    # @return [Integer]
    attr_accessor :allocated_storage_size_in_gbs

    # User specified size of the data volume. May be less than current allocatedStorageSizeInGBs.
    #
    # @return [Integer]
    attr_accessor :data_storage_size_in_gbs

    # The absolute limit the DB System's storage size may ever expand to, either manually or automatically.
    # This limit is based based on the initial dataStorageSizeInGBs when the DB System was first created.
    # Both dataStorageSizeInGBs and maxDataStorageSizeInGBs can not exceed this value.
    #
    # DB Systems with an initial storage size of 400 GB or less can be expanded up to 32 TB.
    # DB Systems with an initial storage size between 401-800 GB can be expanded up to 64 TB.
    # DB Systems with an initial storage size between 801-1200 GB can be expanded up to 96 TB.
    # DB Systems with an initial storage size of 1201 GB or more can be expanded up to 128 TB.
    #
    # @return [Integer]
    attr_accessor :data_storage_size_limit_in_gbs

    # Enable/disable automatic storage expansion. When set to true, the DB System will automatically
    # add storage incrementally up to the value specified in maxStorageSizeInGBs.
    #
    # @return [BOOLEAN]
    attr_accessor :is_auto_expand_storage_enabled

    # Maximum storage size this DB System can expand to. When isAutoExpandStorageEnabled
    # is set to true, the DB System will add storage incrementally up to this value.
    #
    # DB Systems with an initial storage size of 400 GB or less can be expanded up to 32 TB.
    # DB Systems with an initial storage size between 401-800 GB can be expanded up to 64 TB.
    # DB Systems with an initial storage size between 801-1200 GB can be expanded up to 96 TB.
    # DB Systems with an initial storage size of 1201 GB or more can be expanded up to 128 TB.
    #
    # It is not possible to decrease data storage size. You cannot set the maximum data storage size to less
    # than either current DB System dataStorageSizeInGBs or allocatedStorageSizeInGBs.
    #
    # @return [Integer]
    attr_accessor :max_storage_size_in_gbs

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'allocated_storage_size_in_gbs': :'allocatedStorageSizeInGBs',
        'data_storage_size_in_gbs': :'dataStorageSizeInGBs',
        'data_storage_size_limit_in_gbs': :'dataStorageSizeLimitInGBs',
        'is_auto_expand_storage_enabled': :'isAutoExpandStorageEnabled',
        'max_storage_size_in_gbs': :'maxStorageSizeInGBs'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'allocated_storage_size_in_gbs': :'Integer',
        'data_storage_size_in_gbs': :'Integer',
        'data_storage_size_limit_in_gbs': :'Integer',
        'is_auto_expand_storage_enabled': :'BOOLEAN',
        'max_storage_size_in_gbs': :'Integer'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [Integer] :allocated_storage_size_in_gbs The value to assign to the {#allocated_storage_size_in_gbs} property
    # @option attributes [Integer] :data_storage_size_in_gbs The value to assign to the {#data_storage_size_in_gbs} property
    # @option attributes [Integer] :data_storage_size_limit_in_gbs The value to assign to the {#data_storage_size_limit_in_gbs} property
    # @option attributes [BOOLEAN] :is_auto_expand_storage_enabled The value to assign to the {#is_auto_expand_storage_enabled} property
    # @option attributes [Integer] :max_storage_size_in_gbs The value to assign to the {#max_storage_size_in_gbs} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.allocated_storage_size_in_gbs = attributes[:'allocatedStorageSizeInGBs'] if attributes[:'allocatedStorageSizeInGBs']

      raise 'You cannot provide both :allocatedStorageSizeInGBs and :allocated_storage_size_in_gbs' if attributes.key?(:'allocatedStorageSizeInGBs') && attributes.key?(:'allocated_storage_size_in_gbs')

      self.allocated_storage_size_in_gbs = attributes[:'allocated_storage_size_in_gbs'] if attributes[:'allocated_storage_size_in_gbs']

      self.data_storage_size_in_gbs = attributes[:'dataStorageSizeInGBs'] if attributes[:'dataStorageSizeInGBs']

      raise 'You cannot provide both :dataStorageSizeInGBs and :data_storage_size_in_gbs' if attributes.key?(:'dataStorageSizeInGBs') && attributes.key?(:'data_storage_size_in_gbs')

      self.data_storage_size_in_gbs = attributes[:'data_storage_size_in_gbs'] if attributes[:'data_storage_size_in_gbs']

      self.data_storage_size_limit_in_gbs = attributes[:'dataStorageSizeLimitInGBs'] if attributes[:'dataStorageSizeLimitInGBs']

      raise 'You cannot provide both :dataStorageSizeLimitInGBs and :data_storage_size_limit_in_gbs' if attributes.key?(:'dataStorageSizeLimitInGBs') && attributes.key?(:'data_storage_size_limit_in_gbs')

      self.data_storage_size_limit_in_gbs = attributes[:'data_storage_size_limit_in_gbs'] if attributes[:'data_storage_size_limit_in_gbs']

      self.is_auto_expand_storage_enabled = attributes[:'isAutoExpandStorageEnabled'] unless attributes[:'isAutoExpandStorageEnabled'].nil?
      self.is_auto_expand_storage_enabled = false if is_auto_expand_storage_enabled.nil? && !attributes.key?(:'isAutoExpandStorageEnabled') # rubocop:disable Style/StringLiterals

      raise 'You cannot provide both :isAutoExpandStorageEnabled and :is_auto_expand_storage_enabled' if attributes.key?(:'isAutoExpandStorageEnabled') && attributes.key?(:'is_auto_expand_storage_enabled')

      self.is_auto_expand_storage_enabled = attributes[:'is_auto_expand_storage_enabled'] unless attributes[:'is_auto_expand_storage_enabled'].nil?
      self.is_auto_expand_storage_enabled = false if is_auto_expand_storage_enabled.nil? && !attributes.key?(:'isAutoExpandStorageEnabled') && !attributes.key?(:'is_auto_expand_storage_enabled') # rubocop:disable Style/StringLiterals

      self.max_storage_size_in_gbs = attributes[:'maxStorageSizeInGBs'] if attributes[:'maxStorageSizeInGBs']

      raise 'You cannot provide both :maxStorageSizeInGBs and :max_storage_size_in_gbs' if attributes.key?(:'maxStorageSizeInGBs') && attributes.key?(:'max_storage_size_in_gbs')

      self.max_storage_size_in_gbs = attributes[:'max_storage_size_in_gbs'] if attributes[:'max_storage_size_in_gbs']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        allocated_storage_size_in_gbs == other.allocated_storage_size_in_gbs &&
        data_storage_size_in_gbs == other.data_storage_size_in_gbs &&
        data_storage_size_limit_in_gbs == other.data_storage_size_limit_in_gbs &&
        is_auto_expand_storage_enabled == other.is_auto_expand_storage_enabled &&
        max_storage_size_in_gbs == other.max_storage_size_in_gbs
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [allocated_storage_size_in_gbs, data_storage_size_in_gbs, data_storage_size_limit_in_gbs, is_auto_expand_storage_enabled, max_storage_size_in_gbs].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
