# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20240815

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # This class provides a wrapper around {OCI::SecurityAttribute::SecurityAttributeClient} and offers convenience methods
  # for operations that would otherwise need to be chained together. For example, instead of performing an action
  # on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
  # to enter a given state, you can call a single method in this class to accomplish the same functionality
  class SecurityAttribute::SecurityAttributeClientCompositeOperations
    # The {OCI::SecurityAttribute::SecurityAttributeClient} used to communicate with the service_client
    #
    # @return [OCI::SecurityAttribute::SecurityAttributeClient]
    attr_reader :service_client

    # Initializes a new SecurityAttributeClientCompositeOperations
    #
    # @param [OCI::SecurityAttribute::SecurityAttributeClient] service_client The client used to communicate with the service.
    #   Defaults to a new service client created via {OCI::SecurityAttribute::SecurityAttributeClient#initialize} with no arguments
    def initialize(service_client = OCI::SecurityAttribute::SecurityAttributeClient.new)
      @service_client = service_client
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:disable Layout/EmptyLines


    # Calls {OCI::SecurityAttribute::SecurityAttributeClient#create_security_attribute} and then waits for the {OCI::SecurityAttribute::Models::SecurityAttribute} acted upon
    # to enter the given state(s).
    #
    # @param [String] security_attribute_namespace_id The OCID of the security attribute namespace.
    #
    # @param [OCI::SecurityAttribute::Models::CreateSecurityAttributeDetails] create_security_attribute_details Request object for creating a new security attribute in the specified security attribute namespace.
    # @param [Array<String>] wait_for_states An array of states to wait on. These should be valid values for {OCI::SecurityAttribute::Models::SecurityAttribute#lifecycle_state}
    # @param [Hash] base_operation_opts Any optional arguments accepted by {OCI::SecurityAttribute::SecurityAttributeClient#create_security_attribute}
    # @param [Hash] waiter_opts Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:
    #   * max_interval_seconds: The maximum interval between queries, in seconds.
    #   * max_wait_seconds The maximum time to wait, in seconds
    #
    # @return [OCI::Response] A {OCI::Response} object with data of type {OCI::SecurityAttribute::Models::SecurityAttribute}
    def create_security_attribute_and_wait_for_state(security_attribute_namespace_id, create_security_attribute_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
      operation_result = @service_client.create_security_attribute(security_attribute_namespace_id, create_security_attribute_details, base_operation_opts)

      return operation_result if wait_for_states.empty?

      lowered_wait_for_states = wait_for_states.map(&:downcase)
      wait_for_resource_id = operation_result.data.id

      begin
        waiter_result = @service_client.get_security_attribute(wait_for_resource_id).wait_until(
          eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
          max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
          max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
        )
        result_to_return = waiter_result

        return result_to_return
      rescue StandardError
        raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
      end
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:enable Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:disable Layout/EmptyLines


    # Calls {OCI::SecurityAttribute::SecurityAttributeClient#create_security_attribute_namespace} and then waits for the {OCI::SecurityAttribute::Models::SecurityAttributeNamespace} acted upon
    # to enter the given state(s).
    #
    # @param [OCI::SecurityAttribute::Models::CreateSecurityAttributeNamespaceDetails] create_security_attribute_namespace_details Request object for creating a new security attribute namespace.
    # @param [Array<String>] wait_for_states An array of states to wait on. These should be valid values for {OCI::SecurityAttribute::Models::SecurityAttributeNamespace#lifecycle_state}
    # @param [Hash] base_operation_opts Any optional arguments accepted by {OCI::SecurityAttribute::SecurityAttributeClient#create_security_attribute_namespace}
    # @param [Hash] waiter_opts Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:
    #   * max_interval_seconds: The maximum interval between queries, in seconds.
    #   * max_wait_seconds The maximum time to wait, in seconds
    #
    # @return [OCI::Response] A {OCI::Response} object with data of type {OCI::SecurityAttribute::Models::SecurityAttributeNamespace}
    def create_security_attribute_namespace_and_wait_for_state(create_security_attribute_namespace_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
      operation_result = @service_client.create_security_attribute_namespace(create_security_attribute_namespace_details, base_operation_opts)

      return operation_result if wait_for_states.empty?

      lowered_wait_for_states = wait_for_states.map(&:downcase)
      wait_for_resource_id = operation_result.data.id

      begin
        waiter_result = @service_client.get_security_attribute_namespace(wait_for_resource_id).wait_until(
          eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
          max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
          max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
        )
        result_to_return = waiter_result

        return result_to_return
      rescue StandardError
        raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
      end
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:enable Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:disable Layout/EmptyLines


    # Calls {OCI::SecurityAttribute::SecurityAttributeClient#delete_security_attribute_namespace} and then waits for the {OCI::SecurityAttribute::Models::SecurityAttributeNamespace} acted upon
    # to enter the given state(s).
    #
    # @param [String] security_attribute_namespace_id The OCID of the security attribute namespace.
    #
    # @param [Array<String>] wait_for_states An array of states to wait on. These should be valid values for {OCI::SecurityAttribute::Models::SecurityAttributeNamespace#lifecycle_state}
    # @param [Hash] base_operation_opts Any optional arguments accepted by {OCI::SecurityAttribute::SecurityAttributeClient#delete_security_attribute_namespace}
    # @param [Hash] waiter_opts Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:
    #   * max_interval_seconds: The maximum interval between queries, in seconds.
    #   * max_wait_seconds The maximum time to wait, in seconds
    #
    # @return [OCI::Response] A {OCI::Response} object with data of type nil
    def delete_security_attribute_namespace_and_wait_for_state(security_attribute_namespace_id, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
      initial_get_result = @service_client.get_security_attribute_namespace(security_attribute_namespace_id)
      operation_result = @service_client.delete_security_attribute_namespace(security_attribute_namespace_id, base_operation_opts)

      return operation_result if wait_for_states.empty?

      lowered_wait_for_states = wait_for_states.map(&:downcase)

      begin
        waiter_result = initial_get_result.wait_until(
          eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
          max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
          max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200,
          succeed_on_not_found: true
        )
        result_to_return = waiter_result

        return result_to_return
      rescue StandardError
        raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
      end
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:enable Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:disable Layout/EmptyLines


    # Calls {OCI::SecurityAttribute::SecurityAttributeClient#update_security_attribute} and then waits for the {OCI::SecurityAttribute::Models::SecurityAttribute} acted upon
    # to enter the given state(s).
    #
    # @param [String] security_attribute_namespace_id The OCID of the security attribute namespace.
    #
    # @param [String] security_attribute_name The name of the security attribute.
    #
    # @param [OCI::SecurityAttribute::Models::UpdateSecurityAttributeDetails] update_security_attribute_details Request object for updating a security attribute.
    # @param [Array<String>] wait_for_states An array of states to wait on. These should be valid values for {OCI::SecurityAttribute::Models::SecurityAttribute#lifecycle_state}
    # @param [Hash] base_operation_opts Any optional arguments accepted by {OCI::SecurityAttribute::SecurityAttributeClient#update_security_attribute}
    # @param [Hash] waiter_opts Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:
    #   * max_interval_seconds: The maximum interval between queries, in seconds.
    #   * max_wait_seconds The maximum time to wait, in seconds
    #
    # @return [OCI::Response] A {OCI::Response} object with data of type {OCI::SecurityAttribute::Models::SecurityAttribute}
    def update_security_attribute_and_wait_for_state(security_attribute_namespace_id, security_attribute_name, update_security_attribute_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
      operation_result = @service_client.update_security_attribute(security_attribute_namespace_id, security_attribute_name, update_security_attribute_details, base_operation_opts)

      return operation_result if wait_for_states.empty?

      lowered_wait_for_states = wait_for_states.map(&:downcase)
      wait_for_resource_id = operation_result.data.id

      begin
        waiter_result = @service_client.get_security_attribute(wait_for_resource_id).wait_until(
          eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
          max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
          max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
        )
        result_to_return = waiter_result

        return result_to_return
      rescue StandardError
        raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
      end
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:enable Layout/EmptyLines

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:disable Layout/EmptyLines


    # Calls {OCI::SecurityAttribute::SecurityAttributeClient#update_security_attribute_namespace} and then waits for the {OCI::SecurityAttribute::Models::SecurityAttributeNamespace} acted upon
    # to enter the given state(s).
    #
    # @param [String] security_attribute_namespace_id The OCID of the security attribute namespace.
    #
    # @param [OCI::SecurityAttribute::Models::UpdateSecurityAttributeNamespaceDetails] update_security_attribute_namespace_details Request object for updating a namespace.
    # @param [Array<String>] wait_for_states An array of states to wait on. These should be valid values for {OCI::SecurityAttribute::Models::SecurityAttributeNamespace#lifecycle_state}
    # @param [Hash] base_operation_opts Any optional arguments accepted by {OCI::SecurityAttribute::SecurityAttributeClient#update_security_attribute_namespace}
    # @param [Hash] waiter_opts Optional arguments for the waiter. Keys should be symbols, and the following keys are supported:
    #   * max_interval_seconds: The maximum interval between queries, in seconds.
    #   * max_wait_seconds The maximum time to wait, in seconds
    #
    # @return [OCI::Response] A {OCI::Response} object with data of type {OCI::SecurityAttribute::Models::SecurityAttributeNamespace}
    def update_security_attribute_namespace_and_wait_for_state(security_attribute_namespace_id, update_security_attribute_namespace_details, wait_for_states = [], base_operation_opts = {}, waiter_opts = {})
      operation_result = @service_client.update_security_attribute_namespace(security_attribute_namespace_id, update_security_attribute_namespace_details, base_operation_opts)

      return operation_result if wait_for_states.empty?

      lowered_wait_for_states = wait_for_states.map(&:downcase)
      wait_for_resource_id = operation_result.data.id

      begin
        waiter_result = @service_client.get_security_attribute_namespace(wait_for_resource_id).wait_until(
          eval_proc: ->(response) { response.data.respond_to?(:lifecycle_state) && lowered_wait_for_states.include?(response.data.lifecycle_state.downcase) },
          max_interval_seconds: waiter_opts.key?(:max_interval_seconds) ? waiter_opts[:max_interval_seconds] : 30,
          max_wait_seconds: waiter_opts.key?(:max_wait_seconds) ? waiter_opts[:max_wait_seconds] : 1200
        )
        result_to_return = waiter_result

        return result_to_return
      rescue StandardError
        raise OCI::Errors::CompositeOperationError.new(partial_results: [operation_result])
      end
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/ParameterLists, Metrics/PerceivedComplexity
    # rubocop:enable Layout/EmptyLines
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
