# Copyright (c) 2016, 2025, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

# NOTE: This class is auto generated by OracleSDKGenerator. DO NOT EDIT. API Version: 20210330
require 'date'
require 'logger'

# rubocop:disable Lint/UnneededCopDisableDirective, Metrics/LineLength
module OCI
  # Dynamic Group object
  #
  class StackMonitoring::Models::DynamicGroupDetails
    STACK_MONITORING_ASSIGNMENT_ENUM = [
      STACK_MONITORING_ASSIGNMENT_MANAGEMENT_AGENTS = 'MANAGEMENT_AGENTS'.freeze,
      STACK_MONITORING_ASSIGNMENT_MONITORED_INSTANCES = 'MONITORED_INSTANCES'.freeze,
      STACK_MONITORING_ASSIGNMENT_UNKNOWN_ENUM_VALUE = 'UNKNOWN_ENUM_VALUE'.freeze
    ].freeze

    # **[Required]** Name of dynamic Group
    #
    # @return [String]
    attr_accessor :name

    # Identity domain name
    #
    # @return [String]
    attr_accessor :domain

    # **[Required]** Assignment of dynamic group in context of Stack Monitoring service. It describes the purpose of dynamic groups in Stack Monitoring.
    #
    # @return [String]
    attr_reader :stack_monitoring_assignment

    # Attribute mapping from ruby-style variable name to JSON key.
    def self.attribute_map
      {
        # rubocop:disable Style/SymbolLiteral
        'name': :'name',
        'domain': :'domain',
        'stack_monitoring_assignment': :'stackMonitoringAssignment'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # Attribute type mapping.
    def self.swagger_types
      {
        # rubocop:disable Style/SymbolLiteral
        'name': :'String',
        'domain': :'String',
        'stack_monitoring_assignment': :'String'
        # rubocop:enable Style/SymbolLiteral
      }
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:disable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral


    # Initializes the object
    # @param [Hash] attributes Model attributes in the form of hash
    # @option attributes [String] :name The value to assign to the {#name} property
    # @option attributes [String] :domain The value to assign to the {#domain} property
    # @option attributes [String] :stack_monitoring_assignment The value to assign to the {#stack_monitoring_assignment} property
    def initialize(attributes = {})
      return unless attributes.is_a?(Hash)

      # convert string to symbol for hash key
      attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

      self.name = attributes[:'name'] if attributes[:'name']

      self.domain = attributes[:'domain'] if attributes[:'domain']

      self.stack_monitoring_assignment = attributes[:'stackMonitoringAssignment'] if attributes[:'stackMonitoringAssignment']

      raise 'You cannot provide both :stackMonitoringAssignment and :stack_monitoring_assignment' if attributes.key?(:'stackMonitoringAssignment') && attributes.key?(:'stack_monitoring_assignment')

      self.stack_monitoring_assignment = attributes[:'stack_monitoring_assignment'] if attributes[:'stack_monitoring_assignment']
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity
    # rubocop:enable Metrics/MethodLength, Layout/EmptyLines, Style/SymbolLiteral

    # Custom attribute writer method checking allowed values (enum).
    # @param [Object] stack_monitoring_assignment Object to be assigned
    def stack_monitoring_assignment=(stack_monitoring_assignment)
      # rubocop:disable Style/ConditionalAssignment
      if stack_monitoring_assignment && !STACK_MONITORING_ASSIGNMENT_ENUM.include?(stack_monitoring_assignment)
        OCI.logger.debug("Unknown value for 'stack_monitoring_assignment' [" + stack_monitoring_assignment + "]. Mapping to 'STACK_MONITORING_ASSIGNMENT_UNKNOWN_ENUM_VALUE'") if OCI.logger
        @stack_monitoring_assignment = STACK_MONITORING_ASSIGNMENT_UNKNOWN_ENUM_VALUE
      else
        @stack_monitoring_assignment = stack_monitoring_assignment
      end
      # rubocop:enable Style/ConditionalAssignment
    end

    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines


    # Checks equality by comparing each attribute.
    # @param [Object] other the other object to be compared
    def ==(other)
      return true if equal?(other)

      self.class == other.class &&
        name == other.name &&
        domain == other.domain &&
        stack_monitoring_assignment == other.stack_monitoring_assignment
    end
    # rubocop:enable Metrics/CyclomaticComplexity, Metrics/AbcSize, Metrics/PerceivedComplexity, Layout/EmptyLines

    # @see the `==` method
    # @param [Object] other the other object to be compared
    def eql?(other)
      self == other
    end

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Calculates hash code according to all attributes.
    # @return [Fixnum] Hash code
    def hash
      [name, domain, stack_monitoring_assignment].hash
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # rubocop:disable Metrics/AbcSize, Layout/EmptyLines


    # Builds the object from hash
    # @param [Hash] attributes Model attributes in the form of hash
    # @return [Object] Returns the model itself
    def build_from_hash(attributes)
      return nil unless attributes.is_a?(Hash)

      self.class.swagger_types.each_pair do |key, type|
        if type =~ /^Array<(.*)>/i
          # check to ensure the input is an array given that the the attribute
          # is documented as an array but the input is not
          if attributes[self.class.attribute_map[key]].is_a?(Array)
            public_method("#{key}=").call(
              attributes[self.class.attribute_map[key]]
                .map { |v| OCI::Internal::Util.convert_to_type(Regexp.last_match(1), v) }
            )
          end
        elsif !attributes[self.class.attribute_map[key]].nil?
          public_method("#{key}=").call(
            OCI::Internal::Util.convert_to_type(type, attributes[self.class.attribute_map[key]])
          )
        end
        # or else data not found in attributes(hash), not an issue as the data can be optional
      end

      self
    end
    # rubocop:enable Metrics/AbcSize, Layout/EmptyLines

    # Returns the string representation of the object
    # @return [String] String presentation of the object
    def to_s
      to_hash.to_s
    end

    # Returns the object in the form of hash
    # @return [Hash] Returns the object in the form of hash
    def to_hash
      hash = {}
      self.class.attribute_map.each_pair do |attr, param|
        value = public_method(attr).call
        next if value.nil? && !instance_variable_defined?("@#{attr}")

        hash[param] = _to_hash(value)
      end
      hash
    end

    private

    # Outputs non-array value in the form of hash
    # For object, use to_hash. Otherwise, just return the value
    # @param [Object] value Any valid value
    # @return [Hash] Returns the value in the form of hash
    def _to_hash(value)
      if value.is_a?(Array)
        value.compact.map { |v| _to_hash(v) }
      elsif value.is_a?(Hash)
        {}.tap do |hash|
          value.each { |k, v| hash[k] = _to_hash(v) }
        end
      elsif value.respond_to? :to_hash
        value.to_hash
      else
        value
      end
    end
  end
end
# rubocop:enable Lint/UnneededCopDisableDirective, Metrics/LineLength
